@@ -1,6 +1,10 @@
 <?php
 /**
  * This is DokuWiki's Main Configuration file
+ *
+ * All the default values are kept here, you should not modify it but use
+ * a local.php file instead to override the settings from here.
+ *
  * This is a piece of PHP code so PHP syntax applies!
  *
  * For help with the configuration see http://www.splitbrain.org/dokuwiki/wiki:config
@@ -8,14 +12,14 @@
 
 
 /* Datastorage and Permissions */
+
 $conf['fmode']       = 0644;              //set file creation mode
 $conf['dmode']       = 0755;              //set directory creation mode
-
 $conf['lang']        = 'en';              //your language
 $conf['basedir']     = '';                //absolute dir from serveroot - blank for autodetection
 $conf['baseurl']     = '';                //URL to server including protocol - blank for autodetect
 $conf['savedir']     = './data';          //where to store all the files
-$conf['allowdebug']  = 1;                 //make debug possible, disable after install! 0|1
+$conf['allowdebug']  = 0;                 //allow debug output, enable if needed 0|1
 
 /* Display Options */
 
@@ -52,31 +56,38 @@ $conf['mailguard']   = 'hex';             //obfuscate email addresses against sp
                                           //  'none'    - do not obfuscate addresses
 
 /* Authentication Options - read http://www.splitbrain.org/dokuwiki/wiki:acl */
+
 $conf['useacl']      = 0;                //Use Access Control Lists to restrict access?
-$conf['openregister']= 1;                //Should users to be allowed to register?
 $conf['autopasswd']  = 1;                //autogenerate passwords and email them to user
-$conf['resendpasswd']= 0;                //allow resend password function?
 $conf['authtype']    = 'plain';          //which authentication backend should be used
 $conf['passcrypt']   = 'smd5';           //Used crypt method (smd5,md5,sha1,ssha,crypt,mysql,my411)
 $conf['defaultgroup']= 'user';           //Default groups new Users are added to
 $conf['superuser']   = '!!not set!!';    //The admin can be user or @group
 $conf['profileconfirm'] = '1';           //Require current password to confirm changes to user profile
+$conf['disableactions'] = '';            //comma separated list of actions to disable
 
 /* Advanced Options */
+
+$conf['updatecheck'] = 1;                //automatically check for new releases?
 $conf['userewrite']  = 0;                //this makes nice URLs: 0: off 1: .htaccess 2: internal
 $conf['useslash']    = 0;                //use slash instead of colon? only when rewrite is on
+$conf['usedraft']    = 1;                //automatically save a draft while editing (0|1)
 $conf['sepchar']     = '_';              //word separator character in page names; may be a
                                          //  letter, a digit, '_', '-', or '.'.
 $conf['canonical']   = 0;                //Should all URLs use full canonical http://... style?
 $conf['autoplural']  = 0;                //try (non)plural form of nonexisting files?
-$conf['usegzip']     = 1;                //gzip old revisions?
+$conf['compression'] = 'gz';             //compress old revisions: (0: off) ('gz': gnuzip) ('bz2': bzip)
+                                         //  bz2 generates smaller files, but needs more cpu-power
 $conf['cachetime']   = 60*60*24;         //maximum age for cachefile in seconds (defaults to a day)
-$conf['purgeonadd']  = 1;                //purge cache when a new file is added (needed for up to date links)
 $conf['locktime']    = 15*60;            //maximum age for lockfiles (defaults to 15 minutes)
+$conf['fetchsize']   = 0;                //maximum size (bytes) fetch.php may download from extern, disabled by default
 $conf['notify']      = '';               //send change info to this email (leave blank for nobody)
+$conf['registernotify'] = '';            //send info about newly registered users to this email (leave blank for nobody)
 $conf['mailfrom']    = '';               //use this email when sending mails
+$conf['gzip_output'] = 0;                //use gzip content encodeing for the output xhtml (if allowed by browser)
 $conf['gdlib']       = 2;                //the GDlib version (0, 1 or 2) 2 tries to autodetect
 $conf['im_convert']  = '';               //path to ImageMagicks convert (will be used instead of GD)
+$conf['jpg_quality'] = '70';             //quality of compression when scaling jpg images (0-100)
 $conf['spellchecker']= 0;                //enable Spellchecker (needs PHP >= 4.3.0 and aspell installed)
 $conf['subscribers'] = 0;                //enable change notice subscription support
 $conf['compress']    = 1;                //Strip whitespaces and comments from Styles and JavaScript? 1|0
@@ -93,6 +104,8 @@ $conf['rss_linkto'] = 'diff';            //what page RSS entries link to:
                                          //  'page'    - the revised page itself
                                          //  'rev'     - page showing all revisions
                                          //  'current' - most recent revision of page
+$conf['rss_update'] = 5*60;              //Update the RSS feed every n minutes (defaults to 5 minutes)
+$conf['recent_days'] = 7;                //How many days of recent changes to keep. (days)
 
 //Set target to use when creating links - leave empty for same window
 $conf['target']['wiki']      = '';
@@ -109,6 +122,7 @@ $conf['proxy']['pass'] = '';
 $conf['proxy']['ssl']  = 0;
 
 /* Safemode Hack */
+
 $conf['safemodehack'] = 0;               //read http://wiki.splitbrain.org/wiki:safemodehack !
 $conf['ftp']['host'] = 'localhost';
 $conf['ftp']['port'] = '21';
