@@ -11,6 +11,7 @@
   if(!defined('DOKU_INC')) define('DOKU_INC',realpath(dirname(__FILE__)).'/');
   require_once(DOKU_INC.'inc/init.php');
   require_once(DOKU_INC.'inc/common.php');
+  require_once(DOKU_INC.'inc/events.php');
   require_once(DOKU_INC.'inc/pageutils.php');
   require_once(DOKU_INC.'inc/html.php');
   require_once(DOKU_INC.'inc/auth.php');
@@ -19,6 +20,7 @@
   //import variables
   $QUERY = trim($_REQUEST['id']);
   $ID    = getID();
+  $NS    = getNS($ID);
   $REV   = $_REQUEST['rev'];
   $ACT   = $_REQUEST['do'];
   $IDX   = $_REQUEST['idx'];
@@ -44,15 +46,15 @@
   //set default #FIXME not needed here? done in actions?
   if(empty($ACT)) $ACT = 'show';
 
+  //make infos about the selected page available
+  $INFO = pageinfo();
 
+  // handle debugging
   if($conf['allowdebug'] && $ACT == 'debug'){
     html_debug();
     exit;
   }
 
-  //make infos about the selected page available
-  $INFO = pageinfo();
-
   //send 404 for missing pages if configured
   if($conf['send404'] && !$INFO['exists']){
     header('HTTP/1.0 404 Not Found');
@@ -61,11 +63,18 @@
   //prepare breadcrumbs (initialize a static var)
   breadcrumbs();
 
+  // check upstream
+  checkUpdateMessages();
+
+  trigger_event('DOKUWIKI_STARTED',$tmp=array());
+
   //close session
   session_write_close();
 
   //do the work
   act_dispatch($ACT);
 
+  trigger_event('DOKUWIKI_DONE', $tmp=array());
+
 //  xdebug_dump_function_profile(1);
 ?>
