@@ -834,7 +834,7 @@ class DiffFormatter
  *
  */
 
-define('NBSP', "\xA0");     // iso-8859-x non-breaking space.
+define('NBSP', "\xC2\xA0");     // utf-8 non-breaking space.
 
 class _HWLDF_WordAccumulator {
   function _HWLDF_WordAccumulator () {
@@ -1014,7 +1014,7 @@ class TableDiffFormatter extends DiffFormatter
   }
 
   function emptyLine() {
-    $line = str_replace('  ','&nbsp; ',$line);
+    //$line = str_replace('  ','&nbsp; ',$line);
     return '<td colspan="2">&nbsp;</td>';
   }
 
