@@ -23,88 +23,111 @@ function act_dispatch(){
   global $lang;
   global $conf;
 
-  //sanitize $ACT
-  $ACT = act_clean($ACT);
+  // give plugins an opportunity to process the action
+  $evt = new Doku_Event('ACTION_ACT_PREPROCESS',$ACT);
+  if ($evt->advise_before()) {
 
-  //check if searchword was given - else just show
-  $s = cleanID($QUERY);
-  if($ACT == 'search' && empty($s)){
-    $ACT = 'show';
-  }
+    //sanitize $ACT
+    $ACT = act_clean($ACT);
 
-  //login stuff
-  if(in_array($ACT,array('login','logout')))
-    $ACT = act_auth($ACT);
-
-  //check if user is asking to (un)subscribe a page
-  if($ACT == 'subscribe' || $ACT == 'unsubscribe')
-    $ACT = act_subscription($ACT);
-
-  //check permissions
-  $ACT = act_permcheck($ACT);
-
-  //register
-  if($ACT == 'register' && register()){
-    $ACT = 'login';
-  }
-
-  if ($ACT == 'resendpwd' && act_resendpwd()) {
-    $ACT = 'login';
-  }
-
-  //update user profile
-  if (($ACT == 'profile') && updateprofile()) {
-    msg($lang['profchanged'],1);
-    $ACT = 'show';
-  }
-
-  //save
-  if($ACT == 'save')
-    $ACT = act_save($ACT);
-
-  //edit
-  if(($ACT == 'edit' || $ACT == 'preview') && $INFO['editable']){
-    $ACT = act_edit($ACT);
-  }else{
-    unlock($ID); //try to unlock
-  }
-
-  //handle export
-  if(substr($ACT,0,7) == 'export_')
-    $ACT = act_export($ACT);
-
-  //display some infos
-  if($ACT == 'check'){
-    check();
-    $ACT = 'show';
-  }
-
-  //handle admin tasks
-  if($ACT == 'admin'){
-    // retrieve admin plugin name from $_REQUEST['page']
-    if ($_REQUEST['page']) {
-        $pluginlist = plugin_list('admin');
-        if (in_array($_REQUEST['page'], $pluginlist)) {
-          // attempt to load the plugin
-          if ($plugin =& plugin_load('admin',$_REQUEST['page']) !== NULL)
-              $plugin->handle();
-        }
+    //check if searchword was given - else just show
+    $s = cleanID($QUERY);
+    if($ACT == 'search' && empty($s)){
+      $ACT = 'show';
     }
-/*
-        if($_REQUEST['page'] == 'acl'){
-            require_once(DOKU_INC.'inc/admin_acl.php');
-            admin_acl_handler();
+
+    //login stuff
+    if(in_array($ACT,array('login','logout')))
+      $ACT = act_auth($ACT);
+
+    //check if user is asking to (un)subscribe a page
+    if($ACT == 'subscribe' || $ACT == 'unsubscribe')
+      $ACT = act_subscription($ACT);
+
+    //check permissions
+    $ACT = act_permcheck($ACT);
+
+    //register
+    if($ACT == 'register' && register()){
+      $ACT = 'login';
     }
-*/
-  }
+
+    if ($ACT == 'resendpwd' && act_resendpwd()) {
+      $ACT = 'login';
+    }
+
+    //update user profile
+    if (($ACT == 'profile') && updateprofile()) {
+      msg($lang['profchanged'],1);
+      $ACT = 'show';
+    }
+
+    //save
+    if($ACT == 'save')
+      $ACT = act_save($ACT);
+
+    //cancel conflicting edit
+    if($ACT == 'cancel')
+      $ACT = 'show';
+
+    //draft deletion
+    if($ACT == 'draftdel')
+      $ACT = act_draftdel($ACT);
+
+    //draft saving on preview
+    if($ACT == 'preview')
+      $ACT = act_draftsave($ACT);
+
+    //edit
+    if(($ACT == 'edit' || $ACT == 'preview') && $INFO['editable']){
+      $ACT = act_edit($ACT);
+    }else{
+      unlock($ID); //try to unlock
+    }
+
+    //handle export
+    if(substr($ACT,0,7) == 'export_')
+      $ACT = act_export($ACT);
+
+    //display some infos
+    if($ACT == 'check'){
+      check();
+      $ACT = 'show';
+    }
+
+    //handle admin tasks
+    if($ACT == 'admin'){
+      // retrieve admin plugin name from $_REQUEST['page']
+      if (!empty($_REQUEST['page'])) {
+          $pluginlist = plugin_list('admin');
+          if (in_array($_REQUEST['page'], $pluginlist)) {
+            // attempt to load the plugin
+            if ($plugin =& plugin_load('admin',$_REQUEST['page']) !== NULL)
+                $plugin->handle();
+          }
+      }
+    }
+
+    // check permissions again - the action may have changed
+    $ACT = act_permcheck($ACT);
+  }  // end event ACTION_ACT_PREPROCESS default action
+  $evt->advise_after();
+  unset($evt);
+
 
   //call template FIXME: all needed vars available?
-  header('Content-Type: text/html; charset=utf-8');
+  $headers[] = 'Content-Type: text/html; charset=utf-8';
+  trigger_event('ACTION_HEADERS_SEND',$headers,'act_sendheaders');
+
   include(template('main.php'));
   // output for the commands is now handled in inc/templates.php
   // in function tpl_content()
 }
 
+function act_sendheaders($headers) {
+  foreach ($headers as $hdr) header($hdr);
+}
+
 /**
  * Sanitize the action command
  *
@@ -116,10 +139,10 @@ function act_clean($act){
   global $lang;
   global $conf;
 
-  //handle localized buttons
-  if($act == $lang['btn_save']) $act = 'save';
-  if($act == $lang['btn_preview']) $act = 'preview';
-  if($act == $lang['btn_cancel']) $act = 'show';
+  // check if the action was given as array key
+  if(is_array($act)){
+    list($act) = array_keys($act);
+  }
 
   //remove all bad chars
   $act = strtolower($act);
@@ -128,6 +151,12 @@ function act_clean($act){
   if($act == 'export_html') $act = 'export_xhtml';
   if($act == 'export_htmlbody') $act = 'export_xhtmlbody';
 
+  // check if action is disabled
+  if(!actionOK($act)){
+    msg('Command disabled: '.htmlspecialchars($act),-1);
+    return 'show';
+  }
+
   //disable all acl related commands if ACL is disabled
   if(!$conf['useacl'] && in_array($act,array('login','logout','register','admin',
                                              'subscribe','unsubscribe','profile',
@@ -136,12 +165,12 @@ function act_clean($act){
     return 'show';
   }
 
-  if(array_search($act,array('login','logout','register','save','edit',
-                             'preview','search','show','check','index','revisions',
-                             'diff','recent','backlink','admin','subscribe',
-                             'unsubscribe','profile','resendpwd',)) === false
-     && substr($act,0,7) != 'export_' ) {
-    msg('Unknown command: '.htmlspecialchars($act),-1);
+  if(!in_array($act,array('login','logout','register','save','cancel','edit','draft',
+                          'preview','search','show','check','index','revisions',
+                          'diff','recent','backlink','admin','subscribe',
+                          'unsubscribe','profile','resendpwd','recover','wordblock',
+                          'draftdel',)) && substr($act,0,7) != 'export_' ) {
+    msg('Command unknown: '.htmlspecialchars($act),-1);
     return 'show';
   }
   return $act;
@@ -156,7 +185,7 @@ function act_permcheck($act){
   global $INFO;
   global $conf;
 
-  if(in_array($act,array('save','preview','edit'))){
+  if(in_array($act,array('save','preview','edit','recover'))){
     if($INFO['exists']){
       if($act == 'edit'){
         //the edit function will check again and do a source show
@@ -171,11 +200,9 @@ function act_permcheck($act){
   }elseif(in_array($act,array('login','search','recent','profile'))){
     $permneed = AUTH_NONE;
   }elseif($act == 'register'){
-    if ($conf['openregister']){
-      $permneed = AUTH_NONE;
-    }else{
-      $permneed = AUTH_ADMIN;
-    }
+    $permneed = AUTH_NONE;
+  }elseif($act == 'resendpwd'){
+    $permneed = AUTH_NONE;
   }elseif($act == 'admin'){
     $permneed = AUTH_ADMIN;
   }else{
@@ -186,6 +213,43 @@ function act_permcheck($act){
   return 'denied';
 }
 
+/**
+ * Handle 'draftdel'
+ *
+ * Deletes the draft for the current page and user
+ */
+function act_draftdel($act){
+  global $INFO;
+  @unlink($INFO['draft']);
+  $INFO['draft'] = null;
+  return 'show';
+}
+
+/**
+ * Saves a draft on preview
+ *
+ * @todo this currently duplicates code from ajax.php :-/
+ */
+function act_draftsave($act){
+  global $INFO;
+  global $ID;
+  global $conf;
+  if($conf['usedraft'] && $_POST['wikitext']){
+    $draft = array('id'     => $ID,
+                   'prefix' => $_POST['prefix'],
+                   'text'   => $_POST['wikitext'],
+                   'suffix' => $_POST['suffix'],
+                   'date'   => $_POST['date'],
+                   'client' => $INFO['client'],
+                  );
+    $cname = getCacheName($draft['client'].$ID,'.draft');
+    if(io_saveFile($cname,serialize($draft))){
+      $INFO['draft'] = $cname;
+    }
+  }
+  return $act;
+}
+
 /**
  * Handle 'save'
  *
@@ -215,6 +279,9 @@ function act_save($act){
   //unlock it
   unlock($ID);
 
+  //delete draft
+  act_draftdel($act);
+
   //show it
   session_write_close();
   header("Location: ".wl($ID,'',true));
@@ -259,6 +326,7 @@ function act_auth($act){
  */
 function act_edit($act){
   global $ID;
+  global $INFO;
 
   //check if locked by anyone - if not lock for my self
   $lockedby = checklock($ID);
