@@ -13,10 +13,23 @@
   require_once(DOKU_INC.'inc/common.php');
   require_once(DOKU_INC.'inc/io.php');
 
+  // some ACL level defines
+  define('AUTH_NONE',0);
+  define('AUTH_READ',1);
+  define('AUTH_EDIT',2);
+  define('AUTH_CREATE',4);
+  define('AUTH_UPLOAD',8);
+  define('AUTH_DELETE',16);
+  define('AUTH_ADMIN',255);
+
+  global $conf;
+
   if($conf['useacl']){
     require_once(DOKU_INC.'inc/blowfish.php');
     require_once(DOKU_INC.'inc/mail.php');
 
+    global $auth;
+
     // load the the backend auth functions and instantiate the auth object
     if (@file_exists(DOKU_INC.'inc/auth/'.$conf['authtype'].'.class.php')) {
       require_once(DOKU_INC.'inc/auth/basic.class.php');
@@ -40,19 +53,18 @@
     }
   }
 
-  if (!defined('DOKU_COOKIE')) define('DOKU_COOKIE', 'DW'.md5($conf['title']));
-
-  // some ACL level defines
-  define('AUTH_NONE',0);
-  define('AUTH_READ',1);
-  define('AUTH_EDIT',2);
-  define('AUTH_CREATE',4);
-  define('AUTH_UPLOAD',8);
-  define('AUTH_DELETE',16);
-  define('AUTH_ADMIN',255);
-
   // do the login either by cookie or provided credentials
   if($conf['useacl']){
+    if (!isset($_REQUEST['u'])) $_REQUEST['u'] = '';
+    if (!isset($_REQUEST['p'])) $_REQUEST['p'] = '';
+    if (!isset($_REQUEST['r'])) $_REQUEST['r'] = '';
+
+    // if no credentials were given try to use HTTP auth (for SSO)
+    if(empty($_REQUEST['u']) && empty($_COOKIE[DOKU_COOKIE]) && !empty($_SERVER['PHP_AUTH_USER'])){
+      $_REQUEST['u'] = $_SERVER['PHP_AUTH_USER'];
+      $_REQUEST['p'] = $_SERVER['PHP_AUTH_PW'];
+    }
+
     // external trust mechanism in place?
     if(!is_null($auth) && $auth->canDo('external')){
       $auth->trustExternal($_REQUEST['u'],$_REQUEST['p'],$_REQUEST['r']);
@@ -103,7 +115,7 @@ function auth_login($user,$pass,$sticky=false){
   global $auth;
   $sticky ? $sticky = true : $sticky = false; //sanity check
 
-  if(isset($user)){
+  if(!empty($user)){
     //usual login
     if ($auth->checkPass($user,$pass)){
       // make logininfo globally available
@@ -117,10 +129,10 @@ function auth_login($user,$pass,$sticky=false){
       setcookie(DOKU_COOKIE,$cookie,$time,'/');
 
       // set session
-      $_SESSION[$conf['title']]['auth']['user'] = $user;
-      $_SESSION[$conf['title']]['auth']['pass'] = $pass;
-      $_SESSION[$conf['title']]['auth']['buid'] = auth_browseruid();
-      $_SESSION[$conf['title']]['auth']['info'] = $USERINFO;
+      $_SESSION[DOKU_COOKIE]['auth']['user'] = $user;
+      $_SESSION[DOKU_COOKIE]['auth']['pass'] = $pass;
+      $_SESSION[DOKU_COOKIE]['auth']['buid'] = auth_browseruid();
+      $_SESSION[DOKU_COOKIE]['auth']['info'] = $USERINFO;
       return true;
     }else{
       //invalid credentials - log off
@@ -133,7 +145,7 @@ function auth_login($user,$pass,$sticky=false){
     $cookie = base64_decode($_COOKIE[DOKU_COOKIE]);
     list($user,$sticky,$pass) = split('\|',$cookie,3);
     // get session info
-    $session = $_SESSION[$conf['title']]['auth'];
+    $session = $_SESSION[DOKU_COOKIE]['auth'];
 
     if($user && $pass){
       // we got a cookie - see if we can trust it
@@ -212,12 +224,12 @@ function auth_logoff(){
   global $INFO, $ID;
   global $auth;
 
-  if(isset($_SESSION[$conf['title']]['auth']['user']))
-    unset($_SESSION[$conf['title']]['auth']['user']);
-  if(isset($_SESSION[$conf['title']]['auth']['pass']))
-    unset($_SESSION[$conf['title']]['auth']['pass']);
-  if(isset($_SESSION[$conf['title']]['auth']['info']))
-    unset($_SESSION[$conf['title']]['auth']['info']);
+  if(isset($_SESSION[DOKU_COOKIE]['auth']['user']))
+    unset($_SESSION[DOKU_COOKIE]['auth']['user']);
+  if(isset($_SESSION[DOKU_COOKIE]['auth']['pass']))
+    unset($_SESSION[DOKU_COOKIE]['auth']['pass']);
+  if(isset($_SESSION[DOKU_COOKIE]['auth']['info']))
+    unset($_SESSION[DOKU_COOKIE]['auth']['info']);
   if(isset($_SERVER['REMOTE_USER']))
     unset($_SERVER['REMOTE_USER']);
   $USERINFO=null; //FIXME
@@ -366,13 +378,20 @@ function auth_aclcheck($id,$user,$groups){
  * @see rawurldecode()
  */
 function auth_nameencode($name,$skip_group=false){
-  if($skip_group && $name{0} =='@'){
-    return '@'.preg_replace('/([\x00-\x2f\x3a-\x40\x5b-\x60\x7b-\x7f])/e',
-                            "'%'.dechex(ord('\\1'))",substr($name,1));
-  }else{
-    return preg_replace('/([\x00-\x2f\x3a-\x40\x5b-\x60\x7b-\x7f])/e',
-                        "'%'.dechex(ord('\\1'))",$name);
+  global $cache_authname;
+  $cache =& $cache_authname;
+
+  if (!isset($cache[$name][$skip_group])) {
+    if($skip_group && $name{0} =='@'){
+      $cache[$name][$skip_group] = '@'.preg_replace('/([\x00-\x2f\x3a-\x40\x5b-\x60\x7b-\x7f])/e',
+                                                    "'%'.dechex(ord('\\1'))",substr($name,1));
+    }else{
+      $cache[$name][$skip_group] = preg_replace('/([\x00-\x2f\x3a-\x40\x5b-\x60\x7b-\x7f])/e',
+                                                "'%'.dechex(ord('\\1'))",$name);
+    }
   }
+
+  return $cache[$name][$skip_group];
 }
 
 /**
@@ -452,8 +471,8 @@ function register(){
   $_POST['login'] = preg_replace('/.*:/','',$_POST['login']);
   $_POST['login'] = cleanID($_POST['login']);
   //clean fullname and email
-  $_POST['fullname'] = trim(str_replace(':','',$_POST['fullname']));
-  $_POST['email']    = trim(str_replace(':','',$_POST['email']));
+  $_POST['fullname'] = trim(preg_replace('/[\x00-\x1f:<>&%,;]+/','',$_POST['fullname']));
+  $_POST['email']    = trim(preg_replace('/[\x00-\x1f:<>&%,;]+/','',$_POST['email']));
 
   if( empty($_POST['login']) ||
       empty($_POST['fullname']) ||
@@ -487,14 +506,23 @@ function register(){
     return false;
   }
 
+  // create substitutions for use in notification email
+  $substitutions = array(
+    'NEWUSER' => $_POST['login'],
+    'NEWNAME' => $_POST['fullname'],
+    'NEWEMAIL' => $_POST['email'],
+  );
+
   if (!$conf['autopasswd']) {
     msg($lang['regsuccess2'],1);
+    notify('', 'register', '', $_POST['login'], false, $substitutions);
     return true;
   }
 
   // autogenerated password? then send him the password
   if (auth_sendPassword($_POST['login'],$pass)){
     msg($lang['regsuccess'],1);
+    notify('', 'register', '', $_POST['login'], false, $substitutions);
     return true;
   }else{
     msg($lang['regmailfail'],-1);
@@ -513,7 +541,7 @@ function updateprofile() {
   global $lang;
   global $auth;
 
-  if(!$_POST['save']) return false;
+  if(empty($_POST['save'])) return false;
 
   // should not be able to get here without Profile being possible...
   if(!$auth->canDo('Profile')) {
@@ -527,8 +555,8 @@ function updateprofile() {
   }
 
   //clean fullname and email
-  $_POST['fullname'] = trim(str_replace(':','',$_POST['fullname']));
-  $_POST['email']    = trim(str_replace(':','',$_POST['email']));
+  $_POST['fullname'] = trim(preg_replace('/[\x00-\x1f:<>&%,;]+/','',$_POST['fullname']));
+  $_POST['email']    = trim(preg_replace('/[\x00-\x1f:<>&%,;]+/','',$_POST['email']));
 
   if (empty($_POST['fullname']) || empty($_POST['email'])) {
     msg($lang['profnoempty'],-1);
@@ -562,8 +590,14 @@ function updateprofile() {
 /**
  * Send a  new password
  *
+ * This function handles both phases of the password reset:
+ *
+ *   - handling the first request of password reset
+ *   - validating the password reset auth token
+ *
  * @author Benoit Chesneau <benoit@bchesneau.info>
  * @author Chris Smith <chris@jalakai.co.uk>
+ * @author Andreas Gohr <andi@splitbrain.org>
  *
  * @return bool true on success, false on any error
 */
@@ -572,40 +606,90 @@ function act_resendpwd(){
     global $conf;
     global $auth;
 
-    if(!$_POST['save']) return false;
-    if(!$conf['resendpasswd']) return false;
+    if(!actionOK('resendpwd')) return false;
 
     // should not be able to get here without modPass being possible...
     if(!$auth->canDo('modPass')) {
-      msg($lang['resendna'],-1);
-      return false;
+        msg($lang['resendna'],-1);
+        return false;
     }
 
-    if (empty($_POST['login'])) {
-      msg($lang['resendpwdmissing'], -1);
-      return false;
+    $token = preg_replace('/[^a-f0-9]+/','',$_REQUEST['pwauth']);
+
+    if($token){
+        // we're in token phase
+
+        $tfile = $conf['cachedir'].'/'.$token{0}.'/'.$token.'.pwauth';
+        if(!@file_exists($tfile)){
+            msg($lang['resendpwdbadauth'],-1);
+            return false;
+        }
+        $user = io_readfile($tfile);
+        @unlink($tfile);
+        $userinfo = $auth->getUserData($user);
+        if(!$userinfo['mail']) {
+            msg($lang['resendpwdnouser'], -1);
+            return false;
+        }
+
+        $pass = auth_pwgen();
+        if (!$auth->modifyUser($user,array('pass' => $pass))) {
+            msg('error modifying user data',-1);
+            return false;
+        }
+
+        if (auth_sendPassword($user,$pass)) {
+            msg($lang['resendpwdsuccess'],1);
+        } else {
+            msg($lang['regmailfail'],-1);
+        }
+        return true;
+
     } else {
-      $user = $_POST['login'];
+        // we're in request phase
+
+        if(!$_POST['save']) return false;
+
+        if (empty($_POST['login'])) {
+            msg($lang['resendpwdmissing'], -1);
+            return false;
+        } else {
+            $_POST['login'] = preg_replace('/.*:/','',$_POST['login']);
+            $user = cleanID($_POST['login']);
+        }
+
+        $userinfo = $auth->getUserData($user);
+        if(!$userinfo['mail']) {
+            msg($lang['resendpwdnouser'], -1);
+            return false;
+        }
+
+        // generate auth token
+        $token = md5(auth_cookiesalt().$user); //secret but user based
+        $tfile = $conf['cachedir'].'/'.$token{0}.'/'.$token.'.pwauth';
+        $url = wl('',array('do'=>'resendpwd','pwauth'=>$token),true,'&');
+
+        io_saveFile($tfile,$user);
+
+        $text = rawLocale('pwconfirm');
+        $text = str_replace('@DOKUWIKIURL@',DOKU_URL,$text);
+        $text = str_replace('@FULLNAME@',$userinfo['name'],$text);
+        $text = str_replace('@LOGIN@',$user,$text);
+        $text = str_replace('@TITLE@',$conf['title'],$text);
+        $text = str_replace('@CONFIRM@',$url,$text);
+
+        if(mail_send($userinfo['name'].' <'.$userinfo['mail'].'>',
+                     $lang['regpwmail'],
+                     $text,
+                     $conf['mailfrom'])){
+            msg($lang['resendpwdconfirm'],1);
+        }else{
+            msg($lang['regmailfail'],-1);
+        }
+        return true;
     }
 
-    $userinfo = $auth->getUserData($user);
-    if(!$userinfo['mail']) {
-      msg($lang['resendpwdnouser'], -1);
-      return false;
-    }
-
-    $pass = auth_pwgen();
-    if (!$auth->modifyUser($user,array('pass' => $pass))) {
-      msg('error modifying user data',-1);
-      return false;
-    }
-
-    if (auth_sendPassword($user,$pass)) {
-      msg($lang['resendpwdsuccess'],1);
-    } else {
-      msg($lang['regmailfail'],-1);
-    }
-    return true;
+    return false; // never reached
 }
 
 /**
