@@ -339,12 +339,14 @@ class auth_mysql extends auth_basic {
       if($this->_openDB()) {
         $this->_lockTables("READ");
         $sql  = $this->_createSQLFilter($this->cnf['getUsers'], $filter);
-        $sql .= " ".$this->cnf['SortOrder']." LIMIT $limit OFFSET $first";
+        $sql .= " ".$this->cnf['SortOrder']." LIMIT $first, $limit";
         $result = $this->_queryDB($sql);
 
-        foreach ($result as $user)
-          if (($info = $this->_getUserInfo($user['user'])))
-            $out[$user['user']] = $info;
+        if (!empty($result)) {
+          foreach ($result as $user)
+            if (($info = $this->_getUserInfo($user['user'])))
+              $out[$user['user']] = $info;
+        }
 
         $this->_unlockTables();
         $this->_closeDB();
@@ -756,6 +758,7 @@ class auth_mysql extends auth_basic {
      * @author Matthias Grimm <matthiasgrimm@users.sourceforge.net>
      */
     function _queryDB($query) {
+      $resultarray = array();
       if ($this->dbcon) {
         $result = @mysql_query($query,$this->dbcon);
         if ($result) {
