@@ -49,6 +49,16 @@ function ft_pageSearch($query,&$poswords){
     $hidden = array_filter(array_keys($docs),'isHiddenPage');
     $not = array_merge($not,$hidden);
 
+    // filter unmatched namespaces
+    if(!empty($q['ns'])) {
+        $pattern = implode('|^',$q['ns']);
+        foreach($docs as $key => $val) {
+            if(!preg_match('/^'.$pattern.'/',$key)) {
+                unset($docs[$key]);
+            }
+        }
+    }
+
     // remove negative matches
     foreach($not as $n){
         unset($docs[$n]);
@@ -95,35 +105,24 @@ function ft_pageSearch($query,&$poswords){
  */
 function ft_backlinks($id){
     global $conf;
+    $swfile   = DOKU_INC.'inc/lang/'.$conf['lang'].'/stopwords.txt';
+    $stopwords = @file_exists($swfile) ? file($swfile) : array();
+
     $result = array();
 
     // quick lookup of the pagename
     $page    = noNS($id);
-    $sw      = array(); // we don't use stopwords here
-    $matches = idx_lookup(idx_tokenizer($page,$sw));  // pagename may contain specials (_ or .)
+    $matches = idx_lookup(idx_tokenizer($page,$stopwords));  // pagename may contain specials (_ or .)
     $docs    = array_keys(ft_resultCombine(array_values($matches)));
     $docs    = array_filter($docs,'isVisiblePage'); // discard hidden pages
     if(!count($docs)) return $result;
     require_once(DOKU_INC.'inc/parserutils.php');
 
-    // check instructions for matching links
+    // check metadata for matching links
     foreach($docs as $match){
-        $instructions = p_cached_instructions(wikiFN($match),true);
-        if(is_null($instructions)) continue;
-
-        $match_ns =  getNS($match);
-
-        foreach($instructions as $ins){
-            if($ins[0] == 'internallink' || ($conf['camelcase'] && $ins[0] == 'camelcaselink') ){
-                $link = $ins[1][0];
-                resolve_pageid($match_ns,$link,$exists); //exists is not used
-                if($link == $id){
-                    //we have a match - finish
-                    $result[] = $match;
-                    break;
-                }
-            }
-        }
+        // metadata relation reference links are already resolved
+        $links = p_get_metadata($match,'relation references');
+        if (isset($links[$id])) $result[] = $match;
     }
 
     if(!count($result)) return $result;
@@ -190,20 +189,67 @@ function ft_snippet($id,$poswords){
     $poswords = preg_quote($poswords,'#');
     $re       = '('.str_replace(' ','|',$poswords).')';
     $text     = rawWiki($id);
-    //FIXME caseinsensitive matching doesn't work with UTF-8!?
-    preg_match_all('#(.{0,50})'.$re.'(.{0,50})#iu',$text,$matches,PREG_SET_ORDER);
 
-    $cnt = 0;
-    $snippet = '';
-    foreach($matches as $match){
-        $snippet .= '...'.htmlspecialchars($match[1]);
-        $snippet .= '<span class="search_hit">';
-        $snippet .= htmlspecialchars($match[2]);
-        $snippet .= '</span>';
-        $snippet .= htmlspecialchars($match[3]).'... ';
-        if($cnt++ == 2) break;
+    $match = array();
+    $snippets = array();
+    $utf8_offset = $offset = $end = 0;
+    $len = utf8_strlen($text);
+
+    for ($cnt=3; $cnt--;) {
+      if (!preg_match('#'.$re.'#iu',$text,$match,PREG_OFFSET_CAPTURE,$offset)) break;
+
+      list($str,$idx) = $match[0];
+
+      // convert $idx (a byte offset) into a utf8 character offset
+      $utf8_idx = utf8_strlen(substr($text,0,$idx));
+      $utf8_len = utf8_strlen($str);
+
+      // establish context, 100 bytes surrounding the match string
+      // first look to see if we can go 100 either side,
+      // then drop to 50 adding any excess if the other side can't go to 50,
+      $pre = min($utf8_idx-$utf8_offset,100);
+      $post = min($len-$utf8_idx-$utf8_len,100);
+
+      if ($pre>50 && $post>50) {
+        $pre = $post = 50;
+      } else if ($pre>50) {
+        $pre = min($pre,100-$post);
+      } else if ($post>50) {
+        $post = min($post, 100-$pre);
+      } else {
+        // both are less than 50, means the context is the whole string
+        // make it so and break out of this loop - there is no need for the
+        // complex snippet calculations
+        $snippets = array($text);
+        break;
+      }
+
+      // establish context start and end points, try to append to previous
+      // context if possible
+      $start = $utf8_idx - $pre;
+      $append = ($start < $end) ? $end : false;  // still the end of the previous context snippet
+      $end = $utf8_idx + $utf8_len + $post;      // now set it to the end of this context
+
+      if ($append) {
+        $snippets[count($snippets)-1] .= utf8_substr($text,$append,$end-$append);
+      } else {
+        $snippets[] = utf8_substr($text,$start,$end-$start);
+      }
+
+      // set $offset for next match attempt
+      //   substract strlen to avoid splitting a potential search success,
+      //   this is an approximation as the search pattern may match strings
+      //   of varying length and it will fail if the context snippet
+      //   boundary breaks a matching string longer than the current match
+      $utf8_offset = $utf8_idx + $post;
+      $offset = $idx + strlen(utf8_substr($text,$utf8_idx,$post));
+      $offset = utf8_correctIdx($text,$offset);
     }
 
+    $m = "\1";
+    $snippets = preg_replace('#'.$re.'#iu',$m.'$1'.$m,$snippets);
+    $snippet = preg_replace('#'.$m.'([^'.$m.']*?)'.$m.'#iu','<span class="search_hit">$1</span>',hsc(join('... ',$snippets)));
+
     return $snippet;
 }
 
@@ -241,7 +287,6 @@ function ft_resultCombine($args){
  * Builds an array of search words from a query
  *
  * @todo support OR and parenthesises?
- * @todo add namespace handling
  */
 function ft_queryParser($query){
     global $conf;
@@ -254,10 +299,17 @@ function ft_queryParser($query){
 
     $q = array();
     $q['query']   = $query;
+    $q['ns']      = array();
     $q['phrases'] = array();
     $q['and']     = array();
     $q['not']     = array();
 
+    // strip namespace from query
+    if(preg_match('/([^@]*)@(.*)/',$query,$match))  {
+        $query = $match[1];
+        $q['ns'] = explode('@',preg_replace("/ /",'',$match[2]));
+    }
+
     // handle phrase searches
     while(preg_match('/"(.*?)"/',$query,$match)){
         $q['phrases'][] = $match[1];
