@@ -52,38 +52,40 @@ function html_login(){
   print p_locale_xhtml('login');
   ?>
     <div class="centeralign">
-    <form action="<?php echo script()?>" accept-charset="<?php echo $lang['encoding']?>" method="post">
+    <form action="<?php echo script()?>" accept-charset="<?php echo $lang['encoding']?>"
+          method="post" id="dw__login">
       <fieldset>
         <legend><?php echo $lang['btn_login']?></legend>
         <input type="hidden" name="id" value="<?php echo $ID?>" />
         <input type="hidden" name="do" value="login" />
         <label class="block">
           <span><?php echo $lang['user']?></span>
-          <input type="text" name="u" value="<?php echo formText($_REQUEST['u'])?>" class="edit" />
+          <input type="text" name="u" value="<?php echo formText($_REQUEST['u'])?>"
+                 class="edit" id="focus__this" />
         </label><br />
         <label class="block">
           <span><?php echo $lang['pass']?></span>
           <input type="password" name="p" class="edit" />
         </label><br />
-        <input type="submit" value="<?php echo $lang['btn_login']?>" class="button" />
         <label for="remember__me" class="simple">
           <input type="checkbox" name="r" id="remember__me" value="1" />
           <span><?php echo $lang['remember']?></span>
         </label>
+        <input type="submit" value="<?php echo $lang['btn_login']?>" class="button" />
       </fieldset>
     </form>
   <?php
-    if($auth->canDo('addUser') && $conf['openregister']){
+    if($auth->canDo('addUser') && actionOK('register')){
       print '<p>';
       print $lang['reghere'];
-      print ': <a href="'.wl($ID,'do=register').'" class="wikilink1">'.$lang['register'].'</a>';
+      print ': <a href="'.wl($ID,'do=register').'" rel="nofollow" class="wikilink1">'.$lang['register'].'</a>';
       print '</p>';
     }
 
-    if ($auth->canDo('modPass') && $conf['resendpasswd']) {
+    if ($auth->canDo('modPass') && actionOK('resendpwd')) {
       print '<p>';
       print $lang['pwdforget'];
-      print ': <a href="'.wl($ID,'do=resendpwd').'" class="wikilink1">'.$lang['btn_resendpwd'].'</a>';
+      print ': <a href="'.wl($ID,'do=resendpwd').'" rel="nofollow" class="wikilink1">'.$lang['btn_resendpwd'].'</a>';
       print '</p>';
     }
   ?>
@@ -98,49 +100,26 @@ function html_login(){
 }
 
 /**
- * shows the edit/source/show button dependent on current mode
+ * prints a section editing button
+ * used as a callback in html_secedit
  *
  * @author Andreas Gohr <andi@splitbrain.org>
  */
-function html_editbutton(){
+function html_secedit_button($matches){
   global $ID;
-  global $REV;
-  global $ACT;
   global $INFO;
 
-  if($ACT == 'show' || $ACT == 'search'){
-    if($INFO['writable']){
-      if($INFO['exists']){
-        $r = html_btn('edit',$ID,'e',array('do' => 'edit','rev' => $REV),'post');
-      }else{
-        $r = html_btn('create',$ID,'e',array('do' => 'edit','rev' => $REV),'post');
-      }
-    }else{
-      $r = html_btn('source',$ID,'v',array('do' => 'edit','rev' => $REV),'post');
-    }
-  }else{
-    $r = html_btn('show',$ID,'v',array('do' => 'show'));
-  }
-  return $r;
-}
+  $section = $matches[2];
+  $name = $matches[1];
 
-/**
- * prints a section editing button
- *
- * @author Andreas Gohr <andi@splitbrain.org>
- */
-function html_secedit_button($section,$p){
-  global $ID;
-  global $lang;
   $secedit  = '';
-#  if($p) $secedit .= "</p>\n";
   $secedit .= '<div class="secedit">';
   $secedit .= html_btn('secedit',$ID,'',
                         array('do'      => 'edit',
-                              'lines'   => "$section"),
-                              'post');
+                              'lines'   => "$section",
+                              'rev' => $INFO['lastmod']),
+                              'post', $name);
   $secedit .= '</div>';
-#  if($p) $secedit .= "\n<p>";
   return $secedit;
 }
 
@@ -151,16 +130,14 @@ function html_secedit_button($section,$p){
  */
 function html_secedit($text,$show=true){
   global $INFO;
+
   if($INFO['writable'] && $show && !$INFO['rev']){
-    $text = preg_replace('#<!-- SECTION \[(\d+-\d+)\] -->#e',
-                         "html_secedit_button('\\1',true)",
-                         $text);
-    $text = preg_replace('#<!-- SECTION \[(\d+-)\] -->#e',
-                         "html_secedit_button('\\1',false)",
-                         $text);
+    $text = preg_replace_callback('#<!-- SECTION "(.*?)" \[(\d+-\d*)\] -->#',
+                         'html_secedit_button', $text);
   }else{
-    $text = preg_replace('#<!-- SECTION \[(\d*-\d*)\] -->#e','',$text);
+    $text = preg_replace('#<!-- SECTION "(.*?)" \[(\d+-\d*)\] -->#','',$text);
   }
+
   return $text;
 }
 
@@ -173,7 +150,7 @@ function html_topbtn(){
   global $lang;
 
   $ret  = '';
-  $ret  = '<a href="#dokuwiki__top"><input type="button" class="button" value="'.$lang['btn_top'].'" onclick="window.scrollTo(0, 0)" /></a>';
+  $ret  = '<a class="nolink" href="#dokuwiki__top"><input type="button" class="button" value="'.$lang['btn_top'].'" onclick="window.scrollTo(0, 0)" title="'.$lang['btn_top'].'" /></a>';
 
   return $ret;
 }
@@ -187,7 +164,7 @@ function html_backtomedia_button($params,$akey=''){
   global $conf;
   global $lang;
 
-  $ret = '<form class="button" method="get" action="'.DOKU_BASE.'lib/exe/media.php"><div class="no">';
+  $ret = '<form class="button" method="get" action="'.DOKU_BASE.'lib/exe/mediamanager.php"><div class="no">';
 
   reset($params);
   while (list($key, $val) = each($params)) {
@@ -196,10 +173,12 @@ function html_backtomedia_button($params,$akey=''){
   }
 
   $ret .= '<input type="submit" value="'.htmlspecialchars($lang['btn_backtomedia']).'" class="button" ';
+  $tit = htmlspecialchars($lang['btn_backtomedia']);
   if($akey){
-    $ret .= 'title="ALT+'.strtoupper($akey).'" ';
+    $tit .= ' [ALT+'.strtoupper($akey).']';
     $ret .= 'accesskey="'.$akey.'" ';
   }
+  $ret .= 'title="'.$tit.'" ';
   $ret .= '/>';
   $ret .= '</div></form>';
 
@@ -208,16 +187,18 @@ function html_backtomedia_button($params,$akey=''){
 
 /**
  * Displays a button (using its own form)
+ * If tooltip exists, the access key tooltip is replaced.
  *
  * @author Andreas Gohr <andi@splitbrain.org>
  */
-function html_btn($name,$id,$akey,$params,$method='get'){
+function html_btn($name,$id,$akey,$params,$method='get',$tooltip=''){
   global $conf;
   global $lang;
 
   $label = $lang['btn_'.$name];
 
   $ret = '';
+  $tip = '';
 
   //filter id (without urlencoding)
   $id = idfilter($id,false);
@@ -242,11 +223,18 @@ function html_btn($name,$id,$akey,$params,$method='get'){
     }
   }
 
+  if ($tooltip!='') {
+      $tip = htmlspecialchars($tooltip);
+  }else{
+      $tip = htmlspecialchars($label);
+  }
+
   $ret .= '<input type="submit" value="'.htmlspecialchars($label).'" class="button" ';
   if($akey){
-    $ret .= 'title="ALT+'.strtoupper($akey).'" ';
+    $tip .= ' [ALT+'.strtoupper($akey).']';
     $ret .= 'accesskey="'.$akey.'" ';
   }
+  $ret .= 'title="'.$tip.'" ';
   $ret .= '/>';
   $ret .= '</div></form>';
 
@@ -286,6 +274,36 @@ function html_show($txt=''){
   }
 }
 
+/**
+ * ask the user about how to handle an exisiting draft
+ *
+ * @author Andreas Gohr <andi@splitbrain.org>
+ */
+function html_draft(){
+  global $INFO;
+  global $ID;
+  global $lang;
+  global $conf;
+  $draft = unserialize(io_readFile($INFO['draft'],false));
+  $text  = cleanText(con($draft['prefix'],$draft['text'],$draft['suffix'],true));
+
+  echo p_locale_xhtml('draft');
+  ?>
+  <form id="dw__editform" method="post" action="<?php echo script()?>"
+   accept-charset="<?php echo $lang['encoding']?>"><div class="no">
+    <input type="hidden" name="id"   value="<?php echo $ID?>" />
+    <input type="hidden" name="date" value="<?php echo $draft['date']?>" /></div>
+    <textarea name="wikitext" id="wiki__text" readonly="readonly" cols="80" rows="10" class="edit"><?php echo "\n".formText($text)?></textarea>
+
+    <div id="draft__status"><?php echo $lang['draftdate'].' '.date($conf['dformat'],filemtime($INFO['draft']))?></div>
+
+    <input class="button" type="submit" name="do[recover]" value="<?php echo $lang['btn_recover']?>" tabindex="1" />
+    <input class="button" type="submit" name="do[draftdel]" value="<?php echo $lang['btn_draftdel']?>" tabindex="2" />
+    <input class="button" type="submit" name="do[show]" value="<?php echo $lang['btn_cancel']?>" tabindex="3" />
+  </form>
+  <?php
+}
+
 /**
  * Highlights searchqueries in HTML code
  *
@@ -331,21 +349,34 @@ function html_search(){
   print p_locale_xhtml('searchpage');
   flush();
 
+  //check if search is restricted to namespace
+  if(preg_match('/([^@]*)@([^@]*)/',$QUERY,$match)) {
+      $id = cleanID($match[1]);
+      if(empty($id)) {
+        print '<div class="nothing">'.$lang['nothingfound'].'</div>';
+        flush();
+        return;
+      }
+  } else {
+      $id = cleanID($QUERY);
+  }
+
   //show progressbar
   print '<div class="centeralign" id="dw__loading">';
-  print '<br /></div>';
   print '<script type="text/javascript" charset="utf-8">';
-  print 'showLoadBar("dw__loading");';
+  print 'showLoadBar();';
   print '</script>';
+  print "<br /></div>\n";
   flush();
 
   //do quick pagesearch
   $data = array();
-  $data = ft_pageLookup(cleanID($QUERY));
+
+  $data = ft_pageLookup($id);
   if(count($data)){
     sort($data);
     print '<div class="search_quickresult">';
-    print '<h3>'.$lang[quickhits].':</h3>';
+    print '<h3>'.$lang['quickhits'].':</h3>';
     print '<ul class="search_quickhits">';
     foreach($data as $id){
       print '<li> ';
@@ -396,7 +427,7 @@ function html_locked(){
   global $lang;
   global $INFO;
 
-  $locktime = filemtime(wikiFN($ID).'.lock');
+  $locktime = filemtime(wikiLockFN($ID));
   $expire = @date($conf['dformat'], $locktime + $conf['locktime'] );
   $min    = round(($conf['locktime'] - (time() - $locktime) )/60);
 
@@ -411,19 +442,34 @@ function html_locked(){
  * list old revisions
  *
  * @author Andreas Gohr <andi@splitbrain.org>
+ * @author Ben Coburn <btcoburn@silicodon.net>
  */
-function html_revisions(){
+function html_revisions($first=0){
   global $ID;
   global $INFO;
   global $conf;
   global $lang;
-  $revisions = getRevisions($ID);
+  /* we need to get one additionally log entry to be able to
+   * decide if this is the last page or is there another one.
+   * see html_recent()
+   */
+  $revisions = getRevisions($ID, $first, $conf['recent']+1);
+  if(count($revisions)==0 && $first!=0){
+    $first=0;
+    $revisions = getRevisions($ID, $first, $conf['recent']+1);;
+  }
+  $hasNext = false;
+  if (count($revisions)>$conf['recent']) {
+    $hasNext = true;
+    array_pop($revisions); // remove extra log entry
+  }
+
   $date = @date($conf['dformat'],$INFO['lastmod']);
 
   print p_locale_xhtml('revisions');
   print '<ul>';
-  if($INFO['exists']){
-    print ($INFO['minor']) ? '<li class="minor">' : '<li>';
+  if($INFO['exists'] && $first==0){
+    print (isset($INFO['meta']) && isset($INFO['meta']['last_change']) && $INFO['meta']['last_change']['type']==='e') ? '<li class="minor">' : '<li>';
     print '<div class="li">';
 
     print $date;
@@ -432,6 +478,7 @@ function html_revisions(){
 
     print '<a class="wikilink1" href="'.wl($ID).'">'.$ID.'</a> ';
 
+    print ' &ndash; ';
     print $INFO['sum'];
     print ' <span class="user">';
     print $INFO['editor'];
@@ -444,25 +491,31 @@ function html_revisions(){
 
   foreach($revisions as $rev){
     $date = date($conf['dformat'],$rev);
-    $info = getRevisionInfo($ID,$rev);
+    $info = getRevisionInfo($ID,$rev,true);
 
-    print ($info['minor']) ? '<li class="minor">' : '<li>';
+    print ($info['type']==='e') ? '<li class="minor">' : '<li>';
     print '<div class="li">';
     print $date;
 
-    print ' <a href="'.wl($ID,"rev=$rev,do=diff").'">';
-    $p = array();
-    $p['src']    = DOKU_BASE.'lib/images/diff.png';
-    $p['width']  = 15;
-    $p['height'] = 11;
-    $p['title']  = $lang['diff'];
-    $p['alt']    = $lang['diff'];
-    $att = buildAttributes($p);
-    print "<img $att />";
-    print '</a> ';
+    if(@file_exists(wikiFN($ID,$rev))){
+      print ' <a href="'.wl($ID,"rev=$rev,do=diff").'">';
+      $p = array();
+      $p['src']    = DOKU_BASE.'lib/images/diff.png';
+      $p['width']  = 15;
+      $p['height'] = 11;
+      $p['title']  = $lang['diff'];
+      $p['alt']    = $lang['diff'];
+      $att = buildAttributes($p);
+      print "<img $att />";
+      print '</a> ';
 
-    print '<a class="wikilink1" href="'.wl($ID,"rev=$rev").'">'.$ID.'</a> ';
+      print '<a class="wikilink1" href="'.wl($ID,"rev=$rev").'">'.$ID.'</a>';
+    }else{
+      print ' <img src="'.DOKU_BASE.'lib/images/blank.gif" width="15" height="11" alt="" /> ';
+      print $ID;
+    }
 
+    print ' &ndash; ';
     print htmlspecialchars($info['sum']);
     print ' <span class="user">';
     if($info['user']){
@@ -476,6 +529,23 @@ function html_revisions(){
     print '</li>';
   }
   print '</ul>';
+
+  print '<div class="pagenav">';
+  $last = $first + $conf['recent'];
+  if ($first > 0) {
+    $first -= $conf['recent'];
+    if ($first < 0) $first = 0;
+    print '<div class="pagenav-prev">';
+    print html_btn('newer',$ID,"p",array('do' => 'revisions', 'first' => $first));
+    print '</div>';
+  }
+  if ($hasNext) {
+    print '<div class="pagenav-next">';
+    print html_btn('older',$ID,"n",array('do' => 'revisions', 'first' => $last));
+    print '</div>';
+  }
+  print '</div>';
+
 }
 
 /**
@@ -483,6 +553,7 @@ function html_revisions(){
  *
  * @author Andreas Gohr <andi@splitbrain.org>
  * @author Matthias Grimm <matthiasgrimm@users.sourceforge.net>
+ * @author Ben Coburn <btcoburn@silicodon.net>
  */
 function html_recent($first=0){
   global $conf;
@@ -495,16 +566,20 @@ function html_recent($first=0){
   $recents = getRecents($first,$conf['recent'] + 1,getNS($ID));
   if(count($recents) == 0 && $first != 0){
     $first=0;
-    $recents = getRecents(0,$conf['recent'] + 1,getNS($ID));
+    $recents = getRecents($first,$conf['recent'] + 1,getNS($ID));
+  }
+  $hasNext = false;
+  if (count($recents)>$conf['recent']) {
+    $hasNext = true;
+    array_pop($recents); // remove extra log entry
   }
-  $cnt = count($recents) <= $conf['recent'] ? count($recents) : $conf['recent'];
 
   print p_locale_xhtml('recent');
   print '<ul>';
 
   foreach($recents as $recent){
     $date = date($conf['dformat'],$recent['date']);
-    print ($recent['minor']) ? '<li class="minor">' : '<li>';
+    print ($recent['type']==='e') ? '<li class="minor">' : '<li>';
     print '<div class="li">';
 
     print $date.' ';
@@ -532,7 +607,7 @@ function html_recent($first=0){
     print '</a> ';
 
     print html_wikilink(':'.$recent['id'],$conf['useheading']?NULL:$recent['id']);
-    print ' '.htmlspecialchars($recent['sum']);
+    print ' &ndash; '.htmlspecialchars($recent['sum']);
 
     print ' <span class="user">';
     if($recent['user']){
@@ -556,7 +631,7 @@ function html_recent($first=0){
     print html_btn('newer','',"p",array('do' => 'recent', 'first' => $first));
     print '</div>';
   }
-  if ($conf['recent'] < count($recents)) {
+  if ($hasNext) {
     print '<div class="pagenav-next">';
     print html_btn('older','',"n",array('do' => 'recent', 'first' => $last));
     print '</div>';
@@ -597,6 +672,7 @@ function html_index($ns){
  * @author Andreas Gohr <andi@splitbrain.org>
  */
 function html_list_index($item){
+  global $ID;
   $ret = '';
   $base = ':'.$item['id'];
   $base = substr($base,strrpos($base,':')+1);
@@ -738,9 +814,10 @@ function html_diff($text='',$intro=true){
   global $REV;
   global $lang;
   global $conf;
+
   if($text){
-    $df  = new Diff(split("\n",htmlspecialchars(rawWiki($ID,''))),
-                    split("\n",htmlspecialchars(cleanText($text))));
+    $df  = new Diff(explode("\n",htmlspecialchars(rawWiki($ID,''))),
+                    explode("\n",htmlspecialchars(cleanText($text))));
     $left  = '<a class="wikilink1" href="'.wl($ID).'">'.
               $ID.' '.date($conf['dformat'],@filemtime(wikiFN($ID))).'</a>'.
               $lang['current'];
@@ -750,14 +827,21 @@ function html_diff($text='',$intro=true){
       $r = $REV;
     }else{
       //use last revision if none given
-      $revs = getRevisions($ID);
+      $revs = getRevisions($ID, 0, 1);
       $r = $revs[0];
     }
 
-    $df  = new Diff(split("\n",htmlspecialchars(rawWiki($ID,$r))),
-                    split("\n",htmlspecialchars(rawWiki($ID,''))));
-    $left  = '<a class="wikilink1" href="'.wl($ID,"rev=$r").'">'.
-              $ID.' '.date($conf['dformat'],$r).'</a>';
+    if($r){
+      $df  = new Diff(explode("\n",htmlspecialchars(rawWiki($ID,$r))),
+                      explode("\n",htmlspecialchars(rawWiki($ID,''))));
+      $left  = '<a class="wikilink1" href="'.wl($ID,"rev=$r").'">'.
+                $ID.' '.date($conf['dformat'],$r).'</a>';
+    }else{
+      $df  = new Diff(array(''),
+                      explode("\n",htmlspecialchars(rawWiki($ID,''))));
+      $left  = '<a class="wikilink1" href="'.wl($ID).'">'.
+                $ID.'</a>';
+    }
     $right = '<a class="wikilink1" href="'.wl($ID).'">'.
               $ID.' '.date($conf['dformat'],@filemtime(wikiFN($ID))).'</a> '.
               $lang['current'];
@@ -796,8 +880,8 @@ function html_conflict($text,$summary){
     <input type="hidden" name="wikitext" value="<?php echo formText($text)?>" />
     <input type="hidden" name="summary" value="<?php echo formText($summary)?>" />
 
-    <input class="button" type="submit" name="do" value="<?php echo $lang['btn_save']?>" accesskey="s" title="[ALT+S]" />
-    <input class="button" type="submit" name="do" value="<?php echo $lang['btn_cancel']?>" />
+    <input class="button" type="submit" name="do[save]" value="<?php echo $lang['btn_save']?>" accesskey="s" title="<?php echo $lang['btn_save']?> [ALT+S]" />
+    <input class="button" type="submit" name="do[cancel]" value="<?php echo $lang['btn_cancel']?>" />
   </div>
   </form>
   <br /><br /><br /><br />
@@ -943,8 +1027,9 @@ function html_updateprofile(){
 /**
  * This displays the edit form (lots of logic included)
  *
- * @fixme  this is a huge lump of code and should be modularized
- * @author Andreas Gohr <andi@splitbrain.org>
+ * @fixme    this is a huge lump of code and should be modularized
+ * @triggers HTML_PAGE_FROMTEMPLATE
+ * @author   Andreas Gohr <andi@splitbrain.org>
  */
 function html_edit($text=null,$include='edit'){ //FIXME: include needed?
   global $ID;
@@ -978,7 +1063,8 @@ function html_edit($text=null,$include='edit'){ //FIXME: include needed?
       }
     }else{
       //try to load a pagetemplate
-      $text = pageTemplate($ID);
+      $data = array($ID);
+      $text = trigger_event('HTML_PAGE_FROMTEMPLATE',$data,'pageTemplate',true);
     }
   }else{
     $pr = true; //preview mode
@@ -988,7 +1074,13 @@ function html_edit($text=null,$include='edit'){ //FIXME: include needed?
   if($wr){
     if ($REV) print p_locale_xhtml('editrev');
     print p_locale_xhtml($include);
+    $ro=false;
   }else{
+    // check pseudo action 'source'
+    if(!actionOK('source')){
+      msg('Command disabled: source',-1);
+      return;
+    }
     print p_locale_xhtml('read');
     $ro='readonly="readonly"';
   }
@@ -997,25 +1089,31 @@ function html_edit($text=null,$include='edit'){ //FIXME: include needed?
 
 ?>
   <div style="width:99%;">
-  <form id="dw__editform" method="post" action="<?php echo script()?>" accept-charset="<?php echo $lang['encoding']?>"><div class="no">
-     <div class="toolbar">
-        <div id="tool__bar"></div>
-        <input type="hidden" name="id"   value="<?php echo $ID?>" />
-        <input type="hidden" name="rev"  value="<?php echo $REV?>" />
-        <input type="hidden" name="date" value="<?php echo $DATE?>" />
-        <input type="hidden" name="prefix" value="<?php echo formText($PRE)?>" />
-        <input type="hidden" name="suffix" value="<?php echo formText($SUF)?>" />
 
-        <?php if($wr){?>
-        <script type="text/javascript" charset="utf-8">
-          <?php /* sets changed to true when previewed */?>
-          textChanged = <?php ($pr) ? print 'true' : print 'false' ?>;
-        </script>
-        <span id="spell__action"></span>
-        <?php } ?>
-        <div id="spell__suggest"></div>
+   <div class="toolbar">
+      <div id="draft__status"><?php if(!empty($INFO['draft'])) echo $lang['draftdate'].' '.date($conf['dformat']);?></div>
+      <div id="tool__bar"><?php if(!$ro){?><a href="<?php echo DOKU_BASE?>lib/exe/mediamanager.php?ns=<?php echo $INFO['namespace']?>"
+      target="_blank"><?php echo $lang['mediaselect'] ?></a><?php }?></div>
+
+      <?php if($wr){?>
+      <script type="text/javascript" charset="utf-8">
+        <?php /* sets changed to true when previewed */?>
+        textChanged = <?php ($pr) ? print 'true' : print 'false' ?>;
+      </script>
+      <span id="spell__action"></span>
+      <div id="spell__suggest"></div>
+      <?php } ?>
+   </div>
+   <div id="spell__result"></div>
+
+
+   <form id="dw__editform" method="post" action="<?php echo script()?>" accept-charset="<?php echo $lang['encoding']?>"><div class="no">
+      <input type="hidden" name="id"   value="<?php echo $ID?>" />
+      <input type="hidden" name="rev"  value="<?php echo $REV?>" />
+      <input type="hidden" name="date" value="<?php echo $DATE?>" />
+      <input type="hidden" name="prefix" value="<?php echo formText($PRE)?>" />
+      <input type="hidden" name="suffix" value="<?php echo formText($SUF)?>" />
     </div>
-    <div id="spell__result"></div>
 
     <textarea name="wikitext" id="wiki__text" <?php echo $ro?> cols="80" rows="10" class="edit" tabindex="1"><?php echo "\n".formText($text)?></textarea>
 
@@ -1023,9 +1121,9 @@ function html_edit($text=null,$include='edit'){ //FIXME: include needed?
       <div id="size__ctl"></div>
       <?php if($wr){?>
          <div class="editButtons">
-            <input class="button" id="edbtn__save" type="submit" name="do" value="<?php echo $lang['btn_save']?>" accesskey="s" title="[ALT+S]" tabindex="4" />
-            <input class="button" id="edbtn__preview" type="submit" name="do" value="<?php echo $lang['btn_preview']?>" accesskey="p" title="[ALT+P]" tabindex="5" />
-            <input class="button" type="submit" name="do" value="<?php echo $lang['btn_cancel']?>" tabindex="5" />
+            <input class="button" id="edbtn__save" type="submit" name="do[save]" value="<?php echo $lang['btn_save']?>" accesskey="s" title="<?php echo $lang['btn_save']?> [ALT+S]" tabindex="4" />
+            <input class="button" id="edbtn__preview" type="submit" name="do[preview]" value="<?php echo $lang['btn_preview']?>" accesskey="p" title="<?php echo $lang['btn_preview']?> [ALT+P]" tabindex="5" />
+            <input class="button" type="submit" name="do[draftdel]" value="<?php echo $lang['btn_cancel']?>" tabindex="6" />
          </div>
       <?php } ?>
       <?php if($wr){ ?>
@@ -1036,7 +1134,7 @@ function html_edit($text=null,$include='edit'){ //FIXME: include needed?
         </div>
       <?php }?>
     </div>
-  </div></form>
+  </form>
   </div>
 <?php
 }
@@ -1060,7 +1158,7 @@ function html_minoredit(){
   $p['id']       = 'minoredit';
   $p['tabindex'] = 3;
   $p['value']    = '1';
-  if($_REQUEST['minor']) $p['checked']='checked';
+  if(!empty($_REQUEST['minor'])) $p['checked']='checked';
   $att = buildAttributes($p);
 
   print '<span class="nowrap">';
@@ -1080,11 +1178,17 @@ function html_debug(){
   global $conf;
   global $lang;
   global $auth;
+  global $INFO;
+
   //remove sensitive data
   $cnf = $conf;
   $cnf['auth']='***';
   $cnf['notify']='***';
   $cnf['ftp']='***';
+  $nfo = $INFO;
+  $nfo['userinfo'] = '***';
+  $ses = $_SESSION;
+  $ses[$conf['title']]['auth'] = '***';
 
   print '<html><body>';
 
@@ -1092,6 +1196,10 @@ function html_debug(){
   print 'output as a mail to andi@splitbrain.org ';
   print 'The best way to do this is to save this page in your browser</p>';
 
+  print '<b>$INFO:</b><pre>';
+  print_r($nfo);
+  print '</pre>';
+
   print '<b>$_SERVER:</b><pre>';
   print_r($_SERVER);
   print '</pre>';
@@ -1131,7 +1239,7 @@ function html_debug(){
   }
 
   print '<b>$_SESSION:</b><pre>';
-  print_r($_SESSION);
+  print_r($ses);
   print '</pre>';
 
   print '<b>Environment:</b><pre>';
@@ -1164,7 +1272,7 @@ function html_admin(){
                    );
   }
 
-  usort($menu, p_sort_modes);
+  usort($menu, 'p_sort_modes');
 
   // output the menu
   ptln('<ul>');
@@ -1174,11 +1282,6 @@ function html_admin(){
     ptln('  <li><div class="li"><a href="'.wl($ID, 'do=admin&amp;page='.$item['plugin']).'">'.$item['prompt'].'</a></div></li>');
   }
 
-  // add in non-plugin functions
-  if (!$conf['openregister']){
-    ptln('<li><div class="li"><a href="'.wl($ID,'do=register').'">'.$lang['admin_register'].'</a></div></li>');
-  }
-
   ptln('</ul>');
 }
 
