@@ -48,6 +48,21 @@ function idx_getPageWords($page){
     $tokens = explode(' ', $body);
     $tokens = array_count_values($tokens);   // count the frequency of each token
 
+// ensure the deaccented or romanised page names of internal links are added to the token array
+// (this is necessary for the backlink function -- there maybe a better way!)
+    if ($conf['deaccent']) {
+      $links = p_get_metadata($page,'relation references');
+
+      $tmp = join(' ',array_keys($links));                // make a single string
+      $tmp = strtr($tmp, ':', ' ');                       // replace namespace separator with a space
+      $link_tokens = array_unique(explode(' ', $tmp));    // break into tokens
+
+      foreach ($link_tokens as $link_token) {
+        if (isset($tokens[$link_token])) continue;
+        $tokens[$link_token] = 1;
+      }
+    }
+
     $words = array();
     foreach ($tokens as $word => $count) {
         // simple filter to restrict use of utf8_stripspecials
@@ -164,14 +179,8 @@ function idx_addPage($page){
     // close the temp file and move it over to be the new one
     fclose($tmp);
     // try rename first (fast) fallback to copy (slow)
-    if(@rename($conf['cachedir'].'/index.tmp',
-              $conf['cachedir'].'/index.idx')){
-        return true;
-    }elseif(copy($conf['cachedir'].'/index.tmp',
-            $conf['cachedir'].'/index.idx')){
-        unlink($conf['cachedir'].'/index.tmp');
-        return true;
-    }
+    io_rename($conf['cachedir'].'/index.tmp',
+              $conf['cachedir'].'/index.idx');
     return false;
 }
 
@@ -239,6 +248,8 @@ function idx_lookup($words){
         if(substr($xword,0,1) == '*'){
             $xword = substr($xword,1);
             $wild  = 1;
+            $ptn = '/'.preg_quote($xword,'/').'$/';
+#            $l = -1*strlen($xword)-1;
         }
         if(substr($xword,-1,1) == '*'){
             $xword = substr($xword,0,-1);
@@ -251,8 +262,11 @@ function idx_lookup($words){
             for($wid=0; $wid<$cnt; $wid++){
                 $iword = $word_idx[$wid];
                 if( (($wild==3) && is_int(strpos($iword,$xword))) ||
-                    (($wild==1) && ("$xword\n" == substr($iword,(-1*strlen($xword))-1))) ||
-                    (($wild==2) && ($xword == substr($iword,0,strlen($xword))))
+#                    (($wild==1) && ("$xword\n" == substr($iword,$l))) ||
+                    (($wild==1) && preg_match($ptn,$iword)) ||
+#                    (($wild==2) && ($xword == substr($iword,0,strlen($xword))))
+                    (($wild==2) && (0 === strpos($iword,$xword)))
+
                   ){
                     $wids[] = $wid;
                     $result[$word][] = $wid;
@@ -343,7 +357,7 @@ function idx_parseIndexLine(&$page_idx,$line){
         $doc = trim($page_idx[$doc]);
         if(!$doc) continue;
         // make sure the document still exists
-        if(!@file_exists(wikiFN($doc))) continue;
+        if(!@file_exists(wikiFN($doc,'',false))) continue;
 
         $result[$doc] = $cnt;
     }
@@ -363,14 +377,14 @@ function idx_parseIndexLine(&$page_idx,$line){
  */
 function idx_tokenizer($string,&$stopwords,$wc=false){
     $words = array();
-    if(!$wc) $wc = '\*';
+    $wc = ($wc) ? '' : $wc = '\*';
 
     if(preg_match('/[^0-9A-Za-z]/u', $string)){
         // handle asian chars as single words (may fail on older PHP version)
         $asia = @preg_replace('/('.IDX_ASIAN.')/u','\1 ',$string);
         if(!is_null($asia)) $string = $asia; //recover from regexp failure
 
-        $arr = explode(' ', utf8_stripspecials($string,' ','._\-:'.$wc));
+        $arr = explode(' ', utf8_stripspecials($string,' ','\._\-:'.$wc));
         foreach ($arr as $w) {
             if (!is_numeric($w) && strlen($w) < 3) continue;
             $w = utf8_strtolower($w);
