@@ -3,23 +3,42 @@
  * Initialize some defaults needed for DokuWiki
  */
 
+  // start timing Dokuwiki execution
+  function delta_time($start=0) {
+    list($usec, $sec) = explode(" ", microtime());
+    return ((float)$usec+(float)$sec)-((float)$start);
+  }
+  define('DOKU_START_TIME', delta_time());
+
   // define the include path
   if(!defined('DOKU_INC')) define('DOKU_INC',realpath(dirname(__FILE__).'/../').'/');
 
   // define config path (packagers may want to change this to /etc/dokuwiki/)
   if(!defined('DOKU_CONF')) define('DOKU_CONF',DOKU_INC.'conf/');
 
-  // set up error reporting to sane values
-  error_reporting(E_ALL ^ E_NOTICE);
+  // check for error reporting override or set error reporting to sane values
+  if (!defined('DOKU_E_LEVEL') && @file_exists(DOKU_CONF.'report_e_all')) {
+    define('DOKU_E_LEVEL', E_ALL);
+  }
+  if (!defined('DOKU_E_LEVEL')) { error_reporting(E_ALL ^ E_NOTICE); }
+  else { error_reporting(DOKU_E_LEVEL); }
+
+  // init memory caches
+  global $cache_revinfo;  $cache_revinfo = array();
+  global $cache_wikifn;   $cache_wikifn = array();
+  global $cache_cleanid;  $cache_cleanid = array();
+  global $cache_authname; $cache_authname = array();
 
   //prepare config array()
   global $conf;
-  $conf = array();
+  if (!defined('DOKU_UNITTEST')) {
+    $conf = array();
 
-  // load the config file(s)
-  require_once(DOKU_CONF.'dokuwiki.php');
-  if(@file_exists(DOKU_CONF.'local.php')){
-    require_once(DOKU_CONF.'local.php');
+    // load the config file(s)
+    require_once(DOKU_CONF.'dokuwiki.php');
+    if(@file_exists(DOKU_CONF.'local.php')){
+      require_once(DOKU_CONF.'local.php');
+    }
   }
 
   //prepare language array
@@ -36,6 +55,9 @@
   if(!defined('DOKU_BASE')) define('DOKU_BASE',getBaseURL());
   if(!defined('DOKU_URL'))  define('DOKU_URL',getBaseURL(true));
 
+  // define cookie and session id
+  if (!defined('DOKU_COOKIE')) define('DOKU_COOKIE', 'DW'.md5(DOKU_URL));
+
   // define Plugin dir
   if(!defined('DOKU_PLUGIN'))  define('DOKU_PLUGIN',DOKU_INC.'lib/plugins/');
 
@@ -53,6 +75,14 @@
   // make session rewrites XHTML compliant
   @ini_set('arg_separator.output', '&amp;');
 
+  // enable gzip compression
+  if ($conf['gzip_output'] &&
+      !defined('DOKU_DISABLE_GZIP_OUTPUT') &&
+      function_exists('ob_gzhandler') &&
+      preg_match('/gzip|deflate/', $_SERVER['HTTP_ACCEPT_ENCODING'])) {
+    ob_start('ob_gzhandler');
+  }
+
   // init session
   if (!headers_sent() && !defined('NOSESSION')){
     session_name("DokuWiki");
@@ -73,8 +103,11 @@
   @ini_set('magic_quotes_sybase',0);
 
   // disable gzip if not available
-  if($conf['usegzip'] && !function_exists('gzopen')){
-    $conf['usegzip'] = 0;
+  if($conf['compression'] == 'bz' && !function_exists('bzopen')){
+    $conf['compression'] = 'gz';
+  }
+  if($conf['compression'] == 'gz' && !function_exists('gzopen')){
+    $conf['compression'] = 0;
   }
 
   // precalculate file creation modes
@@ -100,15 +133,22 @@ function init_paths(){
                  'mediadir'  => 'media',
                  'metadir'   => 'meta',
                  'cachedir'  => 'cache',
-                 'lockdir'   => 'locks',
-                 'changelog' => 'changes.log');
+                 'lockdir'   => 'locks');
 
   foreach($paths as $c => $p){
-    if(!$conf[$c])   $conf[$c] = $conf['savedir'].'/'.$p;
-    $conf[$c]        = init_path($conf[$c]);
-    if(!$conf[$c])   nice_die("The $c does not exist, isn't accessable or writable.
-                               Check your config and permission settings!");
+    if(empty($conf[$c]))  $conf[$c] = $conf['savedir'].'/'.$p;
+    $conf[$c]             = init_path($conf[$c]);
+    if(empty($conf[$c]))  nice_die("The $c does not exist, isn't accessable or writable.
+                               You should check your config and permission settings.
+                               Or maybe you want to <a href=\"install.php\">run the
+                               installer</a>?");
   }
+
+  // path to old changelog only needed for upgrading
+  $conf['changelog_old'] = init_path((isset($conf['changelog']))?($conf['changelog']):($conf['savedir'].'/changes.log'));
+  if ($conf['changelog_old']=='') { unset($conf['changelog_old']); }
+  // hardcoded changelog because it is now a cache that lives in meta
+  $conf['changelog'] = $conf['metadir'].'/_dokuwiki.changes';
 }
 
 /**
@@ -242,6 +282,9 @@ function getBaseURL($abs=false){
   //handle script in lib/exe dir
   $dir = preg_replace('!lib/exe/$!','',$dir);
 
+  //handle script in lib/plugins dir
+  $dir = preg_replace('!lib/plugins/.*$!','',$dir);
+
   //finish here for relative URLs
   if(!$abs) return $dir;
 
@@ -306,7 +349,7 @@ function scriptify($file) {
   }
   fclose($fh);
   //try to rename the old file
-  @rename($file,"$file.old");
+  io_rename($file,"$file.old");
 }
 
 /**
