@@ -120,22 +120,7 @@ $lang['qb_media']   = 'Afegeix imatges o altres fitxers';
 $lang['qb_sig']     = 'Insereix signatura';
 
 $lang['del_confirm']= 'Suprimiu aquesta entrada?';
-
-$lang['admin_acl']  = 'Gestió de la Llista de Control d\'Accés...';
-$lang['admin_register']= 'Afegeix nou usuari...';
-
-$lang['acl_group']  = 'Grup';
-$lang['acl_user']   = 'Usuari';
-$lang['acl_perms']  = 'Permisos per a';
-$lang['page']       = 'Pàgina';
-$lang['namespace']  = 'Espai';
-
-$lang['acl_perm1']  = 'Llegir';
-$lang['acl_perm2']  = 'Editar';
-$lang['acl_perm4']  = 'Crear';
-$lang['acl_perm8']  = 'Penjar fitxers';
-$lang['acl_perm16'] = 'Suprimir';
-$lang['acl_new']    = 'Afegeix nova entrada';
+$lang['admin_register']= 'Afegeix nou usuari';
 
 $lang['spell_start'] = 'Revisa l\'ortografia';
 $lang['spell_stop']  = 'Torna a edició';
