@@ -39,6 +39,9 @@ $lang['btn_unsubscribe'] = 'Fjern abonnement på ændringer';
 $lang['btn_profile']    = 'Opdater profil';
 $lang['btn_reset']     = 'Nulstil';
 $lang['btn_resendpwd'] = 'Send nyt password';
+$lang['btn_draft']    = 'Rediger kladde';
+$lang['btn_recover']  = 'Gendan kladde';
+$lang['btn_draftdel'] = 'Slet kladde';
 
 $lang['loggedinas'] = 'Logget på som';
 $lang['user']       = 'Brugernavn';
@@ -53,6 +56,7 @@ $lang['register']   = 'Tilmeld';
 $lang['profile']    = 'Brugerprofil';
 $lang['badlogin']   = 'Forkert brugernavn eller password.';
 $lang['minoredit']  = 'Mindre ændringer';
+$lang['draftdate']  = 'Kladde automatisk gemt d.';
 
 $lang['regmissing'] = 'Du skal udfylde alle felter.';
 $lang['reguexists'] = 'Dette brugernavn er allerede i brug.';
@@ -69,11 +73,13 @@ $lang['profnochange'] = 'Ingen ændringer, intet modificeret.';
 $lang['profnoempty']  = 'Tomt navn eller e-mail adresse er ikke tilladt.';
 $lang['profchanged']  = 'Brugerprofil opdateret korrekt.';
 
-$lang['pwdforget'] = 'Glemt dit password? F√• et nyt';
-$lang['resendna']  = 'Denne wiki underst√∏tter ikke udsendelse af nyt password.';
+$lang['pwdforget'] = 'Glemt dit password? Få et nyt';
+$lang['resendna']  = 'Denne wiki understøtter ikke udsendelse af nyt password.';
 $lang['resendpwd'] = 'Send nyt password for';
 $lang['resendpwdmissing'] = 'Du skal udfylde alle felter.';
 $lang['resendpwdnouser']  = 'Vi kan ikke finde denne bruger i vores database.';
+$lang['resendpwdbadauth'] = 'Beklager, denne autoriseringskode er ikke gyldig. Kontroller venligst at du benyttede det fulde link til bekræftelse.';
+$lang['resendpwdconfirm'] = 'Et link med bekræftelse er blevet sendt med email.';
 $lang['resendpwdsuccess'] = 'Dit nye password er blevet sendt med e-mail.';
 
 $lang['txt_upload']   = 'Vælg den fil der skal uploades';
@@ -99,6 +105,14 @@ $lang['mediainuse']  = 'Filen "%s" er ikke slettet - den er stadig i brug.';
 $lang['namespaces']  = 'Navnerum';
 $lang['mediafiles']  = 'Tilgængelige filer i';
 
+$lang['js']['keepopen']    = 'Hold vindue åbent ved valg';
+$lang['js']['hidedetails'] = 'Skjul detaljer';
+$lang['mediausage']  = 'Brug den følgende syntaks til at henvise til denne fil:';
+$lang['mediaview']   = 'Vis oprindelig fil';
+$lang['mediaroot']   = 'rod';
+$lang['mediaupload'] = 'Upload en fil til det nuværende navnerum her. For at oprette under-navnerum, tilføj dem til "Upload som" filnavnet, adskilt af kolontegn.';
+$lang['mediaextchange'] = 'Filudvidelse ændret fra .%s til .%s!';
+
 $lang['reference']   = 'Henvisning til';
 $lang['ref_inuse']   = 'Filen kan ikke slettes, da den stadig er i brug på følgende sider:';
 $lang['ref_hidden']  = 'Nogle henvisninger er i dokumenter du ikke har læserettigheder til';
@@ -121,6 +135,7 @@ $lang['summary']    = 'Redigerings resume';
 
 $lang['mail_newpage'] = 'dokument tilføjet:';
 $lang['mail_changed'] = 'dokument ændret:';
+$lang['mail_new_user'] = 'Ny bruger';
 
 $lang['nosmblinks'] = 'Henvisninger til Windows shares virker kun i Microsoft Internet Explorer.\nDu kan stadig kopiere og indsætte linket.';
 
@@ -176,8 +191,35 @@ $lang['subscribe_noaddress']= 'Ingen adresse knyttet til dit login, du kan ikke
 $lang['unsubscribe_success']= 'Fjernet %s fra abonnentliste for %s';
 $lang['unsubscribe_error']  = 'Fejl ved fjernelse af %s fra abonnentliste for %s';
 
-+/* auth.class language support */
-+$lang['authmodfailed']   = 'Fejl i brugervalideringens konfiguration. Kontakt venligst wikiens administrator.';
-+$lang['authtempfail']    = 'Brugervalidering er midlertidigt ude af drift. Hvis dette er vedvarende, kontakt venligst wikiens administrator.';
+/* auth.class language support */
+$lang['authmodfailed']   = 'Fejl i brugervalideringens konfiguration. Kontakt venligst wikiens administrator.';
+$lang['authtempfail']    = 'Brugervalidering er midlertidigt ude af drift. Hvis dette er vedvarende, kontakt venligst wikiens administrator.';
+
+/* installer strings */
+$lang['i_chooselang'] = 'Vælg dit sprog';
+$lang['i_installer']  = 'DokuWiki Installer';
+$lang['i_wikiname']   = 'Wiki Navn';
+$lang['i_enableacl']  = 'Brug ACL (foreslået)';
+$lang['i_superuser']  = 'Superbruger';
+$lang['i_problems']   = 'Installeren fandt nogle problemer, vist nedenunder. Du kan ikke fortsætte før du har rettet dem.';
+$lang['i_modified']   = 'Af sikkerheds hensyn vil dette script kun virke på en ny og umodificeret Dokuwiki installation.
+                         Du burde enten gen-udpakke filerne fra den downloaded pakke eller tjekke den fuldstændige
+                         <a href="http://wiki.splitbrain.org/wiki:install">DokuWiki installations instruktioner</a>';
+$lang['i_funcna']     = 'PHP funtionen <code>%s</code> er ikke tilgængelig. Måske har din udbyder slået det fra af en eller anden grund?';
+$lang['i_phpver']     = 'Din PHP version <code>%s</code> er mindre en den nødvendige <code>%s</code>. Du er nÃ¸d til at opgradere din PHP installation.';
+$lang['i_permfail']   = 'DokuWiki kan ikke skrive til <code>%s</code>. Du er nød til at rette tilladelses indstillingerne for denne mappe!';
+$lang['i_confexists'] = '<code>%s</code> eksisterer allerede';
+$lang['i_writeerr']   = 'Kunne ikke oprette <code>%s</code>. Du bliver nød til at tjekke mappe/fil- tilladelserne og oprette filen manuelt.';
+$lang['i_badhash']    = 'uigenkendelig eller modificeret dokuwiki.php (hash=<code>%s</code>)';
+$lang['i_badval']     = '<code>%s</code> - ulovlig eller tom vÃ¦rdi';
+$lang['i_success']    = 'Konfigurationen fulførtedes med success.  Du kan nu slette install.php filen. Forsæt til
+                        <a href="doku.php">din nye DokuWiki</a>.';
+$lang['i_failure']    = 'Nogle fejl forekom mens konfigurations filerne skulle skrives. Du er mulighvis nød til at fixe dem manuelt før
+                         du kan bruge <a href="doku.php">din nye DokuWiki</a>.';
+$lang['i_policy']     = 'Begyndende ACL politik';
+$lang['i_pol0']       = 'Åben Wiki (alle kan læse, skrive og uploade)';
+$lang['i_pol1']       = 'Offentlig Wiki (alle kan læse, kun registrerede brugere kan skrive og uploade)';
+$lang['i_pol2']       = 'Lukket Wiki (kun for registerede brugere kan læse, skrive og uploade)';
+$lang['i_retry']      = 'Forsøg igen';
 
 //Setup VIM: ex: et ts=2 enc=utf-8 :
