@@ -36,9 +36,12 @@ $lang['btn_backlink']    = "Backlinks";
 $lang['btn_backtomedia'] = 'Back to Mediafile Selection';
 $lang['btn_subscribe']   = 'Subscribe Changes';
 $lang['btn_unsubscribe'] = 'Unsubscribe Changes';
-$lang['btn_profile']    = 'Update Profile';
-$lang['btn_reset']     = 'Reset';
-$lang['btn_resendpwd'] = 'Send new password';
+$lang['btn_profile']     = 'Update Profile';
+$lang['btn_reset']       = 'Reset';
+$lang['btn_resendpwd']   = 'Send new password';
+$lang['btn_draft']    = 'Edit draft';
+$lang['btn_recover']  = 'Recover draft';
+$lang['btn_draftdel'] = 'Delete draft';
 
 $lang['loggedinas'] = 'Logged in as';
 $lang['user']       = 'Username';
@@ -53,6 +56,7 @@ $lang['register']   = 'Register';
 $lang['profile']    = 'User Profile';
 $lang['badlogin']   = 'Sorry, username or password was wrong.';
 $lang['minoredit']  = 'Minor Changes';
+$lang['draftdate']  = 'Draft autosaved on'; // full dformat date will be added
 
 $lang['regmissing'] = 'Sorry, you must fill in all fields.';
 $lang['reguexists'] = 'Sorry, a user with this login already exists.';
@@ -60,7 +64,7 @@ $lang['regsuccess'] = 'The user has been created and the password was sent by em
 $lang['regsuccess2']= 'The user has been created.';
 $lang['regmailfail']= 'Looks like there was an error on sending the password mail. Please contact the admin!';
 $lang['regbadmail'] = 'The given email address looks invalid - if you think this is an error, contact the admin';
-$lang['regbadpass'] = 'The two given passwords are not identically, please try again.';
+$lang['regbadpass'] = 'The two given passwords are not identical, please try again.';
 $lang['regpwmail']  = 'Your DokuWiki password';
 $lang['reghere']    = 'You don\'t have an account yet? Just get one';
 
@@ -74,6 +78,8 @@ $lang['resendna']  = 'This wiki does not support password resending.';
 $lang['resendpwd'] = 'Send new password for';
 $lang['resendpwdmissing'] = 'Sorry, you must fill in all fields.';
 $lang['resendpwdnouser']  = 'Sorry, we can\'t find this user in our database.';
+$lang['resendpwdbadauth'] = 'Sorry, this auth code is not valid. Make sure you used the complete confirmation link.';
+$lang['resendpwdconfirm'] = 'A confirmation link has been sent by email.';
 $lang['resendpwdsuccess'] = 'Your new password has been sent by email.';
 
 $lang['txt_upload']   = 'Select file to upload';
@@ -87,8 +93,8 @@ $lang['notsavedyet'] = 'Unsaved changes will be lost.\nReally continue?';
 $lang['rssfailed']   = 'An error occured while fetching this feed: ';
 $lang['nothingfound']= 'Nothing was found.';
 
-$lang['mediaselect'] = 'Mediafile Selection';
-$lang['fileupload']  = 'Mediafile Upload';
+$lang['mediaselect'] = 'Media Files';
+$lang['fileupload']  = 'Media File Upload';
 $lang['uploadsucc']  = 'Upload successful';
 $lang['uploadfail']  = 'Upload failed. Maybe wrong permissions?';
 $lang['uploadwrong'] = 'Upload denied. This file extension is forbidden!';
@@ -99,6 +105,14 @@ $lang['mediainuse']  = 'The file "%s" hasn\'t been deleted - it is still in use.
 $lang['namespaces']  = 'Namespaces';
 $lang['mediafiles']  = 'Available files in';
 
+$lang['js']['keepopen']    = 'Keep window open on selection';
+$lang['js']['hidedetails'] = 'Hide Details';
+$lang['mediausage']  = 'Use the following syntax to reference this file:';
+$lang['mediaview']   = 'View original file';
+$lang['mediaroot']   = 'root';
+$lang['mediaupload'] = 'Upload a file to the current namespace here. To create subnamespaces, prepend them to your "Upload as" filename separated by colons.';
+$lang['mediaextchange'] = 'Filextension changed from .%s to .%s!';
+
 $lang['reference']   = 'References for';
 $lang['ref_inuse']   = 'The file can\'t be deleted, because it\'s still used by the following pages:';
 $lang['ref_hidden']  = 'Some references  are on pages you don\'t have permission to read';
@@ -121,6 +135,7 @@ $lang['summary']    = 'Edit summary';
 
 $lang['mail_newpage'] = 'page added:';
 $lang['mail_changed'] = 'page changed:';
+$lang['mail_new_user'] = 'New user:';
 
 $lang['nosmblinks'] = 'Linking to Windows shares only works in Microsoft Internet Explorer.\nYou still can copy and paste the link.';
 
@@ -180,4 +195,32 @@ $lang['unsubscribe_error']  = 'Error removing %s from subscription list for %s';
 $lang['authmodfailed']   = 'Bad user authentication configuration. Please inform your Wiki Admin.';
 $lang['authtempfail']    = 'User authentication is temporarily unavailable. If this situation persists, please inform your Wiki Admin.';
 
+/* installer strings */
+$lang['i_chooselang'] = 'Choose your language';
+$lang['i_installer']  = 'DokuWiki Installer';
+$lang['i_wikiname']   = 'Wiki Name';
+$lang['i_enableacl']  = 'Enable ACL (recommended)';
+$lang['i_superuser']  = 'Superuser';
+$lang['i_problems']   = 'The installer found some problems, indicated below. You can not continue until you have fixed them.';
+$lang['i_modified']   = 'For security reasons this script will only work with a new and unmodified Dokuwiki installation.
+                         You should either re-extract the files from the downloaded package or consult the complete
+                         <a href="http://wiki.splitbrain.org/wiki:install">Dokuwiki installation instructions</a>';
+$lang['i_funcna']     = 'PHP function <code>%s</code> is not available. Maybe your hosting provider disabled it for some reason?';
+$lang['i_phpver']     = 'Your PHP version <code>%s</code> is lower than the needed <code>%s</code>. You need to upgrade your PHP install.';
+$lang['i_permfail']   = '<code>%s</code> is not writable by DokuWiki. You need to fix the permission settings of this directory!';
+$lang['i_confexists'] = '<code>%s</code> already exists';
+$lang['i_writeerr']   = 'Unable to create <code>%s</code>. You will need to check directory/file permissions and create the file manually.';
+$lang['i_badhash']    = 'unrecognised or modified dokuwiki.php (hash=<code>%s</code>)';
+$lang['i_badval']     = '<code>%s</code> - illegal or empty value';
+$lang['i_success']    = 'The configuration was finished successfully. You may delete the install.php file now. Continue to
+                        <a href="doku.php">your new DokuWiki</a>.';
+$lang['i_failure']    = 'Some errors occured while writing the configuration files. You may need to fix them manually before
+                         you can use <a href="doku.php">your new DokuWiki</a>.';
+$lang['i_policy']     = 'Initial ACL policy';
+$lang['i_pol0']       = 'Open Wiki (read, write, upload for everyone)';
+$lang['i_pol1']       = 'Public Wiki (read for everyone, write and upload for registered users)';
+$lang['i_pol2']       = 'Closed Wiki (read, write, upload for registered users only)';
+
+$lang['i_retry']      = 'Retry';
+
 //Setup VIM: ex: et ts=2 enc=utf-8 :
