@@ -15,8 +15,8 @@ $lang['encoding']   = 'utf-8';
 $lang['direction']  = 'ltr';
 
 $lang['btn_edit']   = 'Éditer cette page';
-$lang['btn_source'] = 'Montrer le source de la page';
-$lang['btn_show']   = 'Montrer la page';
+$lang['btn_source'] = 'Afficher le texte source';
+$lang['btn_show']   = 'Afficher la page';
 $lang['btn_create'] = 'Créer cette page';
 $lang['btn_search'] = 'Rechercher';
 $lang['btn_save']   = 'Sauver';
@@ -43,6 +43,9 @@ $lang['btn_unsubscribe'] = 'Ne pas notifier les modifications';
 $lang['btn_profile']    = 'Mettre à jour le profil';
 $lang['btn_reset']     = 'Réinitialiser';
 $lang['btn_resendpwd'] = 'Envoyer le mot de passe';
+$lang['btn_draft']    = 'Éditer brouillon';
+$lang['btn_recover']  = 'Récupérer brouillon';
+$lang['btn_draftdel'] = 'Effacer brouillon';
 
 $lang['loggedinas'] = 'Connecté en tant que';
 $lang['user']       = 'Utilisateur';
@@ -57,6 +60,7 @@ $lang['register']   = 'S\'enregistrer';
 $lang['profile']    = 'Profil utilisateur';
 $lang['badlogin']   = 'L\'utilisateur ou le mot de passe est incorrect.';
 $lang['minoredit']  = 'Mineur';
+$lang['draftdate']  = 'Brouillon auto-enregistré le'; // full dformat date will be added
 
 $lang['regmissing'] = 'Désolé, vous devez remplir tous les champs.';
 $lang['reguexists'] = 'Désolé, ce nom d\'utilisateur appartient déjà à un autre utilisateur.';
@@ -78,11 +82,13 @@ $lang['resendna']  = 'Ce wiki ne permet pas le renvoi de mot de passe.';
 $lang['resendpwd'] = 'Renvoyer le mot de passe de';
 $lang['resendpwdmissing'] = 'Désolé, vous devez remplir tous les champs.';
 $lang['resendpwdnouser']  = 'Désolé, cet utilisateur est introuvable dans notre base.';
+$lang['resendpwdbadauth'] = 'Désolé, ce code d\'authentification est invalide. Assurez vous d\'avoir utilisé le lien de confirmation.';
+$lang['resendpwdconfirm'] = 'Un lien de confirmation vous a été envoyé par courriel.';
 $lang['resendpwdsuccess'] = 'Votre nouveau mot de passe vous a été expédié par courriel.';
 
-$lang['txt_upload'] = 'Sélectionnez un fichier à envoyer';
-$lang['txt_filename'] = 'Donnez un "wikiname" (optionnel)';
-$lang['txt_overwrt']  = 'Remplace le fichier actuel';
+$lang['txt_upload'] = 'Sélectionnez un fichier à envoyer ';
+$lang['txt_filename'] = 'Donnez un "wikiname" (optionnel) ';
+$lang['txt_overwrt']  = 'Écraser le fichier cible';
 $lang['lockedby']     = 'Actuellement bloqué par';
 $lang['lockexpire']   = 'Le blocage expire à';
 $lang['willexpire']   = 'Votre blocage pour modifier cette page expire dans une minute.\nPour éviter les conflits, utiliser le bouton Aperçu pour réinitialiser le minuteur.';
@@ -103,18 +109,27 @@ $lang['mediainuse']  = 'Le fichier "%s" n\'a pas été effacé - il est en cours
 $lang['namespaces']  = 'Catégories';
 $lang['mediafiles']  = 'Fichiers disponibles dans';
 
+$lang['js']['keepopen']    = 'Gardez la fenêtre ouverte pendant la sélection';
+$lang['js']['hidedetails'] = 'Masquer détails';
+$lang['mediausage']  = 'Utilisez la syntaxe suivante pour faire référence à ce fichier :';
+$lang['mediaview']   = 'Voir fichier original';
+$lang['mediaroot']   = 'root';
+$lang['mediaupload'] = 'Envoyer un fichier dans la catégorie courante ici. Pour créer des sous-catégories, préfixez le nom du fichier par le nom de la sous-catégorie séparée par un double point.';
+$lang['mediaextchange'] = 'Extension du fichier changée de .%s en .%s!';
+
 $lang['reference']   = 'Références pour';
 $lang['ref_inuse']   = 'Le fichier ne peut être effacé, il est toujours utilisé par les pages suivantes:';
 $lang['ref_hidden']  = 'Quelques références sont sur des pages que vous n\'avez pas la permission de lire';
 
-$lang['hits']       = 'Occurrences trouvées';
-$lang['quickhits']  = 'Pages trouvées';
+$lang['hits']       = 'occurrences trouvées';
+$lang['quickhits']  = 'Pages trouvées ';
 $lang['toc']        = 'Table des matières';
 $lang['current']    = 'version actuelle';
 $lang['yours']      = 'votre version';
 $lang['diff']       = 'différences avec la version actuelle';
 $lang['line']       = 'Ligne';
 $lang['breadcrumb'] = 'Piste';
+$lang['youarehere'] = 'Vous êtes ici';
 $lang['lastmod']    = 'Dernière modification';
 $lang['by']         = 'par';
 $lang['deleted']    = 'effacée';
@@ -124,6 +139,7 @@ $lang['summary']    = 'Résumé';
 
 $lang['mail_newpage'] = 'page ajoutée :';
 $lang['mail_changed'] = 'page changée :';
+$lang['mail_new_user'] = 'Nouvel utilisateur :';
 
 $lang['nosmblinks'] = 'Les liens vers les partages Windows ne fonctionnent qu\'avec Microsoft Internet Explorer.\nVous pouvez toujours faire un copier/coller du lien.';
 
@@ -183,4 +199,32 @@ $lang['unsubscribe_error']  = 'Erreur à la suppression de %s de la liste d\'abo
 $lang['authmodfailed']   = 'Mauvais paramétrage de l\'authentification. Merci d\'informer l\'administrateur du Wiki.';
 $lang['authtempfail']    = 'L\'authentification est temporairement indisponible. Si cela perdure, merci d\'informer l\'administrateur du Wiki.';
 
+/* installer strings */
+$lang['i_chooselang'] = 'Choisissez votre langue';
+$lang['i_installer']  = 'DokuWiki Installeur';
+$lang['i_wikiname']   = 'Nom du Wiki';
+$lang['i_enableacl']  = 'Activer ACL (recommandé)';
+$lang['i_superuser']  = 'Super-utilisateur';
+$lang['i_problems']   = 'The installer found some problems, indicated below. You can not continue until you have fixed them.';
+$lang['i_modified']   = 'Pour des raisons de sécurité ce script ne fonctionne qu\'avec une installation neuve et non modifiée de Dokuwiki.
+                         Vous devriez soit ré-extraire les fichiers depuis le paquet téléchargé soit consulter les
+                         <a href="http://wiki.splitbrain.org/wiki:install">instructions d\'installation de Dokuwiki</a>';
+$lang['i_funcna']     = 'La fonction PHP <code>%s</code> n\'est pas disponible. Peut-être que votre hébergeur l\'a désactivée ?';
+$lang['i_phpver']     = 'Votre version de PHP (<code>%s</code>) est antérieure à la version requise (<code>%s</code>. Vous devez mettre à jour votre installation de PHP.';
+$lang['i_permfail']   = '<code>%s</code> n\'est pas accessible en écriture DokuWiki. Vous devez corriger les permissions de ce répertoire !';
+$lang['i_confexists'] = '<code>%s</code> existe déjà';
+$lang['i_writeerr']   = 'Impossible de créer <code>%s</code>. Vous devez vérifier les permissions des répertoires/fichiers et créer le fichier manuellement.';
+$lang['i_badhash']    = 'dokuwiki.php non reconnu ou modifié (hash=<code>%s</code>)';
+$lang['i_badval']     = '<code>%s</code> - valeur illégale ou vide';
+$lang['i_success']    = 'L\'installation s\'est terminée avec succès. Vous pouvez maintenant supprimer le fichier install.php. Continuer avec
+                        <a href="doku.php">votre nouveau DokuWiki</a>.';
+$lang['i_failure']    = 'Des erreurs sont survenues lors de l\'écriture des fichiers de configuration. Il vous faudra les corriger manuellement avant 
+                         de pouvoir utiliser <a href="doku.php">votre nouveau DokuWiki</a>.';
+$lang['i_policy']     = 'Politique d\'ACL initiale';
+$lang['i_pol0']       = 'Wiki ouvert (lecture, écriture, envoi de fichiers pour tout le monde)';
+$lang['i_pol1']       = 'Wiki public (lecture pour tout le monde, écriture et envoi de fichiers pour les utilisateurs enregistrés)';
+$lang['i_pol2']       = 'Wiki fermé (lecture, écriture, envoi de fichiers pour les utilisateurs enregistrés uniquement)';
+
+$lang['i_retry']      = 'Réessayer';
+
 //Setup VIM: ex: et ts=2 enc=utf-8 :
