@@ -24,7 +24,7 @@ $lang['btn_revs']   = 'История страницы';
 $lang['btn_recent'] = 'Недавние изменения';
 $lang['btn_upload'] = 'Закачать';
 $lang['btn_cancel'] = 'Отменить';
-$lang['btn_index']  = 'Содержание';
+$lang['btn_index']  = 'Все страницы';
 $lang['btn_secedit']= 'Править';
 $lang['btn_login']  = 'Войти';
 $lang['btn_logout'] = 'Выйти';
@@ -32,16 +32,19 @@ $lang['btn_admin']  = 'Управление';
 $lang['btn_update'] = 'Обновить';
 $lang['btn_delete'] = 'Удалить';
 $lang['btn_back']   = 'Назад';
-$lang['btn_backlink']    = "Ссылки сюда";
+$lang['btn_backlink']    = 'Ссылки сюда';
 $lang['btn_backtomedia'] = 'Вернуться к выбору медиа-файла';
 $lang['btn_subscribe']   = 'Подписаться';
 $lang['btn_unsubscribe'] = 'Отписаться';
 $lang['btn_profile']= 'Профиль';
 $lang['btn_reset']  = 'Сброс';
 $lang['btn_resendpwd'] = 'Послать новый пароль';
+$lang['btn_draft']    = 'Править черновик';
+$lang['btn_recover']  = 'Восстановить черновик';
+$lang['btn_draftdel'] = 'Удалить черновик';
 
 $lang['loggedinas'] = 'Вы';
-$lang['user']       = 'Имя пользователя';
+$lang['user']       = 'Логин';
 $lang['pass']       = 'Пароль';
 $lang['newpass']    = 'Новый пароль';
 $lang['oldpass']    = 'Введите текущий пароль';
@@ -53,45 +56,48 @@ $lang['register']   = 'Зарегистрироваться';
 $lang['profile']    = 'Профиль пользователя';
 $lang['badlogin']   = 'Извините, неверное имя пользователя или пароль.';
 $lang['minoredit']  = 'Небольшие изменения';
+$lang['draftdate']  = 'Черновик сохранен'; // full dformat date will be added
 
 $lang['regmissing'] = 'Извините, вам следует заполнить все поля.';
 $lang['reguexists'] = 'Извините, пользователь с таким логином уже существует.';
 $lang['regsuccess'] = 'Пользователь создан, пароль выслан на e-mail.';
 $lang['regsuccess2']= 'Пользователь создан.';
-$lang['regmailfail']= 'Похоже проблема с посылкой пароля по почте. Пожалуйста сообщите администратору!';
-$lang['regbadmail'] = 'Данный вами адрес e-mail выглядит неправильным. Если вы считаете это ошибкой - сообщите админу.';
+$lang['regmailfail']= 'Похоже, проблема с посылкой пароля по почте. Пожалуйста, сообщите администратору!';
+$lang['regbadmail'] = 'Данный вами адрес e-mail выглядит неправильным. Если вы считаете это ошибкой, сообщите админу.';
 $lang['regbadpass'] = 'Два введённых пароля не идентичны. Пожалуйста, попробуйте ещё раз.';
-$lang['regpwmail']  = 'Ваш пароль для системы ДокуВики';
+$lang['regpwmail']  = 'Ваш пароль для системы DokuWiki';
 $lang['reghere']    = 'У вас еще нет аккаунта? Извольте получить';
 
 $lang['profna']       = 'Данная вики не поддерживает изменение профиля';
 $lang['profnochange'] = 'Изменений не внесено, профиль не обновлён.';
-$lang['profnoempty']  = 'Недопустимы пустое имя или адрес электронной почты.';
+$lang['profnoempty']  = 'Логин и адрес e-mail не могут быть пустыми.';
 $lang['profchanged']  = 'Профиль пользователя успешно обновлён.';
 
 $lang['pwdforget'] = 'Забыли пароль? Получите новый';
 $lang['resendna']  = 'Данная вики не поддерживает повторную отправку пароля.';
 $lang['resendpwd'] = 'Выслать пароль для';
 $lang['resendpwdmissing'] = 'Вы должны заполнить все поля формы.';
-$lang['resendpwdnouser']  = 'Пользователь с таким именем не обнаружен в нашей базе данных.';
-$lang['resendpwdsuccess'] = 'Ваш новый пароль был выслан на ваш адрес электронной почты.';
+$lang['resendpwdnouser']  = 'Пользователь с таким логином не обнаружен в нашей базе данных.';
+$lang['resendpwdbadauth'] = 'Извините, неверный код авторизации. Убедитесь, что вы полностью скопировали ссылку. ';
+$lang['resendpwdconfirm'] = 'Ссылка для подтверждения пароля была выслана по e-mail. ';
+$lang['resendpwdsuccess'] = 'Ваш новый пароль был выслан по e-mail.';
 
 $lang['txt_upload']   = 'Выберите файл для закачки';
 $lang['txt_filename'] = 'Введите имя файла в вики (необязательно)';
 $lang['txt_overwrt']  = 'Перезаписать существующий файл';
 $lang['lockedby']     = 'В данный момент заблокирован';
 $lang['lockexpire']   = 'Блокировка истекает в';
-$lang['willexpire']   = 'Ваша блокировка редактирования этой страницы истекает в течение минуты.\nЧтобы избежать конфликтов и сбросить таймер блокировки, нажмите кнопку Просмотр.';
+$lang['willexpire']   = 'Ваша блокировка редактирования этой страницы истекает в течение минуты.\nЧтобы избежать конфликтов и сбросить таймер блокировки, нажмите кнопку просмотра.';
 
 $lang['notsavedyet'] = 'Несохраненные изменения будут потеряны.\nВы действительно хотите продолжить?';
-$lang['rssfailed']   = 'Произошла ошибка во время получения этой RSS-ленты: ';
+$lang['rssfailed']   = 'Произошла ошибка при получении следующей новостной ленты: ';
 $lang['nothingfound']= 'Ничего не найдено.';
 
 $lang['mediaselect'] = 'Выбор медиа-файла';
 $lang['fileupload']  = 'Закачка медиа-файла';
 $lang['uploadsucc']  = 'Закачка произведена успешно';
 $lang['uploadfail']  = 'Закачка не удалась. Может быть проблемы с правами доступа?';
-$lang['uploadwrong'] = 'В загрузке отказано. Недопустимое расширение файла.';
+$lang['uploadwrong'] = 'В закачке отказано. Файлы с таким расширением запрещены. ';
 $lang['uploadexist'] = 'Файл с таким именем существует. Загрузка не произведена.';
 $lang['deletesucc']  = 'Файл "%s" был удалён.';
 $lang['deletefail']  = 'Невозможно удалить файл "%s". Проверьте права доступа к файлу.';
@@ -99,9 +105,17 @@ $lang['mediainuse']  = 'Файл "%s" не был удалён - файл все
 $lang['namespaces']  = 'Пространства имен';
 $lang['mediafiles']  = 'Доступные файлы';
 
-$lang['reference']   = 'Ссылки для';
-$lang['ref_inuse']   = 'Этот файл не может быть удалён, так как он используется следующими страницами:';
-$lang['ref_hidden']  = 'Некоторые ссылки находятся на страницах, на чтение которых у вас нет прав';
+$lang['js']['keepopen'] = 'Не закрывать окно после выбора';
+$lang['js']['hidedetails'] = 'Скрыть детали';
+$lang['mediausage'] = 'Для ссылки на этот файл используйте следующий синтаксис:';
+$lang['mediaview'] = 'Посмотреть исходный файл';
+$lang['mediaroot'] = 'корень';
+$lang['mediaupload'] = 'Здесь можно загрузить файл в текущий каталог ("пространство имен"). Чтобы создать подкаталоги, добавьте их к началу имени файла ("Загрузить как"). Имена подкаталогов разделяются двоеточиями. ';
+$lang['mediaextchange'] = 'Расширение изменилось: с .%s на .%s!';
+
+$lang['reference'] = 'Ссылки для';
+$lang['ref_inuse'] = 'Этот файл не может быть удалён, так как он используется следующими страницами:';
+$lang['ref_hidden'] = 'Некоторые ссылки находятся на страницах, на чтение которых у вас нет прав';
 
 $lang['hits']       = 'соответствий';
 $lang['quickhits']  = 'Соответствия в названиях страниц';
@@ -119,9 +133,9 @@ $lang['created']    = 'создано';
 $lang['restored']   = 'старая ревизия восстановлена';
 $lang['summary']    = 'Сводка изменений';
 
-
 $lang['mail_newpage'] = 'Страница добавлена:';
 $lang['mail_changed'] = 'Страница изменена:';
+$lang['mail_new_user'] = 'Новый пользователь:';
 
 $lang['nosmblinks'] = 'Ссылка на сетевые каталоги Windows работает только из Интернет Эксплорера\nВы все же можете скопировать ссылку.';
 
@@ -168,7 +182,7 @@ $lang['img_fsize']   = 'Размер';
 $lang['img_artist']  = 'Фотограф';
 $lang['img_copyr']   = 'Авторские права';
 $lang['img_format']  = 'Формат';
-$lang['img_camera']  = 'Камера';
+$lang['img_camera']  = 'Модель';
 $lang['img_keywords']= 'Ключевые слова';
 
 $lang['subscribe_success']  = '%s добавлен(а) в список рассылки для страницы %s';
@@ -176,7 +190,35 @@ $lang['subscribe_error']    = 'Ошибка добавления пользов
 $lang['subscribe_noaddress']= 'В вашем профиле не указан адрес электронной почты. Ввиду этого вы не можете подписываться на рассылки.';
 $lang['unsubscribe_success']= '%s удален(а) из списка рассылки для страницы %s';
 $lang['unsubscribe_error']  = 'Ошибка удаления %s из списка рассылки для страницы %s';
-$lang['authmodfailed']      = 'Неправильная конфигурация аутентификации пользователя. Пожалуйста, сообщите об этом вашему администратору вики.';
-$lang['authtempfail']       = 'Аутентификация пользователей временно недоступна. Если проблема продолжается какое-то время, пожалуйста, сообщите об этом вашему администратору вики.';
+
+/* auth.class language support */
+$lang['authmodfailed']     = 'Неправильная конфигурация аутентификации пользователя. Пожалуйста, сообщите об этом вашему администратору вики.';
+$lang['authtempfail']      = 'Аутентификация пользователей временно недоступна. Если проблема продолжается какое-то время, пожалуйста, сообщите об этом вашему администратору вики.';
+
+/* installer strings */
+$lang['i_chooselang'] = 'Выберите ваш язык';
+$lang['i_installer'] = 'Установка DokuWiki';
+$lang['i_wikiname'] = 'Название вики';
+$lang['i_enableacl'] = 'Разрешить ограничение прав доступа (рекомендуется)';
+$lang['i_superuser'] = 'Суперюзер';
+$lang['i_problems'] = 'Программа установки столкнулась с проблемами, перечисленными ниже. Чтобы продолжить, вам необходимо их устранить. ';
+$lang['i_modified'] = 'Из соображений безопасности эта программа запускается только на новой, не измененной установке DokuWiki. 
+                         Вам нужно либо заново распаковать скачанный пакет установки, либо обратиться к полной
+                         <a href="http://wiki.splitbrain.org/wiki:install">инструкции по установке DokuWiki</a>';
+$lang['i_funcna'] = 'Функция PHP <code>%s</code> недоступна. Может быть, она по какой-то причине заблокирована вашим хостингом?';
+$lang['i_phpver'] = 'Ваша версия PHP (<code>%s</code>) ниже требуемой (<code>%s</code>). Вам необходимо обновить установленную версию PHP.';
+$lang['i_permfail'] = '<code>%s</code> недоступна для записи DokuWiki. Вам необходимо исправить системные права доступа для этой директории!';
+$lang['i_confexists'] = '<code>%s</code> уже существует';
+$lang['i_writeerr'] = 'Не удалось создать <code>%s</code>. Вам необходимо проверить системные права доступа к файлу/директориям и создать файл вручную. ';
+$lang['i_badhash'] = 'dokuwiki.php не распознана или изменена (хэш=<code>%s</code>)';
+$lang['i_badval'] = '<code>%s</code> - недопустимое или пустое значение';
+$lang['i_success'] = 'Конфигурация прошла успешно. Теперь вы можете удалить файл install.php. Переходите к
+                        <a href="doku.php">вашей новой DokuWiki</a>.';
+$lang['i_failure'] = 'При записи в файлы конфигурации были обнаружены ошибки. Возможно, вам придется исправить их вручную, прежде, чем вы сможете использовать <a href="doku.php">вашу новую DokuWiki</a>.';
+$lang['i_policy'] = 'Исходная политика прав доступа';
+$lang['i_pol0'] = 'Открытая вики (чтение, запись, закачка файлов для всех)';
+$lang['i_pol1'] = 'Общедоступная вики (чтение для всех, запись и загрузка файлов для зарегистрированных пользователей)';
+$lang['i_pol2'] = 'Закрытая вики (чтение, запись и загрузка файлов только для зарегистрированных пользователей)';
+$lang['i_retry'] = 'Повторить попытку';
 
 //Setup VIM: ex: et ts=2 enc=utf-8 :
