@@ -9,8 +9,11 @@ class Doku_Handler {
 
     var $calls = array();
 
-    var $meta = array(
+    var $status = array(
         'section' => FALSE,
+        'section_edit_start' => -1,
+        'section_edit_level' => 1,
+        'section_edit_title' => ''
     );
 
     var $rewriteBlocks = TRUE;
@@ -25,9 +28,16 @@ class Doku_Handler {
     }
 
     function _finalize(){
-        if ( $this->meta['section'] ) {
-            $S = & new Doku_Handler_Section();
-            $this->calls = $S->process($this->calls);
+
+        $this->CallWriter->finalise();
+
+        if ( $this->status['section'] ) {
+           $last_call = end($this->calls);
+           array_push($this->calls,array('section_close',array(), $last_call[2]));
+           if ($this->status['section_edit_start']>1) {
+               // ignore last edit section if there is only one header
+               array_push($this->calls,array('section_edit',array($this->status['section_edit_start'], 0, $this->status['section_edit_level'], $this->status['section_edit_title']), $last_call[2]));
+           }
         }
 
         if ( $this->rewriteBlocks ) {
@@ -35,6 +45,8 @@ class Doku_Handler {
             $this->calls = $B->process($this->calls);
         }
 
+        trigger_event('PARSER_HANDLER_DONE',$this);
+
         array_unshift($this->calls,array('document_start',array(),0));
         $last_call = end($this->calls);
         array_push($this->calls,array('document_end',array(),$last_call[2]));
@@ -63,7 +75,7 @@ class Doku_Handler {
         if($plugin != null){
             $data = $plugin->handle($match, $state, $pos, $this);
         }
-        $this->_addCall('plugin',array($pluginname,$data,$pos),$pos);
+        $this->_addCall('plugin',array($pluginname,$data,$state),$pos);
         return TRUE;
     }
 
@@ -78,30 +90,28 @@ class Doku_Handler {
     }
 
     function header($match, $state, $pos) {
-        $match = trim($match);
-        $levels = array(
-            '======'=>1,
-            '====='=>2,
-            '===='=>3,
-            '==='=>4,
-            '=='=>5,
-        );
-        $hsplit = preg_split( '/(={2,})/u', $match,-1,
-            PREG_SPLIT_DELIM_CAPTURE | PREG_SPLIT_NO_EMPTY );
+        global $conf;
 
-        // Locate the level - default to level 1 if no match (title contains == signs)
-        if ( isset($hsplit[0]) && array_key_exists($hsplit[0], $levels) ) {
-            $level = $levels[$hsplit[0]];
-        } else {
-            $level = 1;
+        // get level and title
+        $title = trim($match);
+        $level = 7 - strspn($title,'=');
+        if($level < 1) $level = 1;
+        $title = trim($title,'=');
+        $title = trim($title);
+
+        if ($this->status['section']) $this->_addCall('section_close',array(),$pos);
+
+        if ($level<=$conf['maxseclevel']) {
+            $this->_addCall('section_edit',array($this->status['section_edit_start'], $pos-1, $this->status['section_edit_level'], $this->status['section_edit_title']), $pos);
+            $this->status['section_edit_start'] = $pos;
+            $this->status['section_edit_level'] = $level;
+            $this->status['section_edit_title'] = $title;
         }
 
-        // Strip markers and whitespaces
-        $title = trim($match,'=');
-        $title = trim($title,' ');
-
         $this->_addCall('header',array($title,$level,$pos), $pos);
-        $this->meta['section'] = TRUE;
+
+        $this->_addCall('section_open',array($level),$pos);
+        $this->status['section'] = TRUE;
         return TRUE;
     }
 
@@ -181,7 +191,42 @@ class Doku_Handler {
 
 
     function footnote($match, $state, $pos) {
-        $this->_nestingTag($match, $state, $pos, 'footnote');
+//        $this->_nestingTag($match, $state, $pos, 'footnote');
+        if (!isset($this->_footnote)) $this->_footnote = false;
+
+        switch ( $state ) {
+            case DOKU_LEXER_ENTER:
+                // footnotes can not be nested - however due to limitations in lexer it can't be prevented
+                // we will still enter a new footnote mode, we just do nothing
+                if ($this->_footnote) {
+                  $this->_addCall('cdata',array($match), $pos);
+                  break;
+                }
+
+                $this->_footnote = true;
+
+                $ReWriter = & new Doku_Handler_Nest($this->CallWriter,'footnote_close');
+                $this->CallWriter = & $ReWriter;
+                $this->_addCall('footnote_open', array(), $pos);
+            break;
+            case DOKU_LEXER_EXIT:
+                // check whether we have already exitted the footnote mode, can happen if the modes were nested
+                if (!$this->_footnote) {
+                  $this->_addCall('cdata',array($match), $pos);
+                  break;
+                }
+
+                $this->_footnote = false;
+
+                $this->_addCall('footnote_close', array(), $pos);
+                $this->CallWriter->process();
+                $ReWriter = & $this->CallWriter;
+                $this->CallWriter = & $ReWriter->CallWriter;
+            break;
+            case DOKU_LEXER_UNMATCHED:
+                $this->_addCall('cdata', array($match), $pos);
+            break;
+        }
         return TRUE;
     }
 
@@ -462,7 +507,29 @@ class Doku_Handler {
 
     function rss($match, $state, $pos) {
         $link = preg_replace(array('/^\{\{rss>/','/\}\}$/'),'',$match);
-        $this->_addCall('rss',array($link),$pos);
+
+        // get params
+        list($link,$params) = explode(' ',$link,2);
+
+        $p = array();
+        if(preg_match('/\b(\d+)\b/',$params,$match)){
+            $p['max'] = $match[1];
+        }else{
+            $p['max'] = 8;
+        }
+        $p['reverse'] = (preg_match('/rev/',$params));
+        $p['author']  = (preg_match('/\b(by|author)/',$params));
+        $p['date']    = (preg_match('/\b(date)/',$params));
+        $p['details'] = (preg_match('/\b(desc|detail)/',$params));
+
+        if (preg_match('/\b(\d+)([dhm])\b/',$params,$match)) {
+          $period = array('d' => 86400, 'h' => 3600, 'm' => 60);
+          $p['refresh'] = max(600,$match[1]*$period[$match[2]]);  // n * period in seconds, minimum 10 minutes
+        } else {
+          $p['refresh'] = 14400;   // default to 4 hours
+        }
+
+        $this->_addCall('rss',array($link,$p),$pos);
         return TRUE;
     }
 
@@ -644,9 +711,62 @@ class Doku_Handler_CallWriter {
     function writeCalls($calls) {
         $this->Handler->calls = array_merge($this->Handler->calls, $calls);
     }
+
+    // function is required, but since this call writer is first/highest in
+    // the chain it is not required to do anything
+    function finalise() {
+    }
 }
 
 //------------------------------------------------------------------------
+/**
+ * Generic call writer class to handle nesting of rendering instructions
+ * within a render instruction. Also see nest() method of renderer base class
+ *
+ * @author    Chris Smith <chris@jalakai.co.uk>
+ */
+class Doku_Handler_Nest {
+
+    var $CallWriter;
+    var $calls = array();
+
+    var $closingInstruction;
+
+    /**
+     * constructor
+     *
+     * @param  object     $CallWriter     the renderers current call writer
+     * @param  string     $close          closing instruction name, this is required to properly terminate the
+     *                                    syntax mode if the document ends without a closing pattern
+     */
+    function Doku_Handler_Nest(& $CallWriter, $close="nest_close") {
+        $this->CallWriter = & $CallWriter;
+
+        $this->closingInstruction = $close;
+    }
+
+    function writeCall($call) {
+        $this->calls[] = $call;
+    }
+
+    function writeCalls($calls) {
+        $this->calls = array_merge($this->calls, $calls);
+    }
+
+    function finalise() {
+        $last_call = end($this->calls);
+        $this->writeCall(array($this->closingInstruction,array(), $last_call[2]));
+
+        $this->process();
+        $this->CallWriter->finalise();
+    }
+
+    function process() {
+        $first_call = reset($this->calls);
+        $this->CallWriter->writeCall(array("nest", array($this->calls), $first_call[2]));
+    }
+}
+
 class Doku_Handler_List {
 
     var $CallWriter;
@@ -666,11 +786,20 @@ class Doku_Handler_List {
     // Probably not needed but just in case...
     function writeCalls($calls) {
         $this->calls = array_merge($this->calls, $calls);
-        $this->CallWriter->writeCalls($this->calls);
+#        $this->CallWriter->writeCalls($this->calls);
+    }
+
+    function finalise() {
+        $last_call = end($this->calls);
+        $this->writeCall(array('list_close',array(), $last_call[2]));
+
+        $this->process();
+        $this->CallWriter->finalise();
     }
 
     //------------------------------------------------------------------------
     function process() {
+
         foreach ( $this->calls as $call ) {
             switch ($call[0]) {
                 case 'list_item':
@@ -852,7 +981,15 @@ class Doku_Handler_Preformatted {
     // Probably not needed but just in case...
     function writeCalls($calls) {
         $this->calls = array_merge($this->calls, $calls);
-        $this->CallWriter->writeCalls($this->calls);
+#        $this->CallWriter->writeCalls($this->calls);
+    }
+
+    function finalise() {
+        $last_call = end($this->calls);
+        $this->writeCall(array('preformatted_end',array(), $last_call[2]));
+
+        $this->process();
+        $this->CallWriter->finalise();
     }
 
     function process() {
@@ -873,6 +1010,7 @@ class Doku_Handler_Preformatted {
             }
         }
     }
+
 }
 
 //------------------------------------------------------------------------
@@ -895,7 +1033,15 @@ class Doku_Handler_Quote {
     // Probably not needed but just in case...
     function writeCalls($calls) {
         $this->calls = array_merge($this->calls, $calls);
-        $this->CallWriter->writeCalls($this->calls);
+#        $this->CallWriter->writeCalls($this->calls);
+    }
+
+    function finalise() {
+        $last_call = end($this->calls);
+        $this->writeCall(array('quote_end',array(), $last_call[2]));
+
+        $this->process();
+        $this->CallWriter->finalise();
     }
 
     function process() {
@@ -923,7 +1069,9 @@ class Doku_Handler_Quote {
                         for ( $i = 1; $i <= $quoteDiff; $i++ ) {
                             $this->quoteCalls[] = array('quote_close',array(),$call[2]);
                         }
-                    }
+                    } else {
+                        if ($call[0] != 'quote_start') $this->quoteCalls[] = array('linebreak',array(),$call[2]);
+                    } 
 
                     $quoteDepth = $quoteLength;
 
@@ -981,7 +1129,15 @@ class Doku_Handler_Table {
     // Probably not needed but just in case...
     function writeCalls($calls) {
         $this->calls = array_merge($this->calls, $calls);
-        $this->CallWriter->writeCalls($this->calls);
+#        $this->CallWriter->writeCalls($this->calls);
+    }
+
+    function finalise() {
+        $last_call = end($this->calls);
+        $this->writeCall(array('table_end',array(), $last_call[2]));
+
+        $this->process();
+        $this->CallWriter->finalise();
     }
 
     //------------------------------------------------------------------------
@@ -1203,6 +1359,12 @@ class Doku_Handler_Section {
                 $inSection = TRUE;
 
             } else {
+
+                if ($call[0] == 'section_open' )  {
+                    $inSection = TRUE;
+                } else if ($call[0] == 'section_open' ) {
+                    $inSection = FALSE;
+                }
                 $sectionCalls[] = $call;
             }
         }
@@ -1238,7 +1400,7 @@ class Doku_Handler_Block {
             'table_open','tablerow_open','tablecell_open','tableheader_open',
             'quote_open',
             'section_open', // Needed to prevent p_open between header and section_open
-            'code','file','hr','preformatted',
+            'code','file','hr','preformatted','rss',
         );
 
     var $blockClose = array(
@@ -1247,7 +1409,7 @@ class Doku_Handler_Block {
             'table_close','tablerow_close','tablecell_close','tableheader_close',
             'quote_close',
             'section_close', // Needed to prevent p_close after section_close
-            'code','file','hr','preformatted',
+            'code','file','hr','preformatted','rss',
         );
 
     // Stacks can contain paragraphs
@@ -1269,19 +1431,15 @@ class Doku_Handler_Block {
     function Doku_Handler_Block(){
         global $DOKU_PLUGINS;
         //check if syntax plugins were loaded
-        if(!is_array($DOKU_PLUGINS['syntax'])) return;
+        if(empty($DOKU_PLUGINS['syntax'])) return;
         foreach($DOKU_PLUGINS['syntax'] as $n => $p){
             $ptype = $p->getPType();
             if($ptype == 'block'){
                 $this->blockOpen[]  = 'plugin_'.$n;
-                $this->blockOpen[]  = 'plugin_'.$n.'_open';
                 $this->blockClose[] = 'plugin_'.$n;
-                $this->blockClose[] = 'plugin_'.$n.'_close';
             }elseif($ptype == 'stack'){
                 $this->stackOpen[]  = 'plugin_'.$n;
-                $this->stackOpen[]  = 'plugin_'.$n.'_open';
                 $this->stackClose[] = 'plugin_'.$n;
-                $this->stackClose[] = 'plugin_'.$n.'_close';
             }
         }
     }
@@ -1311,8 +1469,16 @@ class Doku_Handler_Block {
             //remove the whole paragraph
             array_splice($this->calls,$i);
         }else{
-            $this->calls[] = array('p_close',array(), $pos);
+            if ($this->calls[count($this->calls)-1][0] == 'section_edit') {
+                $tmp = array_pop($this->calls);
+                $this->calls[] = array('p_close',array(), $pos);
+                $this->calls[] = $tmp;
+            } else {
+                $this->calls[] = array('p_close',array(), $pos);
+            }
         }
+
+        $this->inParagraph = FALSE;
     }
 
     /**
@@ -1325,17 +1491,19 @@ class Doku_Handler_Block {
     function process($calls) {
         foreach ( $calls as $key => $call ) {
             $cname = $call[0];
-            if($cname == 'plugin') $cname='plugin_'.$call[1][0];
+            if($cname == 'plugin') {
+                $cname='plugin_'.$call[1][0];
+
+                $plugin = true;
+                $plugin_open = (($call[1][2] == DOKU_LEXER_ENTER) || ($call[1][2] == DOKU_LEXER_SPECIAL));
+                $plugin_close = (($call[1][2] == DOKU_LEXER_EXIT) || ($call[1][2] == DOKU_LEXER_SPECIAL));
+            } else {
+                $plugin = false;
+            }
 
             // Process blocks which are stack like... (contain linefeeds)
-            if ( in_array($cname,$this->stackOpen ) ) {
-                /*
-                if ( $this->atStart ) {
-                    $this->calls[] = array('p_open',array(), $call[2]);
-                    $this->atStart = FALSE;
-                    $this->inParagraph = TRUE;
-                }
-                */
+            if ( in_array($cname,$this->stackOpen ) && (!$plugin || $plugin_open) ) {
+
                 $this->calls[] = $call;
 
                 // Hack - footnotes shouldn't immediately contain a p_open
@@ -1347,10 +1515,9 @@ class Doku_Handler_Block {
                 continue;
             }
 
-            if ( in_array($cname,$this->stackClose ) ) {
+            if ( in_array($cname,$this->stackClose ) && (!$plugin || $plugin_close)) {
 
                 if ( $this->inParagraph ) {
-                    //$this->calls[] = array('p_close',array(), $call[2]);
                     $this->closeParagraph($call[2]);
                 }
                 $this->calls[] = $call;
@@ -1362,18 +1529,9 @@ class Doku_Handler_Block {
 
                 if ( $cname == 'eol' ) {
 
-
-                    /* XXX
-                    if ( $this->inParagraph ) {
-                        $this->calls[] = array('p_close',array(), $call[2]);
-                    }
-                    $this->calls[] = array('p_open',array(), $call[2]);
-                    $this->inParagraph = TRUE;
-                    */
-
-                    # Check this isn't an eol instruction to skip...
+                    // Check this isn't an eol instruction to skip...
                     if ( $this->skipEolKey != $key ) {
-                         # Look to see if the next instruction is an EOL
+                        // Look to see if the next instruction is an EOL
                         if ( isset($calls[$key+1]) && $calls[$key+1][0] == 'eol' ) {
 
                             if ( $this->inParagraph ) {
@@ -1385,7 +1543,7 @@ class Doku_Handler_Block {
                             $this->inParagraph = TRUE;
 
 
-                            # Mark the next instruction for skipping
+                            // Mark the next instruction for skipping
                             $this->skipEolKey = $key+1;
 
                         }else{
@@ -1398,19 +1556,15 @@ class Doku_Handler_Block {
                 } else {
 
                     $storeCall = TRUE;
-                    if ( $this->inParagraph && in_array($cname, $this->blockOpen) ) {
-                        //$this->calls[] = array('p_close',array(), $call[2]);
+                    if ( $this->inParagraph && (in_array($cname, $this->blockOpen) && (!$plugin || $plugin_open))) {
                         $this->closeParagraph($call[2]);
-                        $this->inParagraph = FALSE;
                         $this->calls[] = $call;
                         $storeCall = FALSE;
                     }
 
-                    if ( in_array($cname, $this->blockClose) ) {
+                    if ( in_array($cname, $this->blockClose) && (!$plugin || $plugin_close)) {
                         if ( $this->inParagraph ) {
-                            //$this->calls[] = array('p_close',array(), $call[2]);
                             $this->closeParagraph($call[2]);
-                            $this->inParagraph = FALSE;
                         }
                         if ( $storeCall ) {
                             $this->calls[] = $call;
@@ -1418,15 +1572,24 @@ class Doku_Handler_Block {
                         }
 
                         // This really sucks and suggests this whole class sucks but...
-                        if ( isset($calls[$key+1])
-                            &&
-                            !in_array($calls[$key+1][0], $this->blockOpen)
-                            &&
-                            !in_array($calls[$key+1][0], $this->blockClose)
-                            ) {
+                        if ( isset($calls[$key+1])) {
+                            $cname_plusone = $calls[$key+1][0];
+                            if ($cname_plusone == 'plugin') {
+                                $cname_plusone = 'plugin'.$calls[$key+1][1][0];
+                                
+                                // plugin test, true if plugin has a state which precludes it requiring blockOpen or blockClose
+                                $plugin_plusone = true;
+                                $plugin_test = ($call[$key+1][1][2] == DOKU_LEXER_MATCHED) || ($call[$key+1][1][2] == DOKU_LEXER_MATCHED);
+                            } else {
+                                $plugin_plusone = false;
+                            }
+                            if ((!in_array($cname_plusone, $this->blockOpen) && !in_array($cname_plusone, $this->blockClose)) ||
+                                ($plugin_plusone && $plugin_test)
+                                ) {
 
-                            $this->calls[] = array('p_open',array(), $call[2]);
-                            $this->inParagraph = TRUE;
+                                $this->calls[] = array('p_open',array(), $call[2]);
+                                $this->inParagraph = TRUE;
+                            }
                         }
                     }
 
