@@ -52,9 +52,6 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
     }
 
     function document_end() {
-        // add button for last section if any and more than one
-        if($this->lastsec > 1) $this->_secedit($this->lastsec,'');
-
         if ( count ($this->footnotes) > 0 ) {
             $this->doc .= '<div class="footnotes">'.DOKU_LF;
 
@@ -93,6 +90,9 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
         if($this->info['toc']){
             $this->doc = $this->render_TOC().$this->doc;
         }
+
+        // make sure there are no empty paragraphs
+        $this->doc = preg_replace('#<p>\s*</p>#','',$this->doc);
     }
 
     /**
@@ -123,13 +123,6 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
 
     function header($text, $level, $pos) {
         global $conf;
-        //handle section editing
-        if($level <= $conf['maxseclevel']){
-            // add button for last section if any
-            if($this->lastsec) $this->_secedit($this->lastsec,$pos-1);
-            // remember current position
-            $this->lastsec = $pos;
-        }
 
         // create a unique header id
         $hid = $this->_headerToLink($text,'true');
@@ -140,7 +133,7 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
             $this->toc[] = array( 'hid'   => $hid,
                                   'title' => $text,
                                   'type'  => 'ul',
-                                  'level' => $level);
+                                  'level' => $level-$conf['toptoclevel']+1);
         }
 
         // write the header
@@ -149,6 +142,22 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
         $this->doc .= "</a></h$level>".DOKU_LF;
     }
 
+     /**
+     * Section edit marker is replaced by an edit button when
+     * the page is editable. Replacement done in 'inc/html.php#html_secedit'
+     *
+     * @author Andreas Gohr <andi@splitbrain.org>
+     * @author Ben Coburn   <btcoburn@silicodon.net>
+     */
+    function section_edit($start, $end, $level, $name) {
+        global $conf;
+
+        if ($start!=-1 && $level<=$conf['maxseclevel']) {
+            $name = str_replace('"', '', $name);
+            $this->doc .= '<!-- SECTION "'.$name.'" ['.$start.'-'.(($end===0)?'':$end).'] -->';
+        }
+    }
+
     function section_open($level) {
         $this->doc .= "<div class=\"level$level\">".DOKU_LF;
     }
@@ -378,19 +387,10 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
         if ( is_null($language) ) {
             $this->preformatted($text);
         } else {
-            //strip leading blank line
+            //strip leading and trailing blank line
             $text = preg_replace('/^\s*?\n/','',$text);
-            // Handle with Geshi here
-            require_once(DOKU_INC . 'inc/geshi.php');
-            $geshi = new GeSHi($text, strtolower($language), DOKU_INC . 'inc/geshi');
-            $geshi->set_encoding('utf-8');
-            $geshi->enable_classes();
-            $geshi->set_header_type(GESHI_HEADER_PRE);
-            $geshi->set_overall_class("code $language");
-            $geshi->set_link_target($conf['target']['extern']);
-
-            $text = $geshi->parse_code();
-            $this->doc .= $text;
+            $text = preg_replace('/\s*?\n$/','',$text);
+            $this->doc .= p_xhtml_cached_geshi($text, $language);
         }
     }
 
@@ -502,7 +502,7 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
         }
 
         //keep hash anchor
-        list($id,$hash) = split('#',$id,2);
+        list($id,$hash) = explode('#',$id,2);
 
         //prepare for formating
         $link['target'] = $conf['target']['wiki'];
@@ -559,6 +559,7 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
         $link['more']   = '';
         $link['class']  = $class;
         $link['url']    = $url;
+
         $link['name']   = $name;
         $link['title']  = $this->_xmlEntities($url);
         if($conf['relnofollow']) $link['more'] .= ' rel="nofollow"';
@@ -671,8 +672,7 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
         $link['style']  = '';
         $link['more']   = '';
 
-        //we just test for image here - we need to encode the title our self
-        $this->_getLinkTitle($name, $address, $isImage);
+        $name = $this->_getLinkTitle($name, $address, $isImage);
         if ( !$isImage ) {
             $link['class']='mail JSnocheck';
         } else {
@@ -682,11 +682,13 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
         $address = $this->_xmlEntities($address);
         $address = obfuscate($address);
         $title   = $address;
+
         if(empty($name)){
             $name = $address;
-        }else{
-            $name = $this->_xmlEntities($name);
         }
+#elseif($isImage{
+#            $name = $this->_xmlEntities($name);
+#        }
 
         if($conf['mailguard'] == 'visible') $address = rawurlencode($address);
 
@@ -711,6 +713,7 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
         $link['suf']    = '';
         $link['more']   = '';
         $link['target'] = $conf['target']['media'];
+        $noLink = false;
 
         $link['title']  = $this->_xmlEntities($src);
         list($ext,$mime) = mimetype($src);
@@ -750,7 +753,7 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
         $link['title']  = $this->_xmlEntities($src);
         $link['url']    = ml($src,array('cache'=>$cache));
         $link['name']   = $this->_media ($src, $title, $align, $width, $height, $cache);
-
+        $noLink = false;
 
         list($ext,$mime) = mimetype($src);
         if(substr($mime,0,5) == 'image'){
@@ -770,34 +773,71 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
     }
 
     /**
-     * Renders an RSS feed using Magpie
+     * Renders an RSS feed
      *
      * @author Andreas Gohr <andi@splitbrain.org>
      */
-    function rss ($url){
+    function rss ($url,$params){
         global $lang;
-        define('MAGPIE_CACHE_ON', false); //we do our own caching
-        define('MAGPIE_DIR', DOKU_INC.'inc/magpie/');
-        define('MAGPIE_OUTPUT_ENCODING','UTF-8'); //return all feeds as UTF-8
-        require_once(MAGPIE_DIR.'/rss_fetch.inc');
+        global $conf;
+
+        require_once(DOKU_INC.'inc/FeedParser.php');
+        $feed = new FeedParser();
+        $feed->feed_url($url);
 
         //disable warning while fetching
-        $elvl = error_reporting(E_ERROR);
-        $rss  = fetch_rss($url);
-        error_reporting($elvl);
+        if (!defined('DOKU_E_LEVEL')) { $elvl = error_reporting(E_ERROR); }
+        $rc = $feed->init();
+        if (!defined('DOKU_E_LEVEL')) { error_reporting($elvl); }
+
+        //decide on start and end
+        if($params['reverse']){
+            $mod = -1;
+            $start = $feed->get_item_quantity()-1;
+            $end   = $start - ($params['max']);
+            $end   = ($end < -1) ? -1 : $end;
+        }else{
+            $mod   = 1;
+            $start = 0;
+            $end   = $feed->get_item_quantity();
+            $end   = ($end > $params['max']) ? $params['max'] : $end;;
+        }
 
         $this->doc .= '<ul class="rss">';
-        if($rss){
-            foreach ($rss->items as $item ) {
-                $this->doc .= '<li>';
-                $this->externallink($item['link'],$item['title']);
-                $this->doc .= '</li>';
+        if($rc){
+            for ($x = $start; $x != $end; $x += $mod) {
+                $item = $feed->get_item($x);
+                $this->doc .= '<li><div class="li">';
+                $this->externallink($item->get_permalink(),
+                                    $item->get_title());
+                if($params['author']){
+                    $author = $item->get_author(0);
+                    if($author){
+                        $name = $author->get_name();
+                        if(!$name) $name = $author->get_email();
+                        if($name) $this->doc .= ' '.$lang['by'].' '.$name;
+                    }
+                }
+                if($params['date']){
+                    $this->doc .= ' ('.$item->get_date($conf['dformat']).')';
+                }
+                if($params['details']){
+                    $this->doc .= '<div class="detail">';
+                    if($htmlok){
+                        $this->doc .= $item->get_description();
+                    }else{
+                        $this->doc .= strip_tags($item->get_description());
+                    }
+                    $this->doc .= '</div>';
+                }
+
+                $this->doc .= '</div></li>';
             }
         }else{
-            $this->doc .= '<li>';
+            $this->doc .= '<li><div class="li">';
             $this->doc .= '<em>'.$lang['rssfailed'].'</em>';
             $this->externallink($url);
-            $this->doc .= '</li>';
+            $this->doc .= '</div></li>';
         }
         $this->doc .= '</ul>';
     }
@@ -808,7 +848,7 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
     }
 
     function table_close(){
-        $this->doc .= '</table>'.DOKU_LF.'<br />'.DOKU_LF;
+        $this->doc .= '</table>'.DOKU_LF;
     }
 
     function tablerow_open(){
@@ -876,11 +916,11 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
         $ret  = '';
         $ret .= $link['pre'];
         $ret .= '<a href="'.$link['url'].'"';
-        if($link['class'])  $ret .= ' class="'.$link['class'].'"';
-        if($link['target']) $ret .= ' target="'.$link['target'].'"';
-        if($link['title'])  $ret .= ' title="'.$link['title'].'"';
-        if($link['style'])  $ret .= ' style="'.$link['style'].'"';
-        if($link['more'])   $ret .= ' '.$link['more'];
+        if(!empty($link['class']))  $ret .= ' class="'.$link['class'].'"';
+        if(!empty($link['target'])) $ret .= ' target="'.$link['target'].'"';
+        if(!empty($link['title']))  $ret .= ' title="'.$link['title'].'"';
+        if(!empty($link['style']))  $ret .= ' style="'.$link['style'].'"';
+        if(!empty($link['more']))   $ret .= ' '.$link['more'];
         $ret .= '>';
         $ret .= $link['name'];
         $ret .= '</a>';
@@ -897,14 +937,21 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
     function _simpleTitle($name){
         global $conf;
 
+        //if there is a hash we use the ancor name only
+        list($name,$hash) = explode('#',$name,2);
+        if($hash) return $hash;
+
+        //trim colons of a namespace link
+        $name = rtrim($name,':');
+
         if($conf['useslash']){
             $nssep = '[:;/]';
         }else{
             $nssep = '[:;]';
         }
         $name = preg_replace('!.*'.$nssep.'!','',$name);
-        //if there is a hash we use the ancor name only
-        $name = preg_replace('!.*#!','',$name);
+
+        if(!$name) return $this->_simpleTitle($conf['start']);
         return $name;
     }
 
@@ -987,7 +1034,7 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
      * @author Andreas Gohr <andi@splitbrain.org>
      */
     function _headerToLink($title,$create=false) {
-        $title = str_replace(':','',cleanID($title,true)); //force ASCII
+        $title = str_replace(':','',cleanID($title));
         $title = ltrim($title,'0123456789._-');
         if(empty($title)) $title='section';
 
@@ -1004,18 +1051,6 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
         return $title;
     }
 
-    /**
-     * Adds code for section editing button
-     *
-     * This is just aplaceholder and gets replace by the button if
-     * section editing is allowed
-     *
-     * @author Andreas Gohr <andi@splitbrain.org>
-     */
-    function _secedit($f, $t){
-        $this->doc .= '<!-- SECTION ['.$f.'-'.$t.'] -->';
-    }
-
     /**
      * Construct a title and handle images in titles
      *
