@@ -15,6 +15,11 @@
  * This function recurses into a given base directory
  * and calls the supplied function for each file and directory
  *
+ * @param   array ref $data The results of the search are stored here
+ * @param   string    $base Where to start the search
+ * @param   callback  $func Callback (function name or arayy with object,method)
+ * @param   string    $dir  Current directory beyond $base
+ * @param   int       $lvl  Recursion Level
  * @author  Andreas Gohr <andi@splitbrain.org>
  */
 function search(&$data,$base,$func,$opts,$dir='',$lvl=1){
@@ -41,16 +46,40 @@ function search(&$data,$base,$func,$opts,$dir='',$lvl=1){
 
   //give directories to userfunction then recurse
   foreach($dirs as $dir){
-    if ($func($data,$base,$dir,'d',$lvl,$opts)){
+    if (search_callback($func,$data,$base,$dir,'d',$lvl,$opts)){
       search($data,$base,$func,$opts,$dir,$lvl+1);
     }
   }
   //now handle the files
   foreach($files as $file){
-    $func($data,$base,$file,'f',$lvl,$opts);
+    search_callback($func,$data,$base,$file,'f',$lvl,$opts);
   }
 }
 
+/**
+ * Used to run the a user callback
+ *
+ * Makes sure the $data array is passed by reference (unlike when using
+ * call_user_func())
+ *
+ * @todo If this can be generalized it may be useful elsewhere in the code
+ * @author Andreas Gohr <andi@splitbrain.org>
+ */
+function search_callback($func,&$data,$base,$file,$type,$lvl,$opts){
+  if(is_array($func)){
+    if(is_object($func[0])){
+      // instanciated object
+      return $func[0]->$func[1]($data,$base,$file,$type,$lvl,$opts);
+    }else{
+      // static call
+      $f = $func[0].'::'.$func[1];
+      return $f($data,$base,$file,$type,$lvl,$opts);
+    }
+  }
+  // simple function call
+  return $func($data,$base,$file,$type,$lvl,$opts);
+}
+
 /**
  * The following functions are userfunctions to use with the search
  * function above. This function is called for every found file or
@@ -120,7 +149,7 @@ function search_index(&$data,$base,$file,$type,$lvl,$opts){
   if($type == 'd' && !preg_match('#^'.$file.'(/|$)#','/'.$opts['ns'])){
     //add but don't recurse
     $return = false;
-  }elseif($type == 'f' && !preg_match('#\.txt$#',$file)){
+  }elseif($type == 'f' && ($opts['nofiles'] || !preg_match('#\.txt$#',$file))){
     //don't add
     return false;
   }
@@ -128,7 +157,7 @@ function search_index(&$data,$base,$file,$type,$lvl,$opts){
   $id = pathID($file);
 
   //check hidden
-  if($type=='f' && isHiddenPage($id)){
+  if(isHiddenPage($id)){
     return false;
   }
 
@@ -178,6 +207,7 @@ function search_media(&$data,$base,$file,$type,$lvl,$opts){
 
   $info['file'] = basename($file);
   $info['size'] = filesize($base.'/'.$file);
+  $info['writable'] = is_writable($base.'/'.$file);
   if(preg_match("/\.(jpe?g|gif|png)$/",$file)){
     $info['isimg'] = true;
     require_once(DOKU_INC.'inc/JpegMeta.php');
