@@ -9,31 +9,10 @@
   if(!defined('DOKU_INC')) define('DOKU_INC',realpath(dirname(__FILE__).'/../').'/');
   require_once(DOKU_CONF.'dokuwiki.php');
 
-/**
- * Wrapper around htmlspecialchars()
- *
- * @author Andreas Gohr <andi@splitbrain.org>
- * @see    htmlspecialchars()
- */
-function hsc($string){
-  return htmlspecialchars($string);
-}
-
-/**
- * print a newline terminated string
- *
- * You can give an indention as optional parameter
- *
- * @author Andreas Gohr <andi@splitbrain.org>
- */
-function ptln($string,$intend=0){
-  for($i=0; $i<$intend; $i++) print ' ';
-  print"$string\n";
-}
-
 /**
  * Returns the path to the given template, uses
- * default one if the custom version doesn't exist
+ * default one if the custom version doesn't exist.
+ * Also enables gzip compression if configured.
  *
  * @author Andreas Gohr <andi@splitbrain.org>
  */
@@ -53,12 +32,24 @@ function template($tpl){
  * (defined by the global $ACT var) by calling the appropriate
  * outputfunction(s) from html.php
  *
- * Everything that doesn't use the default template isn't
- * handled by this function. ACL stuff is not done either.
+ * Everything that doesn't use the main template file isn't
+ * handled by this function. ACL stuff is not done here either.
  *
  * @author Andreas Gohr <andi@splitbrain.org>
  */
-function tpl_content(){
+function tpl_content() {
+  global $ACT;
+
+  ob_start();
+
+  trigger_event('TPL_ACT_RENDER',$ACT,'tpl_content_core');
+
+  $html_output = ob_get_clean();
+
+  trigger_event('TPL_CONTENT_DISPLAY',$html_output,'ptln');
+}
+
+function tpl_content_core(){
   global $ACT;
   global $TEXT;
   global $PRE;
@@ -74,9 +65,15 @@ function tpl_content(){
       html_edit($TEXT);
       html_show($TEXT);
       break;
+    case 'recover':
+      html_edit($TEXT);
+      break;
     case 'edit':
       html_edit();
       break;
+    case 'draft':
+      html_draft();
+      break;
     case 'wordblock':
       html_edit($TEXT,'wordblock');
       break;
@@ -84,7 +81,8 @@ function tpl_content(){
       html_search();
       break;
     case 'revisions':
-      html_revisions();
+      $first = is_numeric($_REQUEST['first']) ? intval($_REQUEST['first']) : 0;
+      html_revisions($first);
       break;
     case 'diff':
       html_diff();
@@ -125,7 +123,11 @@ function tpl_content(){
       tpl_admin();
       break;
     default:
-            msg("Failed to handle command: ".hsc($ACT),-1);
+      $evt = new Doku_Event('TPL_ACT_UNKNOWN',$ACT);
+      if ($evt->advise_before())
+        msg("Failed to handle command: ".hsc($ACT),-1);
+      $evt->advise_after();
+      unset($evt);
   }
 }
 
@@ -137,7 +139,7 @@ function tpl_content(){
 function tpl_admin(){
 
     $plugin = NULL;
-    if ($_REQUEST['page']) {
+    if (!empty($_REQUEST['page'])) {
         $pluginlist = plugin_list('admin');
 
         if (in_array($_REQUEST['page'], $pluginlist)) {
@@ -158,64 +160,129 @@ function tpl_admin(){
  *
  * This has to go into the head section of your template.
  *
+ * @triggers TPL_METAHEADER_OUTPUT
  * @param  boolean $alt Should feeds and alternative format links be added?
  * @author Andreas Gohr <andi@splitbrain.org>
  */
 function tpl_metaheaders($alt=true){
   global $ID;
+  global $REV;
   global $INFO;
   global $ACT;
   global $lang;
   global $conf;
   $it=2;
 
+  // prepare the head array
+  $head = array();
+
+
   // the usual stuff
-  ptln('<meta name="generator" content="DokuWiki '.getVersion().'" />',$it);
-  ptln('<link rel="start" href="'.DOKU_BASE.'" />',$it);
-  ptln('<link rel="contents" href="'.wl($ID,'do=index').'" title="'.$lang['index'].'" />',$it);
+  $head['meta'][] = array( 'name'=>'generator', 'content'=>'DokuWiki '.getVersion() );
+  $head['link'][] = array( 'rel'=>'start', 'href'=>DOKU_BASE );
+  $head['link'][] = array( 'rel'=>'contents', 'href'=> wl($ID,'do=index',false,'&'),
+                           'title'=>$lang['btn_index'] );
 
   if($alt){
-    ptln('<link rel="alternate" type="application/rss+xml" title="Recent Changes" href="'.DOKU_BASE.'feed.php" />',$it);
-    ptln('<link rel="alternate" type="application/rss+xml" title="Current Namespace" href="'.DOKU_BASE.'feed.php?mode=list&amp;ns='.$INFO['namespace'].'" />',$it);
-    ptln('<link rel="alternate" type="text/html" title="Plain HTML" href="'.wl($ID,'do=export_xhtml').'" />',$it);
-    ptln('<link rel="alternate" type="text/plain" title="Wiki Markup" href="'.wl($ID, 'do=export_raw').'" />',$it);
+    $head['link'][] = array( 'rel'=>'alternate', 'type'=>'application/rss+xml',
+                             'title'=>'Recent Changes', 'href'=>DOKU_BASE.'feed.php');
+    $head['link'][] = array( 'rel'=>'alternate', 'type'=>'application/rss+xml',
+                             'title'=>'Current Namespace',
+                             'href'=>DOKU_BASE.'feed.php?mode=list&ns='.$INFO['namespace']);
+    $head['link'][] = array( 'rel'=>'alternate', 'type'=>'text/html', 'title'=>'Plain HTML',
+                             'href'=>exportlink($ID, 'xhtml', '', false, '&'));
+    $head['link'][] = array( 'rel'=>'alternate', 'type'=>'text/plain', 'title'=>'Wiki Markup',
+                             'href'=>exportlink($ID, 'raw', '', false, '&'));
   }
 
   // setup robot tags apropriate for different modes
   if( ($ACT=='show' || $ACT=='export_xhtml') && !$REV){
     if($INFO['exists']){
-      ptln('<meta name="date" content="'.date('Y-m-d\TH:i:sO',$INFO['lastmod']).'" />',$it);
       //delay indexing:
       if((time() - $INFO['lastmod']) >= $conf['indexdelay']){
-        ptln('<meta name="robots" content="index,follow" />',$it);
+        $head['meta'][] = array( 'name'=>'robots', 'content'=>'index,follow');
       }else{
-        ptln('<meta name="robots" content="noindex,nofollow" />',$it);
+        $head['meta'][] = array( 'name'=>'robots', 'content'=>'noindex,nofollow');
       }
     }else{
-      ptln('<meta name="robots" content="noindex,follow" />',$it);
+      $head['meta'][] = array( 'name'=>'robots', 'content'=>'noindex,follow');
     }
+  }elseif(defined('DOKU_MEDIADETAIL')){
+    $head['meta'][] = array( 'name'=>'robots', 'content'=>'index,follow');
   }else{
-    ptln('<meta name="robots" content="noindex,nofollow" />',$it);
+    $head['meta'][] = array( 'name'=>'robots', 'content'=>'noindex,nofollow');
+  }
+
+  // set metadata
+  if($ACT == 'show' || $ACT=='export_xhtml'){
+    // date of modification
+    if($REV){
+      $head['meta'][] = array( 'name'=>'date', 'content'=>date('Y-m-d\TH:i:sO',$REV));
+    }else{
+      $head['meta'][] = array( 'name'=>'date', 'content'=>date('Y-m-d\TH:i:sO',$INFO['lastmod']));
+    }
+
+    // keywords (explicit or implicit)
+    if(!empty($INFO['meta']['subject'])){
+      $head['meta'][] = array( 'name'=>'keywords', 'content'=>join(',',$INFO['meta']['subject']));
+    }else{
+      $head['meta'][] = array( 'name'=>'keywords', 'content'=>str_replace(':',',',$ID));
+    }
   }
 
   // load stylesheets
-  ptln('<link rel="stylesheet" media="screen" type="text/css" href="'.DOKU_BASE.'lib/exe/css.php" />',$it);
-  ptln('<link rel="stylesheet" media="print" type="text/css" href="'.DOKU_BASE.'lib/exe/css.php?print=1" />',$it);
+  $head['link'][] = array('rel'=>'stylesheet', 'media'=>'screen', 'type'=>'text/css',
+                          'href'=>DOKU_BASE.'lib/exe/css.php');
+  $head['link'][] = array('rel'=>'stylesheet', 'media'=>'print', 'type'=>'text/css',
+                          'href'=>DOKU_BASE.'lib/exe/css.php?print=1');
 
   // load javascript
-  $js_edit  = ($ACT=='edit' || $ACT=='preview') ? 1 : 0;
+  $js_edit  = ($ACT=='edit' || $ACT=='preview' || $ACT=='recover' || $ACT=='wordblock' ) ? 1 : 0;
   $js_write = ($INFO['writable']) ? 1 : 0;
-  if($js_edit && $js_write){
-    ptln('<script type="text/javascript" charset="utf-8">',$it);
-    ptln("NS='".$INFO['namespace']."';",$it+2);
+  if(defined('DOKU_MEDIAMANAGER')){
+    $js_edit  = 1;
+    $js_write = 0;
+  }
+  if(($js_edit && $js_write) || defined('DOKU_MEDIAMANAGER')){
+    $script = "NS='".$INFO['namespace']."';";
     if($conf['useacl'] && $_SERVER['REMOTE_USER']){
       require_once(DOKU_INC.'inc/toolbar.php');
-      ptln("SIG='".toolbar_signature()."';",$it+2);
+      $script .= "SIG='".toolbar_signature()."';";
+    }
+    $head['script'][] = array( 'type'=>'text/javascript', 'charset'=>'utf-8',
+                               '_data'=> $script);
+  }
+  $head['script'][] = array( 'type'=>'text/javascript', 'charset'=>'utf-8', '_data'=>'',
+                             'src'=>DOKU_BASE.'lib/exe/js.php?edit='.$js_edit.'&write='.$js_write);
+
+  // trigger event here
+  trigger_event('TPL_METAHEADER_OUTPUT',$head,'_tpl_metaheaders_action',true);
+}
+
+/**
+ * prints the array build by tpl_metaheaders
+ *
+ * $data is an array of different header tags. Each tag can have multiple
+ * instances. Attributes are given as key value pairs. Values will be HTML
+ * encoded automatically so they should be provided as is in the $data array.
+ *
+ * For tags having a body attribute specify the the body data in the special
+ * attribute '_data'. This field will NOT BE ESCAPED automatically.
+ *
+ * @author Andreas Gohr <andi@splitbrain.org>
+ */
+function _tpl_metaheaders_action($data){
+  foreach($data as $tag => $inst){
+    foreach($inst as $attr){
+      echo '<',$tag,' ',buildAttributes($attr);
+      if(isset($attr['_data'])){
+          echo '>',$attr['_data'],'</',$tag,'>';
+      }else{
+        echo '/>';
+      }
+      echo "\n";
     }
-    ptln('</script>',$it);
   }
-  ptln('<script type="text/javascript" charset="utf-8" src="'.
-       DOKU_BASE.'lib/exe/js.php?edit='.$js_edit.'&amp;write='.$js_write.'"></script>',$it);
 }
 
 /**
@@ -248,34 +315,19 @@ function tpl_pagelink($id,$name=NULL){
  * Tries to find out which page is parent.
  * returns false if none is available
  *
- * @author Matthias Grimm <matthiasgrimm@users.sourceforge.net>
+ * @author Andreas Gohr <andi@splitbrain.org>
  */
-function tpl_getparent($ID){
+function tpl_getparent($id){
   global $conf;
-
-  if ($ID != $conf['start']) {
-    $idparts = explode(':', $ID);
-    $pn = array_pop($idparts);    // get the page name
-
-    for ($n=0; $n < 2; $n++) {
-      if (count($idparts) == 0) {
-        $ID = $conf['start'];     // go to topmost page
-        break;
-      }else{
-        $ns = array_pop($idparts);     // get the last part of namespace
-        if ($pn != $ns) {                 // are we already home?
-          array_push($idparts, $ns, $ns); // no, then add a page with same name
-          $ID = implode (':', $idparts); // as the namespace and recombine $ID
-          break;
-        }
-      }
-    }
-
-    if (@file_exists(wikiFN($ID))) {
-      return $ID;
-    }
+  $parent = getNS($id).':';
+  resolve_pageid('',$parent,$exists);
+  if($parent == $id) {
+    $pos = strrpos (getNS($id),':');
+    $parent = substr($parent,0,$pos).':';
+    resolve_pageid('',$parent,$exists);
+    if($parent == $id) return false;
   }
-  return false;
+  return $parent;
 }
 
 /**
@@ -283,10 +335,11 @@ function tpl_getparent($ID){
  *
  * Available Buttons are
  *
- *  edit        - edit/create/show button
+ *  edit        - edit/create/show/draft button
  *  history     - old revisions
  *  recent      - recent changes
  *  login       - login/logout button - if ACL enabled
+ *  profile     - user profile button (if logged in)
  *  index       - The index
  *  admin       - admin page - if enough rights
  *  top         - a back to top button
@@ -294,6 +347,7 @@ function tpl_getparent($ID){
  *  backtomedia - returns to the mediafile upload dialog
  *                after references have been displayed
  *  backlink    - links to the list of backlinks
+ *  subscription- subscribe/unsubscribe button
  *
  * @author Andreas Gohr <andi@splitbrain.org>
  * @author Matthias Grimm <matthiasgrimm@users.sourceforge.net>
@@ -301,14 +355,38 @@ function tpl_getparent($ID){
 function tpl_button($type){
   global $ACT;
   global $ID;
+  global $REV;
   global $NS;
   global $INFO;
   global $conf;
   global $auth;
 
+  // check disabled actions and fix the badly named ones
+  $ctype = $type;
+  if($type == 'history') $ctype='revisions';
+  if(!actionOK($ctype)) return;
+
   switch($type){
     case 'edit':
-      print html_editbutton();
+      #most complicated type - we need to decide on current action
+      if($ACT == 'show' || $ACT == 'search'){
+        if($INFO['writable']){
+          if(!empty($INFO['draft'])){
+            echo html_btn('draft',$ID,'e',array('do' => 'draft'),'post');
+          }else{
+            if($INFO['exists']){
+              echo html_btn('edit',$ID,'e',array('do' => 'edit','rev' => $REV),'post');
+            }else{
+              echo html_btn('create',$ID,'e',array('do' => 'edit','rev' => $REV),'post');
+            }
+          }
+        }else{
+          if(!actionOK('source')) return false; //pseudo action
+          echo html_btn('source',$ID,'v',array('do' => 'edit','rev' => $REV),'post');
+        }
+      }else{
+          echo html_btn('show',$ID,'v',array('do' => 'show'));
+      }
       break;
     case 'history':
       print html_btn('revs',$ID,'o',array('do' => 'revisions'));
@@ -373,15 +451,17 @@ function tpl_button($type){
  *
  * Available links are
  *
- *  edit    - edit/create/show button
+ *  edit    - edit/create/show link
  *  history - old revisions
  *  recent  - recent changes
- *  login   - login/logout button - if ACL enabled
+ *  login   - login/logout link - if ACL enabled
+ *  profile - user profile link (if logged in)
  *  index   - The index
  *  admin   - admin page - if enough rights
- *  top     - a back to top button
- *  back    - a back to parent button - if available
- * backlink - links to the list of backlinks
+ *  top     - a back to top link
+ *  back    - a back to parent link - if available
+ *  backlink - links to the list of backlinks
+ *  subscribe/subscription - subscribe/unsubscribe link
  *
  * @author Andreas Gohr <andi@splitbrain.org>
  * @author Matthias Grimm <matthiasgrimm@users.sourceforge.net>
@@ -396,21 +476,33 @@ function tpl_actionlink($type,$pre='',$suf=''){
   global $lang;
   global $auth;
 
+  // check disabled actions and fix the badly named ones
+  $ctype = $type;
+  if($type == 'history') $ctype='revisions';
+  if(!actionOK($ctype)) return;
+
   switch($type){
     case 'edit':
       #most complicated type - we need to decide on current action
       if($ACT == 'show' || $ACT == 'search'){
         if($INFO['writable']){
-          if($INFO['exists']){
-            tpl_link(wl($ID,'do=edit&amp;rev='.$REV),
-                     $pre.$lang['btn_edit'].$suf,
-                     'class="action edit" accesskey="e" rel="nofollow"');
-          }else{
-            tpl_link(wl($ID,'do=edit&amp;rev='.$REV),
-                     $pre.$lang['btn_create'].$suf,
-                     'class="action create" accesskey="e" rel="nofollow"');
+          if(!empty($INFO['draft'])) {
+            tpl_link(wl($ID,'do=draft'),
+                       $pre.$lang['btn_draft'].$suf,
+                       'class="action edit" acceskey="e" rel="nofollow"');
+          } else {
+            if($INFO['exists']){
+              tpl_link(wl($ID,'do=edit&amp;rev='.$REV),
+                       $pre.$lang['btn_edit'].$suf,
+                       'class="action edit" accesskey="e" rel="nofollow"');
+            }else{
+              tpl_link(wl($ID,'do=edit&amp;rev='.$REV),
+                       $pre.$lang['btn_create'].$suf,
+                       'class="action create" accesskey="e" rel="nofollow"');
+            }
           }
         }else{
+          if(!actionOK('source')) return false; //pseudo action
           tpl_link(wl($ID,'do=edit&amp;rev='.$REV),
                    $pre.$lang['btn_source'].$suf,
                    'class="action source" accesskey="v" rel="nofollow"');
@@ -420,24 +512,25 @@ function tpl_actionlink($type,$pre='',$suf=''){
                    $pre.$lang['btn_show'].$suf,
                    'class="action show" accesskey="v" rel="nofollow"');
       }
-      break;
+      return true;
     case 'history':
       tpl_link(wl($ID,'do=revisions'),$pre.$lang['btn_revs'].$suf,'class="action revisions" accesskey="o"');
-      break;
+      return true;
     case 'recent':
       tpl_link(wl($ID,'do=recent'),$pre.$lang['btn_recent'].$suf,'class="action recent" accesskey="r"');
-      break;
+      return true;
     case 'index':
       tpl_link(wl($ID,'do=index'),$pre.$lang['btn_index'].$suf,'class="action index" accesskey="x"');
-      break;
+      return true;
     case 'top':
       print '<a href="#dokuwiki__top" class="action top" accesskey="x">'.$pre.$lang['btn_top'].$suf.'</a>';
-      break;
+      return true;
     case 'back':
-      if ($ID = tpl_getparent($ID)) {
-        tpl_link(wl($ID,'do=show'),$pre.$lang['btn_back'].$suf,'class="action back" accesskey="b"');
+      if ($parent = tpl_getparent($ID)) {
+        tpl_link(wl($parent,'do=show'),$pre.$lang['btn_back'].$suf,'class="action back" accesskey="b"');
+        return true;
       }
-      break;
+      return false;
     case 'login':
       if($conf['useacl']){
         if($_SERVER['REMOTE_USER']){
@@ -445,12 +538,15 @@ function tpl_actionlink($type,$pre='',$suf=''){
         }else{
           tpl_link(wl($ID,'do=login'),$pre.$lang['btn_login'].$suf,'class="action logout"');
         }
+        return true;
       }
-      break;
+      return false;
     case 'admin':
-      if($INFO['perm'] == AUTH_ADMIN)
+      if($INFO['perm'] == AUTH_ADMIN){
         tpl_link(wl($ID,'do=admin'),$pre.$lang['btn_admin'].$suf,'class="action admin"');
-      break;
+        return true;
+      }
+      return false;
    case 'subscribe':
    case 'subscription':
       if($conf['useacl'] && $ACT == 'show' && $conf['subscribers'] == 1){
@@ -460,20 +556,23 @@ function tpl_actionlink($type,$pre='',$suf=''){
           } else {
             tpl_link(wl($ID,'do=subscribe'),$pre.$lang['btn_subscribe'].$suf,'class="action subscribe"');
           }
+          return true;
         }
       }
-      break;
+      return false;
     case 'backlink':
       tpl_link(wl($ID,'do=backlink'),$pre.$lang['btn_backlink'].$suf, 'class="action backlink"');
-      break;
+      return true;
     case 'profile':
       if($conf['useacl'] && $_SERVER['REMOTE_USER'] &&
          $auth->canDo('Profile') && ($ACT!='profile')){
         tpl_link(wl($ID,'do=profile'),$pre.$lang['btn_profile'].$suf, 'class="action profile"');
+        return true;
       }
-      break;
+      return false;
     default:
       print '[unknown link type]';
+      return true;
   }
 }
 
@@ -493,13 +592,16 @@ function tpl_searchform($ajax=true,$autocomplete=true){
   global $lang;
   global $ACT;
 
+  // don't print the search form if search action has been disabled
+  if (!actionOk('search')) return;
+
   print '<form action="'.wl().'" accept-charset="utf-8" class="search" id="dw__search"><div class="no">';
   print '<input type="hidden" name="do" value="search" />';
   print '<input type="text" ';
   if($ACT == 'search') print 'value="'.htmlspecialchars($_REQUEST['id']).'" ';
   if(!$autocomplete) print 'autocomplete="off" ';
-  print 'id="qsearch__in" accesskey="f" name="id" class="edit" />';
-  print '<input type="submit" value="'.$lang['btn_search'].'" class="button" />';
+  print 'id="qsearch__in" accesskey="f" name="id" class="edit" title="[ALT+F]" />';
+  print '<input type="submit" value="'.$lang['btn_search'].'" class="button" title="'.$lang['btn_search'].'" />';
   if($ajax) print '<div id="qsearch__out" class="ajax_qsearch JSpopup"></div>';
   print '</div></form>';
 }
@@ -546,52 +648,54 @@ function tpl_breadcrumbs(){
  * @link   http://wiki.splitbrain.org/wiki:tipsandtricks:hierarchicalbreadcrumbs
  * @todo   May behave strangely in RTL languages
  */
-function tpl_youarehere(){
+function tpl_youarehere($sep=' &raquo; '){
   global $conf;
   global $ID;
   global $lang;
 
-  //check if enabled
+  // check if enabled
   if(!$conf['youarehere']) return;
 
-  $parts     = explode(':', $ID);
+  $parts = explode(':', $ID);
+  $count = count($parts);
 
-  print $lang['youarehere'].': ';
+  echo $lang['youarehere'].': ';
 
-  //always print the startpage
-  if( $a_part[0] != $conf['start']){
-    if($conf['useheading']){
-      $pageName = p_get_first_heading($conf['start']);
+  // always print the startpage
+  $title = p_get_first_heading($conf['start']);
+  if(!$title) $title = $conf['start'];
+  tpl_link(wl($conf['start']),$title,'title="'.$conf['start'].'"');
+
+  // print intermediate namespace links
+  $part = '';
+  for($i=0; $i<$count - 1; $i++){
+    $part .= $parts[$i].':';
+    $page = $part;
+    resolve_pageid('',$page,$exists);
+    if ($page == $conf['start']) continue; // Skip startpage 
+
+    // output
+    echo $sep;
+    if($exists){
+      $title = p_get_first_heading($page);
+      if(!$title) $title = $parts[$i];
+      tpl_link(wl($page),$title,'title="'.$page.'"');
     }else{
-      $pageName = $conf['start'];
+      tpl_link(wl($page),$parts[$i],'title="'.$page.'" class="wikilink2"');
     }
-    tpl_link(wl($conf['start']),$pageName,'title="'.$pageName.'"');
   }
 
-  $page = '';
-  foreach ($parts as $part){
-        // Skip startpage if already done
-        if ($part == $conf['start']) continue;
-
-          print ' &raquo; ';
-    $page .= $part;
-
-    if(file_exists(wikiFN($page))){
-      if($conf['useheading']){
-        $pageName = p_get_first_heading($page);
-        $partName = $pageName;
-      }else{
-        $pageName = $page;
-        $partName = $part;
-      }
-      tpl_link(wl($page),$partName,'title="'.$pageName.'"');
-    }else{
-      // Print the link, but mark as not-existing, as for other non-existing links
-      tpl_link(wl($page),$part,'title="'.$page.'" class="wikilink2"');
-      //print $page;
-    }
-
-    $page .= ':';
+  // print current page, skipping start page, skipping for namespace index
+  if(isset($page) && $page==$part.$parts[$i]) return;
+  $page = $part.$parts[$i];
+  if($page == $conf['start']) return;
+  echo $sep;
+  if(@file_exists(wikiFN($page))){
+    $title = p_get_first_heading($page);
+    if(!$title) $title = $parts[$i];
+    tpl_link(wl($page),$title,'title="'.$page.'"');
+  }else{
+    tpl_link(wl($page),$parts[$i],'title="'.$page.'" class="wikilink2"');
   }
 }
 
@@ -654,189 +758,14 @@ function tpl_pageinfo(){
 }
 
 /**
- * Print a list of namespaces containing media files
- *
- * @author Andreas Gohr <andi@splitbrain.org>
- */
-function tpl_medianamespaces(){
-    global $conf;
-
-  $data = array();
-  search($data,$conf['mediadir'],'search_namespaces',array());
-  print html_buildlist($data,'idx',media_html_list_namespaces);
-}
-
-/**
- * Print a list of mediafiles in the current namespace
- *
- * @author Andreas Gohr <andi@splitbrain.org>
- */
-function tpl_mediafilelist(){
-  global $conf;
-  global $lang;
-  global $NS;
-  global $AUTH;
-  $dir = utf8_encodeFN(str_replace(':','/',$NS));
-
-  $data = array();
-  search($data,$conf['mediadir'],'search_media',array(),$dir);
-
-  if(!count($data)){
-    ptln('<div class="nothing">'.$lang['nothingfound'].'</div>');
-    return;
-  }
-
-  ptln('<ul>',2);
-  foreach($data as $item){
-    if(!$item['isimg']){
-      // add file icons
-      list($ext,$mime) = mimetype($item['file']);
-      $class = preg_replace('/[^_\-a-z0-9]+/i','_',$ext);
-      $class = ' class="mediafile mf_'.$class.'"';
-    }
-
-    ptln('<li><div class="li">',4);
-    ptln('<a href="javascript:mediaSelect(\':'.$item['id'].'\')"'.$class.'>'.
-         utf8_decodeFN($item['file']).
-         '</a>',6);
-
-    //prepare deletion button
-    if($AUTH >= AUTH_DELETE){
-      $ask  = addslashes($lang['del_confirm']).'\\n';
-      $ask .= addslashes($item['id']);
-
-      $del = '<a href="'.DOKU_BASE.'lib/exe/media.php?delete='.rawurlencode($item['id']).'" '.
-             'onclick="return confirm(\''.$ask.'\')" onkeypress="return confirm(\''.$ask.'\')">'.
-             '<img src="'.DOKU_BASE.'lib/images/del.png" alt="'.$lang['btn_delete'].'" '.
-             'title="'.$lang['btn_delete'].'" /></a>';
-    }else{
-      $del = '';
-    }
-
-    if($item['isimg']){
-      $w = (int) $item['meta']->getField('File.Width');
-      $h = (int) $item['meta']->getField('File.Height');
-
-      ptln('('.$w.'&#215;'.$h.' '.filesize_h($item['size']).')',6);
-      ptln($del.'<br />',6);
-      ptln('<div class="imagemeta">',6);
-
-      //build thumbnail
-      print '<a href="javascript:mediaSelect(\':'.$item['id'].'\')">';
-
-      if($w>120 || $h>120){
-        $ratio = $item['meta']->getResizeRatio(120);
-        $w = floor($w * $ratio);
-        $h = floor($h * $ratio);
-      }
-
-      $src = ml($item['id'],array('w'=>$w,'h'=>$h));
-
-      $p = array();
-      $p['width']  = $w;
-      $p['height'] = $h;
-      $p['alt']    = $item['id'];
-      $p['class']  = 'thumb';
-      $att = buildAttributes($p);
-
-      print '<img src="'.$src.'" '.$att.' />';
-      print '</a>';
-
-      //read EXIF/IPTC data
-      $t = $item['meta']->getField('IPTC.Headline');
-      if($t) print '<strong>'.htmlspecialchars($t).'</strong><br />';
-
-      $t = $item['meta']->getField(array('IPTC.Caption','EXIF.UserComment',
-                                         'EXIF.TIFFImageDescription',
-                                         'EXIF.TIFFUserComment'));
-      if($t) print htmlspecialchars($t).'<br />';
-
-      $t = $item['meta']->getField(array('IPTC.Keywords','IPTC.Category'));
-      if($t) print '<em>'.htmlspecialchars($t).'</em><br />';
-
-      //add edit button
-      if($AUTH >= AUTH_UPLOAD && $item['meta']->getField('File.Mime') == 'image/jpeg'){
-        print '<a href="'.DOKU_BASE.'lib/exe/media.php?edit='.rawurlencode($item['id']).'">';
-        print '<img src="'.DOKU_BASE.'lib/images/edit.gif" alt="'.$lang['metaedit'].'" title="'.$lang['metaedit'].'" />';
-        print '</a>';
-      }
-
-      ptln('</div>',6);
-    }else{
-      ptln ('('.filesize_h($item['size']).')',6);
-      ptln($del,6);
-    }
-    ptln('</div></li>',4);
-  }
-  ptln('</ul>',2);
-}
-
-/**
- * show references to a media file
- * References uses the same visual as search results and share
- * their CSS tags except pagenames won't be links.
- *
- * @author Matthias Grimm <matthiasgrimm@users.sourceforge.net>
- */
-function tpl_showreferences(&$data){
-  global $lang;
-
-  $hidden=0; //count of hits without read permission
-
-  if(count($data)){
-    usort($data,'sort_search_fulltext');
-    foreach($data as $row){
-      if(auth_quickaclcheck($row['id']) >= AUTH_READ){
-        print '<div class="search_result">';
-        print '<span class="mediaref_ref">'.$row['id'].'</span>';
-        print ': <span class="search_cnt">'.$row['count'].' '.$lang['hits'].'</span><br />';
-        print '<div class="search_snippet">'.$row['snippet'].'</div>';
-        print '</div>';
-      }else
-        $hidden++;
-    }
-    if ($hidden){
-      print '<div class="mediaref_hidden">'.$lang['ref_hidden'].'</div>';
-    }
-  }
-}
-
-/**
- * Print the media upload form if permissions are correct
- *
- * @author Andreas Gohr <andi@splitbrain.org>
- */
-function tpl_mediauploadform(){
-  global $NS;
-  global $UPLOADOK;
-  global $AUTH;
-  global $lang;
-
-  if(!$UPLOADOK) return;
-
-  ptln('<form action="'.DOKU_BASE.'lib/exe/media.php" id="dw__upload"'.
-       ' method="post" enctype="multipart/form-data">',2);
-  ptln($lang['txt_upload'].':<br />',4);
-  ptln('<input type="file" name="upload" class="edit" onchange="suggestWikiname();" />',4);
-  ptln('<input type="hidden" name="ns" value="'.hsc($NS).'" /><br />',4);
-  ptln($lang['txt_filename'].'<br />',4);
-  ptln('<input type="text" name="id" class="edit" />',4);
-  ptln('<input type="submit" class="button" value="'.$lang['btn_upload'].'" accesskey="s" />',4);
-  if($AUTH >= AUTH_DELETE){
-    ptln('<label for="dw__ow"><input type="checkbox" name="ow" value="1" id="dw__ow" />'.$lang['txt_overwrt'].'</label>',4);
-  }
-  ptln('</form>',2);
-}
-
-/**
- * Prints the name of the given page (current one if none given).
+ * Prints or returns the name of the given page (current one if none given).
  *
  * If useheading is enabled this will use the first headline else
- * the given ID is printed.
+ * the given ID is used.
  *
  * @author Andreas Gohr <andi@splitbrain.org>
  */
-function tpl_pagetitle($id=null){
+function tpl_pagetitle($id=null, $ret=false){
   global $conf;
   if(is_null($id)){
     global $ID;
@@ -848,7 +777,12 @@ function tpl_pagetitle($id=null){
     $title = p_get_first_heading($id);
     if ($title) $name = $title;
   }
-  print hsc($name);
+
+  if ($ret) {
+      return hsc($name);
+  } else {
+      print hsc($name);
+  }
 }
 
 /**
@@ -861,15 +795,18 @@ function tpl_pagetitle($id=null){
  * and _iptcTagNames() in inc/jpeg.php (You need to prepend IPTC
  * to the names of the latter one)
  *
- * Only allowed in: detail.php, mediaedit.php
+ * Only allowed in: detail.php
  *
  * @author Andreas Gohr <andi@splitbrain.org>
  */
-function tpl_img_getTag($tags,$alt=''){
+function tpl_img_getTag($tags,$alt='',$src=null){
   // Init Exif Reader
   global $SRC;
+
+  if(is_null($src)) $src = $SRC;
+
   static $meta = null;
-  if(is_null($meta)) $meta = new JpegMeta($SRC);
+  if(is_null($meta)) $meta = new JpegMeta($src);
   if($meta === false) return $alt;
   $info = $meta->getField($tags);
   if($info == false) return $alt;
@@ -953,4 +890,92 @@ function tpl_indexerWebBug(){
   print "<img $att />";
 }
 
+// configuration methods
+/**
+ * tpl_getConf($id)
+ *
+ * use this function to access template configuration variables
+ */
+function tpl_getConf($id){
+  global $conf;
+  global $tpl_configloaded;
+
+  $tpl = $conf['template'];
+
+  if (!$tpl_configloaded){
+    $tconf = tpl_loadConfig();
+    if ($tconf !== false){
+      foreach ($tconf as $key => $value){
+        if (isset($conf['tpl'][$tpl][$key])) continue;
+        $conf['tpl'][$tpl][$key] = $value;
+      }
+      $tpl_configloaded = true;
+    }
+  }
+
+  return $conf['tpl'][$tpl][$id];
+}
+
+/**
+ * tpl_loadConfig()
+ * reads all template configuration variables
+ * this function is automatically called by tpl_getConf()
+ */
+function tpl_loadConfig(){
+
+  $file = DOKU_TPLINC.'/conf/default.php';
+  $conf = array();
+
+  if (!@file_exists($file)) return false;
+
+  // load default config file
+  include($file);
+
+  return $conf;
+}
+
+/**
+ * prints the "main content" in the mediamanger popup
+ *
+ * Depending on the user's actions this may be a list of
+ * files in a namespace, the meta editing dialog or
+ * a message of referencing pages
+ *
+ * Only allowed in mediamanager.php
+ *
+ * @author Andreas Gohr <andi@splitbrain.org>
+ */
+function tpl_mediaContent(){
+  global $IMG;
+  global $AUTH;
+  global $INUSE;
+  global $NS;
+  global $JUMPTO;
+
+  ptln('<div id="media__content">');
+  if($_REQUEST['edit']){
+    media_metaform($IMG,$AUTH);
+  }elseif(is_array($INUSE)){
+    media_filesinuse($INUSE,$IMG);
+  }else{
+    media_filelist($NS,$AUTH,$JUMPTO);
+  }
+  ptln('</div>');
+}
+
+/**
+ * prints the namespace tree in the mediamanger popup
+ *
+ * Only allowed in mediamanager.php
+ *
+ * @author Andreas Gohr <andi@splitbrain.org>
+ */
+function tpl_mediaTree(){
+  global $NS;
+
+  ptln('<div id="media__tree">');
+  media_nstree($NS);
+  ptln('</div>');
+}
+
 //Setup VIM: ex: et ts=2 enc=utf-8 :
