@@ -51,6 +51,7 @@ require_once (DOKU_INC.'inc/init.php');
 session_write_close();
 require_once (DOKU_INC.'inc/utf8.php');
 require_once (DOKU_INC.'inc/aspell.php');
+require_once (DOKU_INC.'inc/common.php');
 
 header('Content-Type: text/plain; charset=utf-8');
 
@@ -79,10 +80,14 @@ if(function_exists($call)){
  * the result string and will be checked for
  * spelling errors again.
  *
+ * callback for preg_replace_callback
+ *
  * @author Matthias Grimm <matthiasgrimm@users.sourceforge.net>
  * @author Andreas Gohr <andi@splitbrain.org>
  */
-function spaceslink($string, $check=""){
+function spaceslink($matches){
+  $string  = unslash($matches[1]);
+  $check   = unslash($matches[2]);
   $result  = '  '; //opening [[
   $result .= str_pad('',utf8_strlen($string),' ');
   $result .= $check;
@@ -112,15 +117,16 @@ function spell_check() {
   $string = preg_replace("/(\015\012)|(\015)/","\012",$string);
   $string = htmlspecialchars($string);
 
-  // make sure multiple spaces are kept
+  // make sure multiple spaces and leading are kept
+  $string = preg_replace('/^ /m','&nbsp;',$string);
   $string = preg_replace('/  /','&nbsp; ',$string);
 
   // we need the text as array later
   $data = explode("\n",$string);
 
   // don't check links and medialinks for spelling errors
-  $string = preg_replace('/\{\{(.*?)(\|(.*?))?(\}\})/e','spaceslink("\\1","\\2")',$string);
-  $string = preg_replace('/\[\[(.*?)(\|(.*?))?(\]\])/e','spaceslink("\\1","\\2")',$string);
+  $string = preg_replace_callback('/\{\{(.*?)(\|(.*?))?(\}\})/','spaceslink',$string);
+  $string = preg_replace_callback('/\[\[(.*?)(\|(.*?))?(\]\])/','spaceslink',$string);
 
   // run aspell in terse sgml mode, ignore nbsp as correct word
   if(!$spell->runAspell($string,$out,$err,array('!','+html','@nbsp'))){
