@@ -13,6 +13,35 @@ $lang['nochoice']       = '(keine Auswahlmöglichkeiten vorhanden)';
 $lang['locked']         = 'Die Konfigurationsdatei kann nicht geändert werden, wenn dies unbeabsichtigt ist
                            <br />überprüfen Sie, dass die Dateiberechtigungen korrekt gesetzt sind.';
 
+/* --- Config Setting Headers --- */
+$lang['_configuration_manager'] = 'Konfiguration'; //same as heading in intro.txt
+$lang['_header_dokuwiki'] = 'DokuWiki-Konfiguration';
+$lang['_header_plugin'] = 'Plugin-Konfiguration';
+$lang['_header_template'] = 'Template-Konfiguration';
+$lang['_header_undefined'] = 'Unbekannte Einstellungen';
+
+/* --- Config Setting Groups --- */
+$lang['_basic'] = 'Grund-Konfiguration';
+$lang['_display'] = 'Anzeige-Konfiguration';
+$lang['_authentication'] = 'Authentifizierungs-Konfiguration';
+$lang['_anti_spam'] = 'Anti-Spam-Konfiguration';
+$lang['_editing'] = 'Bearbeitungs-Konfiguration';
+$lang['_links'] = 'Link-Konfiguration';
+$lang['_media'] = 'Medien-Konfiguration';
+$lang['_advanced'] = 'Erweiterte Konfiguration';
+$lang['_network'] = 'Netzwerk-Konfiguration';
+// The settings group name for plugins and templates can be set with
+// plugin_settings_name and template_settings_name respectively. If one
+// of these lang properties is not set, the group name will be generated
+// from the plugin or template name and the localized suffix.
+$lang['_plugin_sufix'] = 'Plugin Konfiguration';
+$lang['_template_sufix'] = 'Template Konfiguration';
+
+/* --- Undefined Setting Messages --- */
+$lang['_msg_setting_undefined'] = 'Keine Konfigurationsmetadaten.';
+$lang['_msg_setting_no_class'] = 'Keine Konfigurationsklasse.';
+$lang['_msg_setting_no_default'] = 'Kein Standardwert.';
+
 
 /* -------------------- Config Options --------------------------- */
 $lang['fmode']          = 'Rechte für neue Dateien';
@@ -55,19 +84,29 @@ $lang['passcrypt']      = 'Verschlüsselungsmechanismus';
 $lang['defaultgroup']   = 'Standardgruppe';
 $lang['superuser']      = 'Administrator';
 $lang['profileconfirm'] = 'Profiländerung nur nach Passwortbestätigung';
+$lang['disableactions'] = 'DokuWiki Aktionen bearbeiten';
+$lang['disableactions_check'] = 'Check';
+$lang['disableactions_subscription'] = 'Seiten-Abbonnements';
+$lang['disableactions_wikicode'] = 'Quelltext betrachten/exortieren';
+$lang['disableactions_other'] = 'Andere Aktionen (Kommagetrennt)';
+$lang['updatecheck']    = 'Automatisch nach Updaten und Sicherheitswarnungen suchen? DokuWiki muss sich dafür mit splitbrain.org verbinden.';
 $lang['userewrite']     = 'URL rewriting';
 $lang['useslash']       = 'Schrägstrich (/) als Namensraumtrenner in URLs verwenden';
+$lang['usedraft']       = 'Während des Bearbeitens automatisch Zwischenentwürfe speichern';
 $lang['sepchar']        = 'Worttrenner für Seitennamen in URLs';
 $lang['canonical']      = 'Immer Links mit vollständigen URLs erzeugen';
 $lang['autoplural']     = 'Bei Links automatisch nach vorhandenen Pluralformen suchen';
-$lang['usegzip']        = 'Alte Seitenversionen komprimieren';
+$lang['compression']    = 'Komprimierungsmethode für alte Seitenrevisionen';
 $lang['cachetime']      = 'Maximale Cachespeicherung (Sek.)';
-$lang['purgeonadd']     = 'Seitencache leeren wenn eine neue Seite angelegt wurde';
 $lang['locktime']       = 'Maximales Alter für Seitensperren (Sek.)';
+$lang['fetchsize']      = 'Maximale Größe (bytes) die fetch.php von extern downloaden darf';
 $lang['notify']         = 'Änderungsmitteilungen and diese E-Mail Adresse versenden';
+$lang['registernotify'] = 'Information über neu registrierte Nutzer an diese E-Mail Adresse senden';
 $lang['mailfrom']       = 'Absendermail für autotmatische Mails';
+$lang['gzip_output']    = 'Seiten mit gzip komprimiert ausliefern';
 $lang['gdlib']          = 'GDlib Version';
 $lang['im_convert']     = 'Pfad zu Image Magicks convert Tool';
+$lang['jpg_quality']    = 'JPEG Kompressionsqualität (0-100)';
 $lang['spellchecker']   = 'Rechtschreibprüfung aktivieren';
 $lang['subscribers']    = 'E-Mail Abos zulassen';
 $lang['compress']       = 'Javascript und Stylesheets komprimieren';
@@ -76,6 +115,8 @@ $lang['send404']        = 'Bei nicht vorhandenen Seiten mit 404 Fehlercode antwo
 $lang['sitemap']        = 'Google Sitemap erzeugen (Tage)';
 $lang['rss_type']       = 'XML-Feed Format';
 $lang['rss_linkto']     = 'XML-Feed verlinken auf';
+$lang['rss_update']     = 'XML-Feed Aktualisierungsinterval (sec)';
+$lang['recent_days']    = 'Wieviele letzte Änderungen sollen einsehbar bleiben? (Tage)';
 $lang['target____wiki']      = 'Zielfenster für interne Links (target Attribut)';
 $lang['target____interwiki'] = 'Zielfenster für InterWiki-Links (target Attribut)';
 $lang['target____extern']    = 'Zielfenster für Externe Links (target Attribut)';
@@ -110,4 +151,6 @@ $lang['rss_linkto_o_page']    = 'geänderte Seite';
 $lang['rss_linkto_o_rev']     = 'Liste aller Änderungen';
 $lang['rss_linkto_o_current'] = 'Aktuelle Seite';
 
-
+$lang['compression_o_0']   = 'keine';
+$lang['compression_o_gz']  = 'gzip';
+$lang['compression_o_bz2'] = 'bz2';
