@@ -1,8 +1,9 @@
 <?php
-/*
+/**
  *  Configuration Class and generic setting classes
  *
  *  @author  Chris Smith <chris@jalakai.co.uk>
+ *  @author  Ben Coburn <btcoburn@silicodon.net>
  */
 
 if (!class_exists('configuration')) {
@@ -26,6 +27,7 @@ if (!class_exists('configuration')) {
      *  constructor
      */
     function configuration($datafile) {
+        global $conf;
 
         if (!@file_exists($datafile)) {
           msg('No configuration metadata found at - '.htmlspecialchars($datafile),-1);
@@ -43,15 +45,17 @@ if (!class_exists('configuration')) {
 
         $this->locked = $this->_is_locked();
 
-        $this->_metadata = array_merge($meta, $this->get_plugin_metadata());
+        $this->_metadata = array_merge($meta, $this->get_plugintpl_metadata($conf['template']));
 
         $this->retrieve_settings();
     }
 
     function retrieve_settings() {
+        global $conf;
+        $no_default_check = array('setting_fieldset', 'setting_undefined', 'setting_no_class');
 
         if (!$this->_loaded) {
-          $default = array_merge($this->_read_config($this->_default_file), $this->get_plugin_default());
+          $default = array_merge($this->_read_config($this->_default_file), $this->get_plugintpl_default($conf['template']));
           $local = $this->_read_config($this->_local_file);
           $protected = $this->_read_config($this->_protected_file);
 
@@ -62,14 +66,21 @@ if (!class_exists('configuration')) {
             if (isset($this->_metadata[$key])) {
               $class = $this->_metadata[$key][0];
               $class = ($class && class_exists('setting_'.$class)) ? 'setting_'.$class : 'setting';
+              if ($class=='setting') {
+                $this->setting[] = new setting_no_class($key,$param);
+              }
 
               $param = $this->_metadata[$key];
               array_shift($param);
             } else {
-              $class = 'setting';
+              $class = 'setting_undefined';
               $param = NULL;
             }
 
+            if (!in_array($class, $no_default_check) && !isset($default[$key])) {
+              $this->setting[] = new setting_no_default($key,$param);
+            }
+
             $this->setting[$key] = new $class($key,$param);
             $this->setting[$key]->initialize($default[$key],$local[$key],$protected[$key]);
           }
@@ -87,11 +98,11 @@ if (!class_exists('configuration')) {
       // backup current file (remove any existing backup)
       if (@file_exists($file) && $backup) {
         if (@file_exists($file.'.bak')) @unlink($file.'.bak');
-        if (!@rename($file, $file.'.bak')) return false;
+        if (!io_rename($file, $file.'.bak')) return false;
       }
 
       if (!$fh = @fopen($file, 'wb')) {
-        @rename($file.'.bak', $file);     // problem opening, restore the backup
+        io_rename($file.'.bak', $file);     // problem opening, restore the backup
         return false;
       }
 
@@ -123,7 +134,7 @@ if (!class_exists('configuration')) {
       if ($this->_format == 'php') {
 
         $contents = @php_strip_whitespace($file);
-        $pattern = '/\$'.$this->_name.'\[[\'"]([^=]+)[\'"]\] ?= ?(.*?);/';
+        $pattern = '/\$'.$this->_name.'\[[\'"]([^=]+)[\'"]\] ?= ?(.*?);(?=[^;]*(?:\$'.$this->_name.'|@include|$))/';
         $matches=array();
         preg_match_all($pattern,$contents,$matches,PREG_SET_ORDER);
 
@@ -179,7 +190,7 @@ if (!class_exists('configuration')) {
       $local = eval('return '.$this->_local_file.';');
 
       if (!is_writable(dirname($local))) return true;
-      if (file_exists($local) && !is_writable($local)) return true;
+      if (@file_exists($local) && !is_writable($local)) return true;
 
       return false;
     }
@@ -206,11 +217,12 @@ if (!class_exists('configuration')) {
     }
 
     /**
-     * load metadata for plugin settings
+     * load metadata for plugin and template settings
      */
-    function get_plugin_metadata(){
-      $file = '/settings/config.metadata.php';
-      $meta = array();
+    function get_plugintpl_metadata($tpl){
+      $file     = '/conf/metadata.php';
+      $class    = '/conf/settings.class.php';
+      $metadata = array();
 
       if ($dh = opendir(DOKU_PLUGIN)) {
         while (false !== ($plugin = readdir($dh))) {
@@ -218,29 +230,67 @@ if (!class_exists('configuration')) {
           if (is_file(DOKU_PLUGIN.$plugin)) continue;
 
           if (@file_exists(DOKU_PLUGIN.$plugin.$file)){
+            $meta = array();
             @include(DOKU_PLUGIN.$plugin.$file);
+            @include(DOKU_PLUGIN.$plugin.$class);
+            if (!empty($meta)) {
+              $metadata['plugin'.CM_KEYMARKER.$plugin.CM_KEYMARKER.'plugin_settings_name'] = array('fieldset');
+            }
+            foreach ($meta as $key => $value){
+              if ($value[0]=='fieldset') { continue; } //plugins only get one fieldset
+              $metadata['plugin'.CM_KEYMARKER.$plugin.CM_KEYMARKER.$key] = $value;
+            }
           }
         }
         closedir($dh);
       }
-      return $meta;
+      
+      // the same for the active template
+      if (@file_exists(DOKU_TPLINC.$file)){
+        $meta = array();
+        @include(DOKU_TPLINC.$file);
+        @include(DOKU_TPLINC.$class);
+        if (!empty($meta)) {
+          $metadata['tpl'.CM_KEYMARKER.$tpl.CM_KEYMARKER.'template_settings_name'] = array('fieldset');
+        }
+        foreach ($meta as $key => $value){
+          if ($value[0]=='fieldset') { continue; } //template only gets one fieldset
+          $metadata['tpl'.CM_KEYMARKER.$tpl.CM_KEYMARKER.$key] = $value;
+        }
+      }
+      
+      return $metadata;
     }
 
     /**
-     * load default settings for plugins
+     * load default settings for plugins and templates
      */
-    function get_plugin_default(){
-      $file    = '/settings/config.default.php';
+    function get_plugintpl_default($tpl){
+      $file    = '/conf/default.php';
       $default = array();
 
       if ($dh = opendir(DOKU_PLUGIN)) {
         while (false !== ($plugin = readdir($dh))) {
           if (@file_exists(DOKU_PLUGIN.$plugin.$file)){
-            $default = array_merge($default, $this->_read_config("DOKU_PLUGIN.'".$plugin.$file."'"));
+            $conf = array();
+            @include(DOKU_PLUGIN.$plugin.$file);
+            foreach ($conf as $key => $value){
+              $default['plugin'.CM_KEYMARKER.$plugin.CM_KEYMARKER.$key] = $value;
+            }
           }
         }
         closedir($dh);
       }
+      
+      // the same for the active template
+      if (@file_exists(DOKU_TPLINC.$file)){
+        $conf = array();
+        @include(DOKU_TPLINC.$file);
+        foreach ($conf as $key => $value){
+          $default['tpl'.CM_KEYMARKER.$tpl.CM_KEYMARKER.$key] = $value;
+        }
+      }
+      
       return $default;
     }
 
@@ -270,7 +320,7 @@ if (!class_exists('setting')) {
     }
 
     /**
-     *  recieves current values for the setting $key
+     *  receives current values for the setting $key
      */
     function initialize($default, $local, $protected) {
         if (isset($default)) $this->_default = $default;
@@ -422,13 +472,17 @@ if (!class_exists('setting_password')) {
 
 if (!class_exists('setting_email')) {
   class setting_email extends setting_string {
-    var $_pattern = '#([a-z0-9\-_.]+?)@([\w\-]+\.([\w\-\.]+\.)*[\w]+)#i';
+    var $_pattern = '#^\s*(([a-z0-9\-_.]+?)@([\w\-]+\.([\w\-\.]+\.)*[\w]+)(,\s*([a-z0-9\-_.]+?)@([\w\-]+\.([\w\-\.]+\.)*[\w]+))*)?\s*$#i';
   }
 }
 
 if (!class_exists('setting_numeric')) {
   class setting_numeric extends setting_string {
-    var $_pattern = '/^[-+\/*0-9 ]*$/';
+    // This allows for many PHP syntax errors...
+    // var $_pattern = '/^[-+\/*0-9 ]*$/';
+    // much more restrictive, but should eliminate syntax errors.
+    var $_pattern = '/^[-]?[0-9]+(?:[-+*][0-9]+)*$/';
+    //FIXME - make the numeric error checking better.
 
     function out($var, $fmt='php') {
 
@@ -572,6 +626,182 @@ if (!class_exists('setting_dirchoice')) {
 }
 
 
+if (!class_exists('setting_hidden')) {
+  class setting_hidden extends setting {
+      // Used to explicitly ignore a setting in the configuration manager.
+  }
+}
+
+if (!class_exists('setting_fieldset')) {
+  class setting_fieldset extends setting {
+      // A do-nothing class used to detect the 'fieldset' type.
+      // Used to start a new settings "display-group".
+  }
+}
+
+if (!class_exists('setting_undefined')) {
+  class setting_undefined extends setting_hidden {
+      // A do-nothing class used to detect settings with no metadata entry.
+      // Used internaly to hide undefined settings, and generate the undefined settings list.
+  }
+}
+
+if (!class_exists('setting_no_class')) {
+  class setting_no_class extends setting_undefined {
+      // A do-nothing class used to detect settings with a missing setting class.
+      // Used internaly to hide undefined settings, and generate the undefined settings list.
+  }
+}
+
+if (!class_exists('setting_no_default')) {
+  class setting_no_default extends setting_undefined {
+      // A do-nothing class used to detect settings with no default value.
+      // Used internaly to hide undefined settings, and generate the undefined settings list.
+  }
+}
+
+if (!class_exists('setting_multicheckbox')) {
+  class setting_multicheckbox extends setting_string {
+
+    var $_choices = array();
+    var $_combine = array();
+
+    function update($input) {
+        if ($this->is_protected()) return false;
+
+        // split any combined values + convert from array to comma separated string
+        $input = ($input) ? $input : array();        
+        $input = $this->_array2str($input);
+
+        $value = is_null($this->_local) ? $this->_default : $this->_local;
+        if ($value == $input) return false;
+
+        if ($this->_pattern && !preg_match($this->_pattern,$input)) {
+          $this->_error = true;
+          $this->_input = $input;
+          return false;
+        }
+
+        $this->_local = $input;
+        return true;
+    }
+
+    function html(&$plugin, $echo=false) {
+
+        $value = '';
+        $disable = '';
+
+        if ($this->is_protected()) {
+          $value = $this->_protected;
+          $disable = 'disabled="disabled"';
+        } else {
+          if ($echo && $this->_error) {
+            $value = $this->_input;
+          } else {
+            $value = is_null($this->_local) ? $this->_default : $this->_local;
+          }
+        }
+
+        $key = htmlspecialchars($this->_key);
+
+        // convert from comma separated list into array + combine complimentary actions
+        $value = $this->_str2array($value);
+        $default = $this->_str2array($this->_default);
+
+        $input = '';
+        foreach ($this->_choices as $choice) {
+          $idx = array_search($choice, $value);
+          $idx_default = array_search($choice,$default);
+
+          $checked = ($idx !== false) ? 'checked="checked"' : '';
+
+          // ideally this would be handled using a second class of "default", however IE6 does not
+          // correctly support CSS selectors referencing multiple class names on the same element
+          // (e.g. .default.selection).
+          $class = (($idx !== false) == (false !== $idx_default)) ? " selectiondefault" : "";
+
+          $prompt = ($plugin->getLang($this->_key.'_'.$choice) ?
+                          $plugin->getLang($this->_key.'_'.$choice) : htmlspecialchars($choice));
+
+          $input .= '<div class="selection'.$class.'">'."\n";
+          $input .= '<label for="config__'.$key.'_'.$choice.'">'.$prompt."</label>\n";
+          $input .= '<input id="config__'.$key.'_'.$choice.'" name="config['.$key.'][]" type="checkbox" class="checkbox" value="'.$choice.'" '.$disable.' '.$checked."/>\n";
+          $input .= "</div>\n";
+
+          // remove this action from the disabledactions array
+          if ($idx !== false) unset($value[$idx]);
+          if ($idx_default !== false) unset($default[$idx_default]);
+        }
+
+        // handle any remaining values
+        $other = join(',',$value);
+
+        $class = (count($default == count($value)) && (count($value) == count(array_intersect($value,$default)))) ?
+                        " selectiondefault" : "";
+
+        $input .= '<div class="other'.$class.'">'."\n";
+        $input .= '<label for="config__'.$key.'_other">'.$plugin->getLang($key.'_other')."</label>\n";
+        $input .= '<input id="config__'.$key.'_other" name="config['.$key.'][other]" type="text" class="edit" value="'.htmlspecialchars($other).'" '.$disable." />\n";
+        $input .= "</div>\n";
+
+//        $label = '<label for="config__'.$key.'">'.$this->prompt($plugin).'</label>';
+        $label = $this->prompt($plugin);
+        return array($label,$input);
+    }
+
+    /**
+     * convert comma separated list to an array and combine any complimentary values
+     */
+    function _str2array($str) {
+      $array = explode(',',$str);
+
+      if (!empty($this->_combine)) {
+        foreach ($this->_combine as $key => $combinators) {
+          $idx = array();
+          foreach ($combinators as $val) {
+            if  (($idx[] = array_search($val, $array)) === false) break;
+          }
+
+          if (count($idx) && $idx[count($idx)-1] !== false) {
+            foreach ($idx as $i) unset($array[$i]);
+            $array[] = $key;
+          }
+        }
+      }
+
+      return $array;
+    }
+
+    /**
+     * convert array of values + other back to a comma separated list, incl. splitting any combined values
+     */
+    function _array2str($input) {
+
+      // handle other
+      $other = trim($input['other']);
+      $other = !empty($other) ? explode(',',str_replace(' ','',$input['other'])) : array();
+      unset($input['other']);
+
+      $array = array_unique(array_merge($input, $other));
+
+      // deconstruct any combinations
+      if (!empty($this->_combine)) {
+       foreach ($this->_combine as $key => $combinators) {
+
+          $idx = array_search($key,$array);
+          if ($idx !== false) {
+            unset($array[$idx]);
+            $array = array_merge($array, $combinators);
+          }
+        }
+      }
+
+      return join(',',array_unique($array));
+    }
+  }
+}
+
+
 /**
  *  Provide php_strip_whitespace (php5 function) functionality
  *
