@@ -10,7 +10,9 @@
  *  @author  neolao <neolao@neolao.com>
  *  @author  Chris Smith <chris@jalakai.co.uk>
  */
-if(!defined('DOKU_INC')) define('DOKU_INC',realpath(dirname(__FILE__).'/../../../').'/');
+// must be run within Dokuwiki
+if(!defined('DOKU_INC')) die();
+
 if(!defined('DOKU_PLUGIN')) define('DOKU_PLUGIN',DOKU_INC.'lib/plugins/');
 if(!defined('DOKU_PLUGIN_IMAGES')) define('DOKU_PLUGIN_IMAGES',DOKU_BASE.'lib/plugins/usermanager/images/');
 require_once(DOKU_PLUGIN.'admin.php');
@@ -27,7 +29,8 @@ class admin_plugin_usermanager extends DokuWiki_Admin_Plugin {
     var $_start = 0;          // index of first user to be displayed
     var $_last = 0;           // index of the last user to be displayed
     var $_pagesize = 20;      // number of users to list on one page
-    var $_user_edit = null;   // set to user selected for editing
+    var $_edit_user = '';     // set to user selected for editing
+    var $_edit_userdata = array();
     var $_disabled = '';      // if disabled set to explanatory string
 
     /**
@@ -41,13 +44,13 @@ class admin_plugin_usermanager extends DokuWiki_Admin_Plugin {
         if (!isset($auth)) { 
           $this->disabled = $this->lang['noauth'];
         } else if (!$auth->canDo('getUsers')) {
-          $this->disabled = $this->lang['notsupported'];
+          $this->disabled = $this->lang['nosupport'];
         } else {
 
           // we're good to go
           $this->_auth = & $auth;
                 
-                }
+        }
     }
 
     /**
@@ -72,7 +75,7 @@ class admin_plugin_usermanager extends DokuWiki_Admin_Plugin {
         if (!is_null($this->_auth)) 
           return parent::getMenuText($language);
 
-        return $this->getLang["menu"].' '.$this->disabled;
+        return $this->getLang('menu').' '.$this->disabled;
     }
 
     /**
@@ -112,7 +115,7 @@ class admin_plugin_usermanager extends DokuWiki_Admin_Plugin {
           case "add"    : $this->_addUser(); break;
           case "delete" : $this->_deleteUser(); break;
           case "modify" : $this->_modifyUser(); break;
-          case "edit"   : $this->_edit_user = $param; break;     // no extra handling required - only html
+          case "edit"   : $this->_editUser($param); break;
           case "search" : $this->_setFilter($param);
                           $this->_start = 0;
                           break;
@@ -227,7 +230,7 @@ class admin_plugin_usermanager extends DokuWiki_Admin_Plugin {
           print $this->locale_xhtml('add');
           ptln("  <div class=\"level2\">");
 
-          $this->_htmlUserForm('add',null,4);
+          $this->_htmlUserForm('add',null,array(),4);
 
           ptln("  </div>");
           ptln("</div>");
@@ -238,7 +241,7 @@ class admin_plugin_usermanager extends DokuWiki_Admin_Plugin {
           print $this->locale_xhtml('edit');
           ptln("  <div class=\"level2\">");
 
-          $this->_htmlUserForm('modify',$this->_edit_user,4);
+          $this->_htmlUserForm('modify',$this->_edit_user,$this->_edit_userdata,4);
 
           ptln("  </div>");
           ptln("</div>");
@@ -250,13 +253,18 @@ class admin_plugin_usermanager extends DokuWiki_Admin_Plugin {
     /**
      * @todo disable fields which the backend can't change
      */
-    function _htmlUserForm($cmd,$user=null,$indent=0) {
+    function _htmlUserForm($cmd,$user='',$userdata=array(),$indent=0) {
+        global $conf;
+        global $ID;
+
+        $name = $mail = $groups = '';
+        $notes = array();
 
         if ($user) {
-          extract($this->_auth->getUserData($user));
-          $groups = join(',',$grps);
+          extract($userdata);
+          if (!empty($grps)) $groups = join(',',$grps);
         } else {
-          $user = $name = $mail = $groups = '';
+          $notes[] = sprintf($this->lang['note_group'],$conf['defaultgroup']);
         }
 
         ptln("<form action=\"".wl($ID)."\" method=\"post\">",$indent);
@@ -272,6 +280,14 @@ class admin_plugin_usermanager extends DokuWiki_Admin_Plugin {
         $this->_htmlInputField($cmd."_usermail",  "usermail",  $this->lang["user_mail"],  $mail,  $this->_auth->canDo("modMail"),  $indent+6);
         $this->_htmlInputField($cmd."_usergroups","usergroups",$this->lang["user_groups"],$groups,$this->_auth->canDo("modGroups"),$indent+6);
 
+        if ($this->_auth->canDo("modPass")) {
+          if ($user) {
+            $notes[] = $this->lang['note_notify'];
+          }
+
+          ptln("<tr><td><label for=\"".$cmd."_usernotify\" >".$this->lang["user_notify"].": </label></td><td><input type=\"checkbox\" id=\"".$cmd."_usernotify\" name=\"usernotify\" value=\"1\" /></td></tr>", $indent);
+        }
+
         ptln("    </tbody>",$indent);
         ptln("    <tbody>",$indent);
         ptln("      <tr>",$indent);
@@ -290,6 +306,10 @@ class admin_plugin_usermanager extends DokuWiki_Admin_Plugin {
         ptln("      </tr>",$indent);
         ptln("    </tbody>",$indent);
         ptln("  </table>",$indent);
+
+        foreach ($notes as $note)
+          ptln("<div class=\"fn\">".$note."</div>",$indent);
+
         ptln("</form>",$indent);
     }
     
@@ -320,7 +340,18 @@ class admin_plugin_usermanager extends DokuWiki_Admin_Plugin {
         list($user,$pass,$name,$mail,$grps) = $this->_retrieveUser();
         if (empty($user)) return false;
 
-        return $this->_auth->createUser($user,$pass,$name,$mail,$grps);
+        if ($ok = $this->_auth->createUser($user,$pass,$name,$mail,$grps)) {
+
+          msg($this->lang['add_ok'], 1);
+
+          if (!empty($_REQUEST['usernotify']) && $pass) {
+            $this->_notifyUser($user,$pass);
+          }
+        } else {
+          msg($this->lang['add_fail'], 1);
+        }
+
+        return $ok;
     }
 
     /**
@@ -343,10 +374,33 @@ class admin_plugin_usermanager extends DokuWiki_Admin_Plugin {
           $part2 = str_replace('%d', (count($selected)-$count), $this->lang['delete_fail']);
           msg("$part1, $part2",-1);
         }
+
+        return true;
     }
 
     /**
-     * Modify user
+     * Edit user (a user has been selected for editing)
+     */
+    function _editUser($param) {
+        if (!$this->_auth->canDo('UserMod')) return false;
+
+        $user = cleanID(preg_replace('/.*:/','',$param));
+        $userdata = $this->_auth->getUserData($user);
+
+        // no user found?
+        if (!$userdata) {
+          msg($this->lang['edit_usermissing'],-1);
+          return false;
+        }
+
+        $this->_edit_user = $user;
+        $this->_edit_userdata = $userdata;
+
+        return true;
+    }
+
+    /**
+     * Modify user (modified user data has been recieved)
      */
     function _modifyUser(){
         if (!$this->_auth->canDo('UserMod')) return false;
@@ -370,7 +424,7 @@ class admin_plugin_usermanager extends DokuWiki_Admin_Plugin {
           // check if $newuser already exists
           if ($this->_auth->getUserData($newuser)) {
             msg(sprintf($this->lang['update_exists'],$newuser),-1);
-            $this->_edit_user = $olduser;
+            $re_edit = true;
           } else {
             $changes['user'] = $newuser;
           }
@@ -385,16 +439,43 @@ class admin_plugin_usermanager extends DokuWiki_Admin_Plugin {
         if (!empty($newgrps) && $this->_auth->canDo('modGroups') && $newgrps != $oldinfo['grps'])
           $changes['grps'] = $newgrps;
 
-    if ($this->_auth->modifyUser($olduser, $changes)) {
+        if ($ok = $this->_auth->modifyUser($olduser, $changes)) {
           msg($this->lang['update_ok'],1);
+
+          if (!empty($_REQUEST['usernotify']) && $newpass) {
+            $notify = empty($changes['user']) ? $olduser : $newuser;
+            $this->_notifyUser($notify,$newpass);
+          }
+
         } else {
           msg($this->lang['update_fail'],-1);
         }
+
+        if (!empty($re_edit)) {
+            $this->_editUser($olduser);
+        }
+
+        return $ok;
     }
 
-    /*
+    /**
+     * send password change notification email
+     */
+    function _notifyUser($user, $password) {
+
+        if ($sent = auth_sendPassword($user,$password)) {
+          msg($this->lang['notify_ok'], 1);
+        } else {
+          msg($this->lang['notify_fail'], -1);
+        }
+
+        return $sent;
+    }
+
+    /**
      * retrieve & clean user data from the form
-     * return an array(user, password, full name, email, array(groups))
+     *
+     * @return  array(user, password, full name, email, array(groups))
      */
     function _retrieveUser($clean=true) {
   
@@ -404,7 +485,7 @@ class admin_plugin_usermanager extends DokuWiki_Admin_Plugin {
         $user[3] = $_REQUEST['usermail'];
         $user[4] = preg_split('/\s*,\s*/',$_REQUEST['usergroups'],-1,PREG_SPLIT_NO_EMPTY);
 
-        if (is_array($user[4]) && (count($user[4]) == 1) && (trim($user[4][0]) == '')) {
+        if (empty($user[4]) || (is_array($user[4]) && (count($user[4]) == 1) && (trim($user[4][0]) == ''))) {
             $user[4] = null;
         }
 
