@@ -1,6 +1,8 @@
 <?php
 /**
  * french language file
+ *
+ * @author     Guy Brand <gb@isis.u-strasbg.fr>
  */
  
 // for admin plugins, the menu prompt to be displayed in the admin menu
@@ -11,7 +13,7 @@ $lang['menu'] = 'Gestion des utilisateurs';
 $lang['noauth']      = '(authentification utilisateur non disponible)';
 $lang['nosupport']   = '(gestion utilisateur non supportée)';
 
-$lang['badauth']     = 'méchanisme d\'authentification invalide';     // should never be displayed!
+$lang['badauth']     = 'mécanisme d\'authentification invalide';     // should never be displayed!
 
 $lang["user_id"] = "Identifiant";
 $lang["user_pass"] = "Mot de passe";
@@ -40,8 +42,18 @@ $lang['update_ok']   = 'utilisateur mis à jour avec succès';
 $lang['update_fail'] = 'échec de la mise à jour utilisateur';
 $lang['update_exists'] = 'échec du changement de nom d\'utilisateur,le nom spécifié (%s) existe déjà (toutes les autres modifications seront effectuées).';
 
-$lang['start']  = 'démarrage';
-$lang['prev']   = 'précédent';
-$lang['next']   = 'suivant';
-$lang['last']   = 'dernier';
+$lang['start']  = 'Démarrage';
+$lang['prev']   = 'Précédent';
+$lang['next']   = 'Suivant';
+$lang['last']   = 'Dernier';
+
+// added after 2006-03-09 release
+$lang['edit_usermissing'] = 'Utilisateur sélectionné non trouvé, cet utilisateur a peut-être été supprimé ou modifié ailleurs.';
+$lang['user_notify'] = 'Notifier l\'utilisateur';
+$lang['note_notify'] = 'Envoi de notification par courriel uniquement lorsqu\'un nouveau mot de passe est attribué à l\'utilisateur.';
+$lang['note_group'] = 'Les nouveaux utilisateurs seront ajoutés au groupe par défaut (%s) si aucun groupé n\'est spécifié.';
+$lang['add_ok'] = 'Utilisateur ajouté avec succès';
+$lang['add_fail'] = 'Echec de l\'ajout de l\'utilisateur';
+$lang['notify_ok'] = 'Courriel  de notification expédié';
+$lang['notify_fail'] = 'Echec de l\'expédition du courriel de notification';
 
