@@ -125,8 +125,12 @@ function showPicker(pickerid,btn){
  * @author Andreas Gohr <andi@splitbrain.org>
  */
 function initToolbar(tbid,edid,tb){
-    if(!document.getElementById){ return; }
-    var toolbar = document.getElementById(tbid);
+    var toolbar = $(tbid);
+    if(!toolbar) return;
+
+    //empty the toolbar area:
+    toolbar.innerHTML='';
+
     var cnt = tb.length;
     for(var i=0; i<cnt; i++){
         // create new button
@@ -328,7 +332,23 @@ var textChanged = false;
  */
 function changeCheck(msg){
   if(textChanged){
-    return confirm(msg);
+    var ok = confirm(msg);
+    if(ok){
+        // remove a possibly saved draft using ajax
+        var dwform = $('dw__editform');
+        if(dwform){
+            var params = 'call=draftdel';
+            params += '&id='+encodeURIComponent(dwform.elements.id.value);
+
+            var sackobj = new sack(DOKU_BASE + 'lib/exe/ajax.php');
+            sackobj.AjaxFailedAlert = '';
+            sackobj.encodeURIString = false;
+            sackobj.runAJAX(params);
+            // we send this request blind without waiting for
+            // and handling the returned data
+        }
+    }
+    return ok;
   }else{
     return true;
   }
@@ -346,15 +366,27 @@ function initChangeCheck(msg){
     var links = document.getElementsByTagName('a');
     for(var i=0; i < links.length; i++){
         if(links[i].className.indexOf('JSnocheck') == -1){
-            links[i].onclick = function(){return changeCheck(msg);};
-            links[i].onkeypress = function(){return changeCheck(msg);};
+            links[i].onclick = function(){
+                                    var rc = changeCheck(msg);
+                                    if(window.event) window.event.returnValue = rc;
+                                    return rc;
+                               };
+            links[i].onkeypress = function(){
+                                    var rc = changeCheck(msg);
+                                    if(window.event) window.event.returnValue = rc;
+                                    return rc;
+                               };
         }
     }
     // add change check for forms
     var forms = document.forms;
     for(i=0; i < forms.length; i++){
         if(forms[i].className.indexOf('JSnocheck') == -1){
-            forms[i].onsubmit = function(){return changeCheck(msg);};
+            forms[i].onsubmit = function(){
+                                    var rc = changeCheck(msg);
+                                    if(window.event) window.event.returnValue = rc;
+                                    return rc;
+                               };
         }
     }
 
@@ -374,8 +406,8 @@ function initChangeCheck(msg){
     };
     edit_text.onkeyup  = summaryCheck;
     var summary = document.getElementById('edit__summary');
-    summary.onchange = summaryCheck;
-    summary.onkeyup  = summaryCheck;
+    addEvent(summary, 'change', summaryCheck);
+    addEvent(summary, 'keyup', summaryCheck);
 
     // set focus
     edit_text.focus();
@@ -408,10 +440,11 @@ function locktimer_class(){
         this.pageid   = '';
 };
 var locktimer = new locktimer_class();
-    locktimer.init = function(timeout,msg){
+    locktimer.init = function(timeout,msg,draft){
         // init values
         locktimer.timeout  = timeout*1000;
         locktimer.msg      = msg;
+        locktimer.draft    = draft;
         locktimer.lasttime = new Date();
 
         if(!$('dw__editform')) return;
@@ -465,8 +498,16 @@ var locktimer = new locktimer_class();
     locktimer.refresh = function(){
         var now = new Date();
         // refresh every minute only
-        if(now.getTime() - locktimer.lasttime.getTime() > 60*1000){
-            locktimer.sack.runAJAX('call=lock&id='+encodeURI(locktimer.pageid));
+        if(now.getTime() - locktimer.lasttime.getTime() > 30*1000){ //FIXME decide on time
+            var params = 'call=lock&id='+encodeURIComponent(locktimer.pageid);
+            if(locktimer.draft){
+                var dwform = $('dw__editform');
+                params += '&prefix='+encodeURIComponent(dwform.elements.prefix.value);
+                params += '&wikitext='+encodeURIComponent(dwform.elements.wikitext.value);
+                params += '&suffix='+encodeURIComponent(dwform.elements.suffix.value);
+                params += '&date='+encodeURIComponent(dwform.elements.date.value);
+            }
+            locktimer.sack.runAJAX(params);
             locktimer.lasttime = now;
         }
     };
@@ -476,7 +517,12 @@ var locktimer = new locktimer_class();
      * Callback. Resets the warning timer
      */
     locktimer.refreshed = function(){
-        if(this.response != '1') return; // locking failed
+        var data  = this.response;
+        var error = data.charAt(0);
+            data  = data.substring(1);
+
+        $('draft__status').innerHTML=data;
+        if(error != '1') return; // locking failed
         locktimer.reset();
     };
 // end of locktimer class functions
