@@ -96,6 +96,7 @@ function ajax_spell_class(){
   this.txtNoSug = 'No Suggestions';
   this.txtChange= 'Change';
 
+  this.timer = null;
 
   /**
    * Initializes everything
@@ -119,6 +120,21 @@ function ajax_spell_class(){
     this.showboxObj = document.getElementById('spell__result');
     this.suggestObj = document.getElementById('spell__suggest');
 
+
+    // set wordwrap style with browser propritary attributes
+    if(is_gecko){
+      this.showboxObj.style.whiteSpace = '-moz-pre-wrap'; // Mozilla, since 1999
+    }else if(is_opera_preseven){
+      this.showboxObj.style.whiteSpace = '-pre-wrap';     // Opera 4-6
+    }else if(is_opera_seven){
+      this.showboxObj.style.whiteSpace = '-o-pre-wrap';   // Opera 7
+    }else{
+      this.showboxObj.style['word-wrap']   = 'break-word';    //Internet Explorer 5.5+
+    }
+    // Which browser supports this?
+    // this.showboxObj.style.whiteSpace = 'pre-wrap';      // css-3
+
+
     // set Translation Strings
     this.txtStart = txtStart;
     this.txtStop  = txtStop;
@@ -304,6 +320,14 @@ function ajax_spell_class(){
    * @author Andreas Gohr <andi@splitbrain.org>
    */
   this.start = function(){
+    if(ajax_spell.timer !== null){
+      window.clearTimeout(ajax_spell.timer);
+      ajax_spell.timer = null;
+    }else{
+      // there is no timer set, we timed out already
+      return;
+    }
+
     var data  = this.response;
     var error = data.charAt(0);
         data  = data.substring(1);
@@ -363,6 +387,27 @@ function ajax_spell_class(){
     ajax_spell.setState('start');
   };
 
+  /**
+   * Calback for the timeout handling
+   *
+   * Will be called when the aspell backend didn't return
+   */
+  this.timedOut = function(){
+    if(ajax_spell.timer !== null){
+      window.clearTimeout(ajax_spell.timer);
+      ajax_spell.timer = null;
+
+      ajax_spell.textboxObj.disabled      = false;
+      ajax_spell.showboxObj.style.display = 'none';
+      ajax_spell.textboxObj.style.display = 'block';
+      ajax_spell.editbarObj.style.visibility = 'visible';
+      ajax_spell.showboxObj.innerHTML     = '';
+      ajax_spell.setState('start');
+
+      window.alert('Error: The spell checker did not respond');
+  }
+  };
+
   // --- Callers ---
 
   /**
@@ -380,6 +425,9 @@ function ajax_spell_class(){
     ajax.onCompletion    = this.start;
     ajax.runAJAX('call=check&utf8='+ajax_spell.utf8ok+
                  '&data='+encodeURIComponent(ajax_spell.textboxObj.value));
+
+    // abort after 13 seconds
+    this.timer = window.setTimeout(ajax_spell.timedOut,13000);
   };
 
   /**
